@@ -3,6 +3,50 @@
 (use-modules (ice-9 optargs))
 
 
+;;;;;;;;;; create documentation for a command - this version just prints out basic info
+;;;;;;;;;;;;;DocumentCommand
+(define (DocumentCommand name)
+  (let ((help (d-GetHelp name)))
+    (if (boolean? help)
+	(begin
+	  (set! help (string-append "Help-d-" name))	  
+	  (let ((sym (with-input-from-string help read)))
+	    (if (defined? sym)
+		(set! help (eval sym (current-module)))
+		(set! help "No help")
+		))))
+    (format #t "~%~%Command ~A~%Tooltip ~A~%Label ~A~%Menu Path ~A~%" name help (d-GetLabel name) (d-GetMenuPath name))))
+;;;;;;;;;;;;;;; 
+
+;;;;;;;;;;;;;; Get highest and lowest note as lilypond syntax. Works on Chords and Single Notes.
+;;;;;;;;;;;;;; GetNotes returns a string of lily-notes from low to high. Make a list out of them and refer to the first (0) element or last (length -1) one.
+;;;;;;;;;;;;;; Returns #f if not a chord
+
+(define (d-GetLowestNote)
+(if (d-GetNotes)
+ (list-ref (string-tokenize(d-GetNotes)) 0 )
+ #f
+ ))
+
+(define (d-GetHighestNote)
+ (if (d-GetNotes)
+ (list-ref (string-tokenize(d-GetNotes)) (- (length (string-tokenize(d-GetNotes)) ) 1 ))
+ #f
+ ))
+
+
+(define (d-CursorGoUp x x-max dx) ;Cursor goes up a specific amount
+   (if (<= x x-max)
+      (begin
+      	(d-CursorUp)
+        (d-CursorGoUp (+ x dx) x-max dx))))
+
+(define (d-CursorGoDown x x-max dx)  ;Cursor goes down a specific amount
+   (if (<= x x-max)
+      (begin
+         (d-CursorDown)
+         (d-CursorGoDown (+ x dx) x-max dx))))
+
 
 (define Chord? (lambda ()
 		  (string=? (d-GetType) "CHORD")))
@@ -24,6 +68,24 @@
 				 (begin
 				    (eval-string  command)
 				    (ApplyToSelection command "(d-NextSelectedObject)"))))))
+(define (PrevDirectiveOfTag tag)
+  (let loop ()
+    (if (d-PrevStandaloneDirective)
+       (if (not (d-Directive-standalone? tag))
+	   (loop)
+	   #t
+	   )
+       #f)))
+(define (NextDirectiveOfTag tag)
+  (let loop ()
+    (if (d-NextStandaloneDirective)
+       (if (not (d-Directive-standalone? tag))
+	   (loop)
+	   #t
+	   )
+       #f)))
+
+
 (define stop "\0")
 (define cue-Advanced "Advanced")
 (define cue-PlaceAbove "Place above staff")
@@ -201,10 +263,25 @@
 
 
 ;;;;;;;;;; SetHeaderField sets a field in the movement header
+;;;;;;;;;; the directive created is tagged Score or Movement depending on the field
 
 (define* (SetHeaderField field #:optional (title #f))
-  (let ((current "") (thematch #f) (tag ""))
-    (set! tag (string-append "Movement-" field))
+  (let ((current "") (thematch #f) (tag "") (type "") (fieldname ""))
+    (if 
+     (or (equal? field "subtitle") (equal? field "subsubtitle") (equal? field "piece"))
+     (begin
+       (set! type "Movement")
+       (if (equal? field "subtitle")
+	   (set! fieldname "Title"))
+        (if (equal? field "subsubtitle")
+	   (set! fieldname "Subtitle"))
+	(if (equal? field "piece")
+	   (set! fieldname "Piece")) )
+     (begin
+       (set! type "Score")
+       (set! fieldname (string-capitalize field))))
+     
+    (set! tag (string-append type fieldname)) 
     (set! current (d-DirectiveGet-header-postfix tag))
     (if (boolean? current)
 	(set! current "") 
@@ -215,10 +292,10 @@
 	  (if (regexp-match? thematch)
 	      (set! current (match:substring thematch 1)))))
     (if (boolean? title)
-	(set! title (d-GetUserInput (string-append "Movement " field) 
-				    (string-append "Give a name for the " field " of the current movement") current)))
+	(set! title (d-GetUserInput (string-append type " " fieldname)
+				    (string-append "Give a name for the " fieldname " of the " type) current)))
     (d-DirectivePut-header-override tag DENEMO_OVERRIDE_GRAPHIC)
-    (d-DirectivePut-header-display tag (string-append field ": " title))
+    (d-DirectivePut-header-display tag (string-append type " " fieldname ": " title))
     
     (d-DirectivePut-header-postfix tag (string-append field " = \"" title "\"\n"))))
 
@@ -226,7 +303,7 @@
 
 (define (SetScoreHeaderField field)
 (let ((title "") (current "") (thematch #f) (tag ""))
-  (set! tag (string-append "Score" field))
+  (set! tag (string-append "Score" (string-capitalize field)))
   (set! current (d-DirectiveGet-scoreheader-postfix tag))
   (if (boolean? current)
       (set! current "") 
@@ -247,6 +324,10 @@
   (d-DirectivePut-standalone-minpixels tag 0)
   (d-CursorLeft))
 
+(define (d-Directive-standalone tag)
+  (if (not (d-Directive-standalone? tag))
+      (d-DirectivePut-standalone tag)))
+
 (define* (d-Directive-standalone?  #:optional (tag #f))
   (if (equal? tag #f)
       (string? (d-DirectiveGetForTag-standalone ""))
@@ -606,3 +687,23 @@
   (d-OutputMIDI (string-append "0x9$ " pitch " %%%"))
  (d-OneShotTimer duration (string-append "(d-OutputMIDI " "\"" "0x8$ " pitch " %%%" "\"" ")" )) 
   )
+
+;;;;;;;;;;;;;; Refresh Procedures.
+;;;;;;;;;;;;;; Naming convention D-<tag> is the refresh proc for tag
+
+(define (D-Anacrusis)
+(let ((duration (d-GetDurationInTicks)))
+  (if (boolean? duration)
+      (set! duration 0))
+  (while (d-NextObjectInMeasure) 
+	 (set! duration (+ duration (d-GetDurationInTicks))))
+  (PrevDirectiveOfTag "Anacrusis")
+  (set! duration (/ duration 12))
+  (if (equal? 0 duration)
+      (begin
+	(HideStandaloneDirective))
+      (begin
+	(d-DirectivePut-standalone-postfix "Anacrusis" (string-append "\\partial 128*" (number->string duration) " " ))))))
+
+
+;;;;;;;;;;;;;;;;;Multi-Measure Rests
