@@ -57,11 +57,7 @@ typedef struct note
   gint y; /**< Holds y co-ordinate for drawing rather than recalculating it each
   		   run through the drawing loop. see calculateheight  */
   enum headtype noteheadtype; /**< Holds note head type.  */
-  gint x_off;  /**< Holds x offset from default position.  */
-  gint y_off; /**< Holds y offset from default position.  */
-  GString *prefix;  /**< LilyPond text to be inserted before the note */
-  GString *postfix; /**< LilyPond text to be inserted after the note */
-  GString *display; /**< something to display to describe the LilyPond attached to the note */
+  GList *directives;/**< list of DenemoDirective to apply to the note */
 }
 note;
 
@@ -103,6 +99,8 @@ typedef enum ornament {
 }Ornament;
  
 
+
+
 /**
  * Structure describing a chord
  * 1;7B
@@ -164,9 +162,9 @@ typedef struct chord
   gboolean is_fakechord; /**< This is the actual value of the fake chord if is_fakechord */
   gpointer fakechord; /**< This is the actual value of the fake chord if is_fakechord */
   gpointer fakechord_extension; /**< This is the extension to the fake chord. It may be a 7, sus4, 9, 11, 13 etc... */
-  GString *prefix; /**< LilyPond text to be inserted before the chord */
-  GString *postfix;/**< LilyPond text to be inserted after the chord */
-  GString *display; /**< something to display to describe the LilyPond attached to the chord */
+  
+  GList *directives;/**< list of DenemoDirective to apply to the chord */
+
 }
 chord;
 
@@ -201,6 +199,7 @@ typedef enum clefs
 typedef struct clef
 {
   enum clefs type;
+  GList *directives;
 }
 clef;
 
@@ -212,6 +211,7 @@ typedef struct timesig
 {
   gint time1; /**< This is the numerator for a time signature */
   gint time2; /**< This is the denominator for a time signature */
+  GList *directives;
 }
 timesig;
 
@@ -224,6 +224,7 @@ typedef struct keysig
   gint isminor; /**< Type of key 0-major 1-minor 2-mode */
   gint mode;  /**< Mode indicator */
   gint accs[7];
+  GList *directives;
 }
 keysig;
 
@@ -272,22 +273,23 @@ typedef struct lyric
 }lyric;
 
 
-/* Data structure for an arbitrary directive to be passed to
- * Lilypond that Denemo doesn't understand. This type is useful
- * in that the user can insert such directives into a LilyPond file
- * by hand and have Denemo respect them when it loads a file and
- * write them back when it saves it */
+/* A standalone DenemoDirective. lilydirective is an obsolete name */
+
+#define lilydirective DenemoDirective
+#if 0
+typedef struct lilydirective DenemoDirective;
 
-typedef struct lilydirective
 {
   GString *directive;/**< the LilyPond text */
   gboolean locked;/**< If true the directive cannot be deleted easily */
   GString *display;/**< Something for Denemo to display (to indicate what the directive is doing*/
   gint x;/**< horizontal offset of display text */
   gint y;/**< vertical offset of display text */
+  GdkBitmap *graphic; /**< bitmap to draw for this directive */
+  gint width, height; /**< width and height of the bitmap */
 }
 lilydirective;
-
+#endif
 
 /**
  * Enum defining stem direction values
