@@ -101,7 +101,7 @@ static gchar *DenemoObjTypeNames[] =
   "FAKECHORD",
   "PARTIAL"
 };
-#define DENEMO_OBJECT_TYPE_NAME(obj) (obj?((obj->type<G_N_ELEMENTS(DenemoObjTypeNames))?DenemoObjTypeNames[obj->type]:NULL):NULL)
+#define DENEMO_OBJECT_TYPE_NAME(obj) ((obj)?(((obj)->type<G_N_ELEMENTS(DenemoObjTypeNames))?DenemoObjTypeNames[(obj)->type]:NULL):NULL)
 
 
 /**
@@ -159,14 +159,13 @@ typedef struct
   GList* midi_events;/**< data are the smf_event_ts that this object gives rise to */
   /**< Allots extra space for accidentals or reverse-aligned notes if
    * the stem is down */
-  gint space_before; /**< Used to specify how much space is needed before the object */
-  gint minpixelsalloted; 
+  gint space_before; /**< Used to specify how much space is needed before the object in display */
+  gint minpixelsalloted;  /**< horizontal space allowed for this object in display */
   gint x; /**< Holds x co-ordinate relative to the beginning of the measure. used in mousing.c */
   gboolean isstart_beamgroup; /**< TRUE if object is the start of a beam group */
   gboolean isend_beamgroup; /**< TRUE if this is the end of a beam group */
-  /* Mudelaobjunion u; has become a pointer*/
   gpointer object; /**< the structures pointed to are given in denemo_objects.h */
-  gboolean isinvisible; /**< If  TRUE it will be rendered white and will not be seen. If it is set FALSE then it will be drawn normally. */
+  gboolean isinvisible; /**< If  TRUE it will be drawn in a distinctive color and will be printed transparent. */
 } DenemoObject;
 
 
@@ -220,7 +219,7 @@ typedef struct
    */
   gint no_of_lines; /**< Number of lines on the staff */
   gint transposition; /**< Determines if the notes are to be played back at pitch or not */
-  gint pos_in_half_lines; /**< I believe this maybe broken. It does not seem to do much*/ 
+
   gint volume;	/**< Volume used for midi/csound playback */
   gboolean mute_volume; /**< mute Volume of voices playback */
   /* Back to Hiller stuff */
@@ -232,10 +231,10 @@ typedef struct
   GString *denemo_name; /**< denemo_name gets copied into lily_name */
   GString *lily_name; /**< this is the name of the staff that is export to lilypond */
   GString *midi_instrument; /**< midi instrument name used for the staff when exported via midi */
-  gboolean midi_prognum_override; /**< override to allow manually setting prognum + channel */
-  guint8 midi_prognum; /**< midi prognum assigned to the staff voice */
-  guint8 midi_channel; /**< midi channel assigned to the staff voice */
-  gint jack_midi_out_port; /**< the port number that jackmidi has assigned */ 
+  GString *device_port; /**< Device name and Port name concatenated into one string */ 
+  gint midi_prognum; /**< midi prognum assigned to the staff voice */
+  gint midi_channel; /**< midi channel assigned to the staff voice */
+  gint midi_port; /**< midi port assigned to the staff voice */ 
   gint space_above; /**< space above the staff used in the denemo gui */
   gint space_below; /**< space below the staff used in the denemo gui */
   GList *verses;/**< a list of text editor widgets each containing a verse */
@@ -298,6 +297,31 @@ typedef struct DenemoKeymap
   GHashTable *cursors;//hashtable linking GdkEvent state to a cursor that should be used in that state
 }keymap;
 
+typedef struct MidiBuffer
+{
+  unsigned char buffer[3];
+  gint channel;
+} MidiBuffer;
+
+#define DENEMO_BUFFER_MAX_INDEX	(100)
+typedef struct DeviceManagerPort
+{
+  GString *port_name;
+  gpointer output_port;
+  MidiBuffer *midi_buffer;/*< an array of midi events queueing for output */
+  gint Index;
+  gint FillIndex;
+volatile  gint BufferEmpty;
+} DeviceManagerPort;
+
+/* structure for device manager */
+typedef struct DeviceManagerDevice
+{
+  GString *client_name;
+  gpointer jack_client;/**< Jack handle for the client with this name */
+  GArray *ports_array;/**< holds the ports array for resizing purposes */
+  DeviceManagerPort *ports;/*< ports for this client, NULL terminated */
+} DeviceManagerDevice;
 
 /**
  * DenemoPrefs holds information on user preferences. 
@@ -329,6 +353,8 @@ typedef struct DenemoPrefs
   gboolean autoupdate;/**< update command set from denemo.org */
   gint maxhistory;/**< how long a history of used files to retain */
   GString *browser; /**< Default browser string */
+  
+  gchar *midi_audio_output; /**< How the user wants to deal with audio/midi output */
   GString *csoundcommand; /**< command used to execute csound */
   GString *csoundorcfile; /**< Path to .orc file used for csound playback */
   gboolean rtcs; /**< Real time csound */
@@ -336,7 +362,16 @@ typedef struct DenemoPrefs
   GString *midi_in;  /**< path to midi_in device */
   gboolean jacktransport; /**< toggle on and off jack transport */
   gboolean jacktransport_start_stopped; /**< toggle if you don't want transport to play immediately but rely on the transport controls */
-  gboolean jack_at_startup; /**< toggle on and off jack initialization at startup */
+#define DENEMO_MAX_DEVICES (50)
+  GArray *midi_device_array;/**< holds the midi_device array for re-sizing purposes */
+  DeviceManagerDevice *midi_device; /**< contains device name and output ports */ 
+  GString *fluidsynth_audio_driver; /**< Audio driver used by fluidsynth */
+  GString *fluidsynth_soundfont; /**< Default soundfont for fluidsynth */
+  gboolean fluidsynth_reverb; /**< Toggle if reverb is applied to fluidsynth */
+  gboolean fluidsynth_chorus; /**< Toggle if chorus is applied to fluidsynth */
+  gint fluidsynth_sample_rate;/**< sample rate in Hz > */
+  gint fluidsynth_period_size;/**< The size of the audio buffers (in frames).> */
+
   GString *pdfviewer; /**< PDF viewer */
   GString *imageviewer; /**< Image Viewer */
   GString *username; /**< Username for use on denemo.org website */
@@ -394,6 +429,9 @@ typedef struct DenemoDirective
 
 #define DENEMO_MIDI_INTERPRETATION_MASK (DENEMO_OVERRIDE_RELATIVE | DENEMO_OVERRIDE_PERCENT) 
 
+#define DENEMO_OVERRIDE_DYNAMIC (1<<28)
+#define DENEMO_OVERRIDE_HIDDEN (1<<29)
+
 
 
   guint32 override; /**< specifies what if anything of the built-in behaviour of the object the directive is attached to is to be overriden by this directive and values to use when overriding MIDI */
@@ -535,6 +573,16 @@ typedef struct DenemoScriptParam { /**< commands called by scripts use one of th
 
 
 
+typedef struct DenemoPosition { /**<Represents a position in a Score */
+  gint movement;
+  gint staff;
+  gint measure;
+  gint object;/**< 0 means no object */
+} DenemoPosition;
+
+
+
+
 typedef struct DenemoScoreblock {
   GString *scoreblock;/**< text of the scoreblock */
   gboolean visible;/**< Whether the scoreblock should be used by default */
@@ -685,6 +733,7 @@ typedef struct DenemoScore
  */
 typedef struct DenemoGUI
 {
+  gint id; /* A unique id, not repeated for this run of the Denemo program */
   /* Fields used fairly directly for drawing */
   GtkWidget *page;
   GtkWidget *scorearea;
@@ -726,7 +775,7 @@ typedef struct DenemoGUI
   GList *midi_events;/*< midi_events to be output at start of first track of each movement */
 
   GList *custom_scoreblocks; /**< List of customized texts for LilyPond output, replaces standard score blocks, elements are DenemoScoreblock * */
-
+  GList *callbacks;/**< scheme callbacks on deletion */
   gpointer lilystart, lilyend; /**<range of lilytext  */
   GString **target; /**< pointer to target string for modification in lilytext  */
   GList *anchors;/**< anchors in the LilyPond text at points where that can be edited */
