@@ -315,7 +315,7 @@ there is a function newclefify and fixnoteheights...
   else
     si->currentobject = g_list_nth ((objnode *) si->currentmeasure->data,
 				    si->cursor_x);
-
+  // g_print("object %p cursorx %d length %d\n", si->currentobject, si->cursor_x, g_list_length(si->currentmeasure->data));
   update_undo_info (si, undo);
 
   score_status(gui, TRUE);
@@ -802,15 +802,17 @@ shiftcursor (DenemoGUI  *gui, gint note_value)
   /* in edit mode edit the current note name */
   if((gui->mode & INPUTEDIT) && gui->si->currentobject) {
     DenemoObject *theobj =  (DenemoObject *)(gui->si->currentobject->data);
-    if(theobj->type == CHORD && ((chord*)theobj->object)->notes) {
-      if(g_list_length( ((chord*)theobj->object)->notes)>1) {/* multi-note chord - remove and add a note */
+    chord *thechord;
+    if(theobj->type == CHORD && (thechord = (chord*)theobj->object)->notes) {
+      theobj->isinvisible=FALSE;
+      if(g_list_length(thechord->notes)>1) {/* multi-note chord - remove and add a note */
 	gui->si->cursor_y = oldcursor_y;
 	delete_chordnote(gui->si);
 	gui->si->cursor_y = mid_c_offset;
 	insert_chordnote (gui->si);
       } else {/* single-note chord - change the note */
       gint dclef = find_prevailing_clef(gui->si);	    
-      modify_note((chord*)theobj->object, mid_c_offset, gui->si->curmeasureaccs[note_value], dclef);
+      modify_note(thechord, mid_c_offset, gui->si->curmeasureaccs[note_value], dclef);
       showwhichaccidentals ((objnode *) gui->si->currentmeasure->data,
 			    gui->si->curmeasurekey, gui->si->curmeasureaccs);
       }
@@ -912,7 +914,7 @@ insertion_point (DenemoScore * si)
       else
 	si->currentmeasure = si->currentmeasure->next;
       if(Denemo.gui->mode&(INPUTRHYTHM))
-	gdk_beep();
+	signal_measure_end();
       /* Now the stuff that needs to be done for each case */
       si->currentmeasurenum++;
       si->currentobject = (objnode *) si->currentmeasure->data;
@@ -950,7 +952,7 @@ dnm_insertchord (DenemoGUI * gui, gint duration, input_mode mode,
   if ((mode & INPUTNORMAL) && (rest != TRUE))
     addtone (mudela_obj_new, si->cursor_y, si->cursoraccs[si->staffletter_y],
 	     si->cursorclef);
-  if ((mode & INPUTBLANK) || (gui->mode & INPUTBLANK))
+  if ((mode & INPUTBLANK) || (gui->mode & INPUTBLANK) || (!rest &&(gui->mode&(INPUTRHYTHM))))
     mudela_obj_new->isinvisible = TRUE;
 
   //  if (si->is_grace_mode)
@@ -965,15 +967,21 @@ dnm_insertchord (DenemoGUI * gui, gint duration, input_mode mode,
   object_insert (gui, mudela_obj_new);
  
   if (gui->mode&(INPUTRHYTHM)) {
+
+#ifdef _HAVE_FLUIDSYNTH_
+    fluid_rhythm_feedback(duration, rest, FALSE);
+#else
     if(rest)
       playpitch(64.0*(1+duration), 60.0/(4.0*gui->si->tempo*(1<<duration)), 0.1, 2);//FIXME make a distinct noise
       else
 	playpitch(64.0*(1+duration), 60.0/(gui->si->tempo*(1<<duration)), 0.2, 1);
+#endif
+
+
   } else {
     if(Denemo.gui->input_source==INPUTKEYBOARD) {
       DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
-      prognum = select_program (curstaffstruct->midi_instrument->str);
-      playnotes (Denemo.prefs.immediateplayback, *(chord *) mudela_obj_new->object, prognum);
+      playnotes (Denemo.prefs.immediateplayback, *(chord *) mudela_obj_new->object,  curstaffstruct->midi_channel);
     }
   }
 }
@@ -1098,9 +1106,9 @@ notechange (DenemoScore * si, gboolean remove)
 	}
       if(Denemo.gui->input_source==INPUTKEYBOARD) {
 	DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
-	prognum = select_program (curstaffstruct->midi_instrument->str);
+
 	playnotes (Denemo.prefs.immediateplayback,
-	 *(chord *) curmudelaobj->object, prognum);
+	 *(chord *) curmudelaobj->object, curstaffstruct->midi_channel);
       }
     }
   return ret;
@@ -1177,9 +1185,9 @@ incrementenshift (DenemoGUI * gui, gint direction)
 	}
       if(Denemo.gui->input_source==INPUTKEYBOARD) {
 	DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
-	prognum = select_program (curstaffstruct->midi_instrument->str);
+
 	playnotes (Denemo.prefs.immediateplayback,
-		   *(chord *) curmudelaobj->object, prognum);
+		   *(chord *) curmudelaobj->object, curstaffstruct->midi_channel);
       }
       unre_data *data = (unre_data *) g_malloc (sizeof (unre_data));
       data->object = curmudelaobj;
@@ -1217,9 +1225,8 @@ setenshift (DenemoScore * si, gint enshift)
 
       if(Denemo.gui->input_source==INPUTKEYBOARD) {
 	DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
-	prognum = select_program (curstaffstruct->midi_instrument->str);
 	playnotes (Denemo.prefs.immediateplayback,
-		   *(chord *) curmudelaobj->object, prognum);
+		   *(chord *) curmudelaobj->object, curstaffstruct->midi_channel);
 
       }
       unre_data *data = (unre_data *) g_malloc (sizeof (unre_data));
@@ -1281,7 +1288,15 @@ changedots (DenemoScore * si, gint amount)
   if (curmudelaobj && curmudelaobj->type == CHORD)
     {
       if (Denemo.gui->mode&(INPUTRHYTHM))
+#ifdef _HAVE_FLUIDSYNTH_
+	{
+	  chord *thechord = (chord *) curmudelaobj->object;
+	  gboolean rest =  (thechord->notes == NULL);
+	  fluid_rhythm_feedback(thechord->baseduration, rest, TRUE);
+	}
+#else
 	  playpitch(440.0, 0.2, 0.2, 1);
+#endif
       changenumdots (curmudelaobj, amount);
 
       if (curmudelaobj->user_string)
@@ -1311,6 +1326,60 @@ dnm_insertmeasures (DenemoScore * si, gint number)
   /* update_hscrollbar (si); */
 }
 
+/**
+ *  Insert measure into the staff after the current position
+ 
+ */
+void
+insertmeasureafter (DenemoGUI *gui)
+{
+  DenemoScore *si = Denemo.gui->si;
+  si->currentmeasure = addmeasures (si, si->currentmeasurenum++, 1, 0);
+  si->cursor_x = 0;
+  si->cursor_appending = TRUE;
+  si->currentobject = NULL;
+  set_rightmeasurenum (si);
+  si->markstaffnum = 0;
+  calcmarkboundaries (si);
+  /* update_hscrollbar (si); */
+}
+
+/**
+ *  Insert measure into the staffs after the current position
+ 
+ */
+void
+addmeasureafter (DenemoGUI *gui)
+{
+  DenemoScore *si = Denemo.gui->si;
+  si->currentmeasure = addmeasures (si, si->currentmeasurenum++, 1, 1);
+  si->cursor_x = 0;
+  si->cursor_appending = TRUE;
+  si->currentobject = NULL;
+  set_rightmeasurenum (si);
+  si->markstaffnum = 0;
+  calcmarkboundaries (si);
+  /* update_hscrollbar (si); */
+}
+
+/**
+ *  Insert measure into the staff before the current position
+ 
+ */
+void
+insertmeasurebefore (DenemoGUI *gui)
+{
+  DenemoScore *si = Denemo.gui->si;
+  si->currentmeasure = addmeasures (si, si->currentmeasurenum-1, 1, 0);
+  si->cursor_x = 0;
+  si->cursor_appending = TRUE;
+  si->currentobject = NULL;
+  set_rightmeasurenum (si);
+  si->markstaffnum = 0;
+  calcmarkboundaries (si);
+  /* update_hscrollbar (si); */
+}
+
 /**
  * Add measure to the end of the score
  * 
