@@ -154,6 +154,9 @@ void delete_staff_after(GtkAction *action, gpointer param);
 void
 appendmeasurestoentirescore(DenemoScore *si, gint number);
 
+void insertmeasureafter(DenemoGUI *gui);
+void addmeasureafter(DenemoGUI *gui);
+void insertmeasurebefore(DenemoGUI *gui);
 
 void deletemeasure(DenemoGUI * gui);
 void deletemeasureallstaffs(DenemoGUI * gui);
