@@ -38,12 +38,13 @@ static GdkGC *  lightbluegc;
 static GdkGC *  blackgc;
 static GdkGC *greengc = NULL;
 
-GdkPixbuf *StaffPixbuf;
+GdkPixbuf *StaffPixbuf, *StaffPixbufSmall;
 
 static void      
 create_tool_pixbuf(void) {
   GtkWidget *widget = gtk_button_new();
   StaffPixbuf = gtk_widget_render_icon (widget, GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_BUTTON, "denemo");
+  StaffPixbufSmall = gtk_widget_render_icon (widget, GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_MENU, "denemo");
 }
 
 
@@ -125,11 +126,12 @@ static gint count_syllables(DenemoStaff *staff, gint from) {
   gint count = 0;
   gint i;
   GList *curmeasure = staff->measures;
+  gboolean in_slur = FALSE;
   for(i=1;curmeasure && (i<from);i++, curmeasure = curmeasure->next) {
     objnode *curobj;
     for(curobj = curmeasure->data;curobj;curobj=curobj->next) {
       DenemoObject *obj = curobj->data;
-      gboolean in_slur = FALSE;
+      
       if(obj->type==CHORD) {
 	  chord *thechord = ((chord *) obj->object);
 	  if(thechord->notes && !in_slur)
@@ -141,8 +143,10 @@ static gint count_syllables(DenemoStaff *staff, gint from) {
 	  if (thechord->is_tied)
 	    count--;
       }
-    }
-  }
+    }//for objs
+  }//for measures
+  if(in_slur)
+    return -count;
   return count;
 }
 
@@ -505,31 +509,28 @@ draw_measure (measurenode * curmeasure, gint x, gint y,
       si->cursortime2 = itp->time2;
     }
 
-  /*  paint the measure number at the
-   * preceding barline */
+  /*  paint the measure number at the preceding barline 
+      - do not do measure 1 as it clashes with the name (and is not needed) */
 
-  //  if (si->currentstaffnum == itp->staffnum)
+  if(itp->measurenum>1) {
+    g_string_sprintf (mstring, "%d", itp->measurenum);
+    pango_layout_set_text (layout, mstring->str, -1);
+    desc = pango_font_description_from_string (FONT);
+    pango_layout_set_font_description (layout, desc);
+    pango_font_description_free (desc);
+    gdk_draw_layout (gui->pixmap, itp->gc, x - SPACE_FOR_BARLINE,
+		     y - 12, layout);
+  }
+  // draw the cursor and set the side effects up if this didn't happen when drawing the currentobject
+  if (!si->currentobject && (si->currentstaffnum == itp->staffnum && si->currentmeasurenum == itp->measurenum))
     {
-      g_string_sprintf (mstring, "%d", itp->measurenum);
-      pango_layout_set_text (layout, mstring->str, -1);
-      desc = pango_font_description_from_string (FONT);
-      pango_layout_set_font_description (layout, desc);
-      pango_font_description_free (desc);
-      gdk_draw_layout (gui->pixmap, itp->gc, x - SPACE_FOR_BARLINE,
-		       y - 12, layout);
-
-      //gdk_draw_text (si->pixmap, mnumfont, itp->gc, x - SPACE_FOR_BARLINE,
-      // y - 2, mstring->str, mstring->len);
-      if (si->currentmeasurenum == itp->measurenum && !si->currentobject && (si->currentstaffnum == itp->staffnum))
-	{
-	  /* That is, the cursor's at the beginning of this blank measure */
-	  si->cursoroffend = FALSE; 
-	  draw_cursor (gui->pixmap, si, x, y, gui->mode, itp->clef->type);
-	  memcpy (si->cursoraccs, itp->curaccs, SEVENGINTS);
-	  si->cursorclef = itp->clef->type;
-	  
-	}
+      /* That is, the cursor's at the beginning of this blank measure */
+      si->cursoroffend = FALSE; 
+      draw_cursor (gui->pixmap, si, x, y, gui->mode, itp->clef->type);
+      memcpy (si->cursoraccs, itp->curaccs, SEVENGINTS);
+      si->cursorclef = itp->clef->type;     
     }
+  
   curobj = (objnode *) curmeasure->data;
   /* These default values for the markx'es may be necessary down
    * the road */
@@ -597,15 +598,16 @@ draw_measure (measurenode * curmeasure, gint x, gint y,
  * @param y    y position of the staff
  * @param gui   pointer to the DenemoGUI structure
  * @param itp  pointer to the infotopass structure
+ * return TRUE if the staff has had to made taller
  */
-static void
+static gboolean
 draw_staff (DenemoStaff * curstaffstruct, gint y,
 	    DenemoGUI * gui, struct infotopass *itp)
 {
   PangoContext *context;
   PangoLayout *layout;
   PangoFontDescription *desc;
-
+  gboolean repeat = FALSE;
   DenemoScore *si = gui->si;
   gint x, i;
   GdkGC *gc;
@@ -641,7 +643,7 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
   if (si->laststaffmarked == itp->staffnum)
     itp->marky2 = y + STAFF_HEIGHT + EXTRAFORSELECTRECT;
 
-  gint buffer = (curstaffstruct->voicenumber == 1) ? 24 :
+  gint staffname_offset = (curstaffstruct->voicenumber == 1) ? 24 :
     (curstaffstruct->voicenumber == 2
      || curstaffstruct->voicenumber == 3) ? 12 : 0;
 
@@ -649,10 +651,10 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
   pango_layout_set_text (layout, curstaffstruct->denemo_name->str, -1);
   desc = pango_font_description_from_string (FONT);
   pango_layout_set_font_description (layout, desc);
+  gdk_draw_layout (gui->pixmap, gc, KEY_MARGIN, y - staffname_offset, layout);
 
 
-  gdk_draw_layout (gui->pixmap, gc, KEY_MARGIN, y - buffer, layout);
-  gint title_highy = 0;
+  // gint title_highy = 0;
 
   pango_font_description_free (desc);
 
@@ -679,10 +681,19 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
       itp->curmeasure = itp->curmeasure->next;
       itp->mwidthiterator = itp->mwidthiterator->next;
       itp->measurenum++;
+
+      if(-itp->highy>itp->in_highy && -itp->highy<MAXEXTRASPACE){
+	curstaffstruct->space_above = -itp->highy;
+	repeat = TRUE;
+      }
+      if(itp->lowy>itp->in_lowy && itp->lowy<MAXEXTRASPACE){
+	curstaffstruct->space_below = itp->lowy;
+	repeat=TRUE;
+      }				      
     }
 
-  if(itp->highy > title_highy)
-    itp->highy = title_highy;
+  // if(itp->highy > title_highy)
+  //  itp->highy = title_highy;
 
   /* now draw the staff lines, reset itp->slur_stack, and we're done */
   for (i = 0; i < curstaffstruct->no_of_lines; i++, y += LINE_SPACE)
@@ -696,6 +707,7 @@ draw_staff (DenemoStaff * curstaffstruct, gint y,
       g_slist_free (itp->slur_stack);
       itp->slur_stack = NULL;
     }
+  return repeat;
 }
 
 /**
@@ -733,6 +745,8 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
        curstaff && itp.staffnum <= si->bottom_staff; itp.staffnum++) {
     DenemoStaff *staff = (DenemoStaff *) curstaff->data;
     itp.verse = staff->currentverse?staff->currentverse->data:NULL;
+    GdkPixbuf *StaffDirectivesPixbuf = (si->currentstaffnum==itp.staffnum)?StaffPixbuf:StaffPixbufSmall;
+      
 
     if (curstaff && staff->voicenumber == 1)
       y += staff->space_above;
@@ -748,17 +762,17 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
     itp.highy = 0;//do not pass on extra_space from one staff to the next
 	gdk_draw_rectangle (gui->pixmap, gcs_lightbluegc(), TRUE, 0, y, LEFT_MARGIN, STAFF_HEIGHT/*staff edit*/);
 
-      if(staff->staff_directives) {
+      if(staff->staff_directives){
 
-	guint width = gdk_pixbuf_get_width( GDK_PIXBUF(StaffPixbuf));
-	guint height = gdk_pixbuf_get_height( GDK_PIXBUF(StaffPixbuf));
-	gdk_draw_pixbuf(gui->pixmap, NULL, StaffPixbuf,  0,0, 0,y, width, height, GDK_RGB_DITHER_NONE,0,0/*staff edit*/);
+	guint width = gdk_pixbuf_get_width( GDK_PIXBUF(StaffDirectivesPixbuf));
+	guint height = gdk_pixbuf_get_height( GDK_PIXBUF(StaffDirectivesPixbuf));
+	gdk_draw_pixbuf(gui->pixmap, NULL, StaffDirectivesPixbuf,  0,0, 0,y, width, height, GDK_RGB_DITHER_NONE,0,0/*staff edit*/);
       }
       if(staff->voice_directives) {
 
-	guint width = gdk_pixbuf_get_width( GDK_PIXBUF(StaffPixbuf));
-	guint height = gdk_pixbuf_get_height( GDK_PIXBUF(StaffPixbuf));
-	gdk_draw_pixbuf(gui->pixmap, NULL, StaffPixbuf,  0,0, 0,y + STAFF_HEIGHT/2, width, height, GDK_RGB_DITHER_NONE,0,0/*staff edit*/);
+	guint width = gdk_pixbuf_get_width( GDK_PIXBUF(StaffDirectivesPixbuf));
+	guint height = gdk_pixbuf_get_height( GDK_PIXBUF(StaffDirectivesPixbuf));
+	gdk_draw_pixbuf(gui->pixmap, NULL, StaffDirectivesPixbuf,  0,0, 0,y + STAFF_HEIGHT/2, width, height, GDK_RGB_DITHER_NONE,0,0/*staff edit*/);
       }
     
     
@@ -772,22 +786,31 @@ draw_score (GtkWidget * widget, DenemoGUI * gui)
       gdk_draw_rectangle (gui->pixmap, lightbluegc, TRUE, KEY_MARGIN-cmajor,y,key+2*cmajor,STAFF_HEIGHT);/*keysig edit*/
       gdk_draw_rectangle (gui->pixmap, graygc, TRUE, KEY_MARGIN+key+cmajor,y,SPACE_FOR_TIME-cmajor,STAFF_HEIGHT);/*timesig edit*/
     }
-    if(si->currentstaffnum==itp.staffnum)
-      reset_lyrics(staff, count_syllables(staff, si->leftmeasurenum));
+    if(si->currentstaffnum==itp.staffnum) {
+
+      gint count =  count_syllables(staff, si->leftmeasurenum);
+      if(count<0) {
+	count = -count;
+	itp.slur_stack =
+	  push_slur_stack (itp.slur_stack, 0);
+      }
+      reset_lyrics(staff, count);
+    }
     
     //allocate wronglength[] large enough for si->rightmeasurenum - si->leftmeasurenum entries then put it in itp
     // and set it in draw_measure
 
     gboolean *wronglength = (gboolean *)g_malloc((sizeof(gboolean))*(2+si->rightmeasurenum - si->leftmeasurenum));
     itp.wronglengths = wronglength;
-    draw_staff (staff, y, gui, &itp);
+    repeat = draw_staff (staff, y, gui, &itp);
 
+#if 0
     //IN FACT itp.highy is only set by one measure, it is reset to zero in the measure loop
     if(-itp.highy>highy && -itp.highy<MAXEXTRASPACE) //FIXME this should be done before draw_staff returns
       /*g_print("setting space above %d staff %d\n", -itp.highy, itp.staffnum),*/staff->space_above = -itp.highy, repeat=TRUE;
     if(itp.lowy>lowy && itp.lowy<MAXEXTRASPACE)
       staff->space_below = itp.lowy, repeat=TRUE;
-
+#endif
     gint measures_in_staff = g_list_length(staff->measures);
     /* Now draw the barlines between the measures, across all the staffs */
     mwidthiterator = g_list_nth (si->measurewidths, si->leftmeasurenum - 1);
@@ -861,7 +884,7 @@ DenemoGUI *gui = Denemo.gui;
 
  do{
    /* Clear the backing pixmap */
-   if(Denemo.gui->input_source!=INPUTKEYBOARD &&
+   if(Denemo.gui->input_source!=INPUTKEYBOARD && Denemo.gui->input_source!=INPUTMIDI &&
       (Denemo.prefs.overlays || (Denemo.gui->input_source==INPUTAUDIO))
       && pitch_entry_active(gui)) {
      gdk_draw_rectangle (gui->pixmap,
