@@ -19,7 +19,7 @@ drawbarline (GdkPixmap * pixmap, GdkGC * gc, gint xx, gint top_y, gint y,
 
   if (type == ORDINARY_BARLINE)
     {
-      //g_print("Ordinary");
+      g_print ("Ordinary Co-ords (%d,%d) - (%d,%d) ", xx, top_y, xx, y);
       gdk_draw_line (pixmap, gc, xx, top_y, xx, y);
     }
   else if (type == DOUBLE_BARLINE)
