@@ -710,11 +710,13 @@ static gchar *get_postfix(GList *g) {
   GString *ret = g_string_new("");
   for(;g;g=g->next) {
     DenemoDirective *d = g->data;
-    if(d->postfix && d->postfix->len)
-      if(d->override & DENEMO_OVERRIDE_LILYPOND)
-	g_string_prepend(ret, d->postfix->str);
-      else
-	g_string_append(ret, d->postfix->str);
+    if(!((d->override & DENEMO_OVERRIDE_HIDDEN))){
+      if(d->postfix && d->postfix->len)
+	if(d->override & DENEMO_OVERRIDE_LILYPOND)
+	  g_string_prepend(ret, d->postfix->str);
+	else
+	  g_string_append(ret, d->postfix->str);
+    }
   }
 return g_string_free(ret, FALSE);
 }
@@ -725,11 +727,13 @@ static gchar *get_prefix(GList *g) {
   GString *ret = g_string_new("");
   for(;g;g=g->next) {
     DenemoDirective *d = g->data;
-    if(d->prefix && d->prefix->len)
-      if(d->override & DENEMO_OVERRIDE_LILYPOND)
-	g_string_prepend(ret, d->prefix->str);
-      else
-	g_string_append(ret, d->prefix->str);
+    if(!((d->override & DENEMO_OVERRIDE_HIDDEN))){
+      if(d->prefix && d->prefix->len)
+	if(d->override & DENEMO_OVERRIDE_LILYPOND)
+	  g_string_prepend(ret, d->prefix->str);
+	else
+	  g_string_append(ret, d->prefix->str);
+    }
   }
 return g_string_free(ret, FALSE);
 }
@@ -761,7 +765,9 @@ generate_lily_for_obj (DenemoGUI *gui, GtkTextIter *iter, gchar *invisibility, D
 		       gint * pcur_stime2)
 {
   GString *ret = g_string_new ("");
-#define outputret gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, iter, ret->str, -1, INEDITABLE, invisibility, NULL), g_string_assign(ret, "")
+#define outputret gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, iter, ret->str, -1, INEDITABLE, invisibility, NULL), \
+    open_braces +=  brace_count(ret->str), \
+    g_string_assign(ret, "")
 #define output(astring) (gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, iter, astring, -1, INEDITABLE, invisibility, NULL))
   gint prevduration = *pprevduration;
   gint prevnumdots = *pprevnumdots;
@@ -783,7 +789,7 @@ generate_lily_for_obj (DenemoGUI *gui, GtkTextIter *iter, gchar *invisibility, D
 
   GString *dynamic_string = NULL;
 
-  {
+
     gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, iter, " ", -1, INEDITABLE, HIGHLIGHT, invisibility, NULL);
 
     switch (curobj->type)
@@ -799,6 +805,7 @@ generate_lily_for_obj (DenemoGUI *gui, GtkTextIter *iter, gchar *invisibility, D
 	for(;g;g=g->next) {
 	  DenemoDirective *directive = (DenemoDirective *)g->data;
 	  if(directive->prefix && directive->prefix->len) {
+	    prevduration = -1;
 	    open_braces += brace_count(directive->prefix->str); 
 	    insert_editable(&directive->prefix, directive->prefix->str, iter, invisibility, gui);
 	  }
@@ -852,6 +859,7 @@ generate_lily_for_obj (DenemoGUI *gui, GtkTextIter *iter, gchar *invisibility, D
 		    for(;g;g=g->next) {
 		      DenemoDirective *directive = (DenemoDirective *)g->data;
 		      if(directive->prefix ) {
+			prevduration = -1;
 			insert_editable(&directive->prefix, directive->prefix->len?directive->prefix->str:" ", iter, invisibility, gui);
 		      }
 		    }
@@ -916,6 +924,7 @@ generate_lily_for_obj (DenemoGUI *gui, GtkTextIter *iter, gchar *invisibility, D
 		      DenemoDirective *directive = (DenemoDirective *)g->data;
 		      if(directive->postfix ) {
 			insert_editable(&directive->postfix, directive->postfix->len?directive->postfix->str:" ", iter, invisibility, gui);
+			prevduration = -1;
 		      }	else
 		      if (notenode->next)
 			output(" ");
@@ -1041,6 +1050,7 @@ generate_lily_for_obj (DenemoGUI *gui, GtkTextIter *iter, gchar *invisibility, D
 	for(;g;g=g->next) {
 	  DenemoDirective *directive = (DenemoDirective *)g->data;
 	  if(directive->postfix && directive->postfix->len) {
+	    prevduration = -1;
 	    open_braces += brace_count(directive->postfix->str);
 	    insert_editable(&directive->postfix, directive->postfix->str, iter, invisibility, gui);
 	  }
@@ -1191,7 +1201,7 @@ generate_lily_for_obj (DenemoGUI *gui, GtkTextIter *iter, gchar *invisibility, D
 
 
     outputret;
-  }//not a LilyPond directive
+
     *pprevduration = prevduration;
     *pprevnumdots = prevnumdots;
 
@@ -1267,8 +1277,11 @@ outputHeader (GString *str, DenemoGUI * gui)
 
   g_string_append_printf (str, "%s", "%%http://www.gnu.org/software/denemo/\n\n");
   /*Print out lilypond syntax version */
-  g_string_append_printf (str, "\\version \"%s\"\n", gui->lilycontrol.lilyversion->str/*LILYPOND_VERSION*/);
-
+  if(gui->lilycontrol.lilyversion->len)
+    g_string_append_printf (str, "\\version \"%s\"\n", gui->lilycontrol.lilyversion->str/*LILYPOND_VERSION*/);
+  else
+    g_string_append_printf (str, "\\version \"%s\"\n", get_lily_version_string());
+  
   /* print \paper block settings for excerpt */
   if (gui->lilycontrol.excerpt == TRUE){
     g_string_append_printf (str, "%s", "\\paper {printallheaders = ##f\n");
@@ -1329,7 +1342,7 @@ outputStaff (DenemoGUI *gui, DenemoScore * si, DenemoStaff * curstaffstruct,
   GList * lyrics = NULL;
   GString * figures = g_string_new("");
   GString * fakechords = g_string_new("");
-  prevduration = 0;
+  prevduration = -1;
   prevnumdots = -1;
   GtkTextIter iter;
   GtkTextMark *curmark;/* movable mark for insertion point of the music of the staff */
@@ -1482,9 +1495,12 @@ outputStaff (DenemoGUI *gui, DenemoScore * si, DenemoStaff * curstaffstruct,
 	    empty_measure=FALSE; 
 
 
+
  if(curobj->type==LILYDIRECTIVE){
 #define OUTPUT_LILY(what) \
-  if(((lilydirective *) curobj->object)->what && ((lilydirective *) curobj->object)->what->len) {\
+  if(((lilydirective *) curobj->object)->what && ((lilydirective *) curobj->object)->what->len\
+     && (!( ((lilydirective *) curobj->object)->override & DENEMO_OVERRIDE_HIDDEN)) \
+     ) {								\
 	  gtk_text_buffer_get_iter_at_mark (gui->textbuffer, &iter, curmark);\
 	  GtkTextChildAnchor *objanc = gtk_text_buffer_create_child_anchor (gui->textbuffer, &iter);\
 	  g_object_set_data(G_OBJECT(objanc), OBJECT, (gpointer)curobjnode);\
@@ -1540,7 +1556,7 @@ outputStaff (DenemoGUI *gui, DenemoScore * si, DenemoStaff * curstaffstruct,
 				 &prevduration, &prevnumdots, &clefname,
 				 &keyname,
 				 &cur_stime1, &cur_stime2);
-			   }
+ }// end not lilydirective
 
 
 
@@ -1548,9 +1564,13 @@ outputStaff (DenemoGUI *gui, DenemoScore * si, DenemoStaff * curstaffstruct,
 
 	  if( (curobjnode==NULL) || (curobjnode->next==NULL)) {	//at end of measure
 	    GString *endstr = g_string_new("");
-	    if (empty_measure)// measure has nothing to use up the duration, assume whole measure rest for primary voice, skip for secondaries.
+	    if (empty_measure)// measure has nothing to use up the duration, assume whole measure rest for primary voice, skip for secondaries.CHANGE to SKIP for all
 	      {
-		g_string_append_printf(endstr, " %c1*%d/%d ",(curstaffstruct->voicenumber == 1)?'R':'s', cur_stime1, cur_stime2);// either R1 or s1 for whole measure rest or skip
+
+		g_string_append_printf(endstr, " %c1*%d/%d ",(curstaffstruct->voicenumber == 1)?/*'R'*/'s':'s', cur_stime1, cur_stime2);// NOW s1 always (was either R1 or s1 for whole measure rest or skip)
+
+
+
 		gtk_text_buffer_get_iter_at_mark (gui->textbuffer, &iter, curmark);
 		gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter, endstr->str, -1,invisibility,NULL);
 		g_string_assign(endstr,"");
@@ -1975,7 +1995,10 @@ output_score_to_buffer (DenemoGUI *gui, gboolean all_movements, gchar * partname
     // containing the fixed stuff. for example:
     gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter, "#(set-default-paper-size \"", -1, INEDITABLE, NULL, NULL);
     insert_editable(&gui->lilycontrol.papersize, gui->lilycontrol.papersize->str, &iter, NULL, gui);
-    gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter, "\")\n", -1, INEDITABLE, NULL, NULL);
+    gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter, "\"\n", -1, INEDITABLE, NULL, NULL);
+    if(!gui->lilycontrol.orientation)
+      gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter, "'landscape", -1, INEDITABLE, NULL, NULL);
+    gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter, ")\n", -1, INEDITABLE, NULL, NULL);
     
     gtk_text_buffer_insert_with_tags_by_name (gui->textbuffer, &iter, "#(set-global-staff-size ", -1, INEDITABLE, NULL, NULL);
     insert_editable(&gui->lilycontrol.staffsize, gui->lilycontrol.staffsize->str, &iter, NULL, gui);
@@ -2106,12 +2129,16 @@ output_score_to_buffer (DenemoGUI *gui, gboolean all_movements, gchar * partname
 	  gchar *staff_prolog_insert =  get_prefix(curstaffstruct->staff_directives);
 	  gchar *staff_epilog_insert =  get_postfix(curstaffstruct->staff_directives);
 	  if(partname==NULL) {//when printing just one part, do not start/stop contexts
+	    gchar *staff_group_prolog_insert = "";//these are just to mark a place where a further directive type could be used to control staff groups
+	    gchar *staff_group_epilog_insert = "";
+
+
 	    if (curstaffstruct->context & DENEMO_CHOIR_START)
-	      g_string_append_printf(thestr, "\\new ChoirStaff %s << %s\n", staff_prolog_insert, staff_epilog_insert);
+	      g_string_append_printf(thestr, "\\new ChoirStaff %s << %s\n", staff_group_prolog_insert, staff_group_epilog_insert);
 	    if (curstaffstruct->context & DENEMO_GROUP_START)
-	      g_string_append_printf(thestr, "\\new StaffGroup %s << %s\n", staff_prolog_insert, staff_epilog_insert);
+	      g_string_append_printf(thestr, "\\new StaffGroup %s << %s\n", staff_group_prolog_insert, staff_group_epilog_insert);
 	    if (curstaffstruct->context & DENEMO_PIANO_START) /* Piano staff cannot start before Group */
-	      g_string_append_printf(thestr, "\\new PianoStaff %s << %s\n", staff_prolog_insert, staff_epilog_insert);
+	      g_string_append_printf(thestr, "\\new PianoStaff %s << %s\n", staff_group_prolog_insert, staff_group_epilog_insert);
 	  }
 	  if(curstaffstruct->voicenumber == 1) {
 	    if(!staff_override)
