@@ -55,11 +55,12 @@
 #include <time.h>
 #include <ctype.h>
 #include <errno.h>
-#include "smf.h"
 
-#include "instrumentname.h"
 #include <denemo/denemo.h>
-
+#include "exportmidi.h"
+#include "smf.h"
+#include "instrumentname.h"
+#include "device_manager.h"
 
 /* 
  * only for developers
@@ -337,44 +338,7 @@ midi_delta (FILE * fd, long delta, int more)
 
   return sz;
 }
-
-
-#if 0
-/**
- * this is used by several meta events
- */
-static smf_event_t *
-midi_meta_text (int metatype, char *string)
-{
-  int len;
-  smf_event_t *event = smf_event_new();
-  len = strlen (string);
-  if(len>255) {
-    g_warning("Truncating string %s\n", string);
-    len = 255;
-  }
-  gchar *buffer = (gchar*)malloc(len+3);
-  event->midi_buffer = buffer;
-  event->midi_buffer_length = len+3;
-  /* meta event */
-  *buffer++ =  0xff;
-
-  /* meta type */
-  *buffer++ =  metatype;
-
-  /* meta size */
-  *buffer++ = (char)len;
-
-  /* meta text */
-  strncpy(buffer, string, len);
-  *(buffer+len) = 0;
-  return event; 
-}
-
-#else
 #define midi_meta_text(a,b) smf_event_new_textual(a,b)
-#endif
-
 
 /**
  * put two strings and a number in a midi comment (debug)
@@ -951,7 +915,7 @@ static smf_event_t* put_event(gchar *buffer, gint numbytes, GList **midi_events,
 }
 
 static gint directive_get_midi_override(DenemoDirective *directive) {	
-  return directive->override&DENEMO_MIDI_MASK;
+  return (directive->override&DENEMO_OVERRIDE_HIDDEN) | (directive->override&DENEMO_MIDI_MASK);
 }
 static gint directive_get_midi_interpretation(DenemoDirective *directive) {	
   return directive->override&DENEMO_MIDI_INTERPRETATION_MASK;
@@ -964,7 +928,7 @@ gchar *substitute_midi_values(gchar* str, gint channel, gint volume) {
   gchar *c;
   for(c=bytes;*c;c++) {
     if(*c=='$')
-      *c = '0'+channel-1;
+      *c = '0'+channel;
     if(*c=='%' && *(c+1)=='%' && *(c+2)=='%')
       sprintf(c, "%3d", volume);//*c = itoa(volume);
   }
@@ -975,7 +939,7 @@ static gchar *directive_get_midi_buffer(DenemoDirective *directive, gint *pnumby
   if(directive->midibytes) {
     gchar *bytes;
     bytes = substitute_midi_values(directive->midibytes->str, channel, volume);
-    //g_print("Got %s as midi bytes\n", bytes);
+    g_print("Got %s as midi bytes\n", bytes);
     char *next;
     char val;
     gint i, numbytes;
@@ -1066,6 +1030,7 @@ change_channel(gint *channel, gint midi_val, gint  midi_interpretation,gint  mid
   }  
   if(*channel>127) *channel=127;
   if(*channel<0) *channel=0;
+  g_print("After channel change channel = %d\n", *channel);
 }
 
 
@@ -1225,68 +1190,6 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
       tracknumber++;
       smf_track_t *track = smf_track_new();
       smf_add_track(smf, track);
-      if(curstaffstruct->staff_directives) {
-	GList *g;
-	DenemoDirective *directive = NULL;
-	for(g=curstaffstruct->staff_directives;g;g=g->next){
-	  gint numbytes;
-	  directive = (DenemoDirective *)g->data;
-	  gint midi_override = directive_get_midi_override(directive);
-	  gchar *buffer = directive_get_midi_buffer(directive, &numbytes, midi_channel, cur_volume);
-	  if(midi_override)
-	    g_warning("No MIDI override values mean anything at Staff level");
-	      if(buffer) 
-		if(NULL==put_event(buffer, numbytes, &curstaffstruct->midi_events, track))
-		  g_warning("Invalid midi bytes in staff directive\n");
-	}
-      }
-
-      if(tracknumber==1) {
-	if (Denemo.gui->lilycontrol.directives) {
-	  //FIXME repeated code
-	  GList *g;
-	  DenemoDirective *directive = NULL;
-	  for(g=Denemo.gui->lilycontrol.directives;g;g=g->next){
-	    gint numbytes;
-	    directive = (DenemoDirective *)g->data;
-	    gint midi_override = directive_get_midi_override(directive);
-	    gchar *buffer = directive_get_midi_buffer(directive, &numbytes, midi_channel, cur_volume);
-	    if(midi_override)
-	      g_warning("No MIDI override values mean anything at Score level");
-	    if(buffer) 
-	      if(NULL==put_event(buffer, numbytes, &Denemo.gui->midi_events, track))
-		g_warning("Invalid midi bytes in score directive\n");
-	  }
-	}
-
-	if (Denemo.gui->si->movementcontrol.directives) {
-	  GList *g;
-	  DenemoDirective *directive = NULL;
-	  for(g=Denemo.gui->si->movementcontrol.directives;g;g=g->next){
-	    gint numbytes;
-	    directive = (DenemoDirective *)g->data;
-	    gint midi_override = directive_get_midi_override(directive);
-	    gchar *buffer = directive_get_midi_buffer(directive, &numbytes, midi_channel, cur_volume);
-	    if(midi_override)
-	      g_warning("No MIDI override values mean anything at Movement level");
-	    if(buffer) 
-	      if(NULL==put_event(buffer, numbytes, &Denemo.gui->si->midi_events, track))
-		g_warning("Invalid midi bytes in movement directive\n");
-	  }
-	}
-
-      }
-
-
-      if (!strcmp (curstaffstruct->midi_instrument->str, "drums"))
-	{
-	  midi_channel = 9;
-	}
-      else
-	{
-	  midi_channel = (tracknumber >= 9) ? tracknumber + 1 : tracknumber;
-	}
-
 
       /* track name */
       event = midi_meta_text (3, curstaffstruct->lily_name->str);
@@ -1296,26 +1199,16 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
       gint cur_tempo = si->tempo;
       event = midi_tempo (cur_tempo);
       smf_track_add_event_delta_pulses(track, event, 0);
+      
+      /* Midi Client/Port */
+      track->user_pointer = (DevicePort *) device_manager_get_DevicePort(curstaffstruct->device_port->str); 
 
       /* The midi instrument */
       event = midi_meta_text (4, curstaffstruct->midi_instrument->str);
       smf_track_add_event_delta_pulses(track, event, 0);
 
-      if (curstaffstruct->midi_prognum_override != TRUE){
-      /* drums is a special case, else try to match an instrument name */
-      	      if (midi_channel == 9)
-		{
-		  prognum = 0;
-		}
-	      else
-		{
-		  prognum = select_program (curstaffstruct->midi_instrument->str);
-		}
-      }
-      else{
-	      prognum = curstaffstruct->midi_prognum;
-	      midi_channel = curstaffstruct->midi_channel;
-      }
+      midi_channel = curstaffstruct->midi_channel;
+      prognum = curstaffstruct->midi_prognum;
 
       /* set selected midi program */
       g_print("Using channel %d prognum %d\n", midi_channel, prognum);
@@ -1341,12 +1234,67 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
       cur_volume = curstaffstruct->volume;
       /* mute output if set */
       mute_volume = curstaffstruct->mute_volume;
-      if(cur_volume==0 && mute_volume==TRUE) {
+      if(cur_volume==0 && mute_volume!=TRUE) {
 	g_warning("volume set to zero but not muted\nResetting volume\n");
 	cur_volume = 65;
       }
 	
 
+      //Now that we have the channel and volume we can interpret any score and staff-wide directives for midi
+      if(curstaffstruct->staff_directives) {
+	GList *g=curstaffstruct->staff_directives;
+	DenemoDirective *directive = NULL;	
+	  for(;g;g=g->next){
+	    gint numbytes;
+	    directive = (DenemoDirective *)g->data;
+	    gint midi_override = directive_get_midi_override(directive);
+	    gchar *buffer = directive_get_midi_buffer(directive, &numbytes, midi_channel, cur_volume);
+	    if(!(midi_override&DENEMO_OVERRIDE_HIDDEN))
+	      if(buffer) 
+		if(NULL==put_event(buffer, numbytes, &curstaffstruct->midi_events, track))
+		  g_warning("Invalid midi bytes in staff directive\n");
+	  }
+      }
+      
+      if(tracknumber==1) {
+	if (Denemo.gui->lilycontrol.directives) {
+	  //FIXME repeated code
+	  GList *g=Denemo.gui->lilycontrol.directives;
+	  DenemoDirective *directive = NULL;
+
+	  for(;g;g=g->next){
+	    gint numbytes;
+	    directive = (DenemoDirective *)g->data;
+	    gint midi_override = directive_get_midi_override(directive);
+	    gchar *buffer = directive_get_midi_buffer(directive, &numbytes, midi_channel, cur_volume);
+	    if(!(midi_override&DENEMO_OVERRIDE_HIDDEN))
+	    if(buffer) 
+	      if(NULL==put_event(buffer, numbytes, &Denemo.gui->midi_events, track))
+		g_warning("Invalid midi bytes in score directive\n");
+	  }
+	}
+
+	if (Denemo.gui->si->movementcontrol.directives) {
+	  GList *g=Denemo.gui->si->movementcontrol.directives;
+	  DenemoDirective *directive = NULL;
+	  for(;g;g=g->next){
+	    gint numbytes;
+	    directive = (DenemoDirective *)g->data;
+	    gint midi_override = directive_get_midi_override(directive);
+	    gchar *buffer = directive_get_midi_buffer(directive, &numbytes, midi_channel, cur_volume);
+	    if(!(midi_override&DENEMO_OVERRIDE_HIDDEN))
+	    if(buffer) 
+	      if(NULL==put_event(buffer, numbytes, &Denemo.gui->si->midi_events, track))
+		g_warning("Invalid midi bytes in movement directive\n");
+	  }
+	}
+
+      }
+
+
+
+
+
       /* reset measure */
       curmeasurenum = 0;
       curmeasure = curstaffstruct->measures;
@@ -1411,9 +1359,9 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			     fmt_ticks (ticks_read));
 		  chordval = *(chord *) curobj->object;
 		  if(chordval.directives) {
-		        GList *g;
+		        GList *g=chordval.directives;
 			DenemoDirective *directive = NULL;
-			for(g=chordval.directives;g;g=g->next){
+			for(;g;g=g->next){
 			  gint numbytes;
 			  directive = (DenemoDirective *)g->data;
 			  gchar *buffer = directive_get_midi_buffer(directive, &numbytes, midi_channel, cur_volume);
@@ -1440,6 +1388,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			      break;
 			      //etc			      
 			    default:
+			      if(!(midi_override&DENEMO_OVERRIDE_HIDDEN))
 			      if(buffer) 
 				if(NULL==put_event(buffer, numbytes, &curobj->midi_events, track))
 				  g_warning("Invalid midi bytes in chord directive\n");
@@ -1816,7 +1765,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		  break;
 
 		case LILYDIRECTIVE:
-		  {
+		  if(!(((DenemoDirective *)curobj->object)->override & DENEMO_OVERRIDE_HIDDEN)) {
 		    gint numbytes;
 		    gchar *buffer = directive_get_midi_buffer(curobj->object, &numbytes, midi_channel, cur_volume);
 		    gint midi_override = directive_get_midi_override(curobj->object);
@@ -1843,6 +1792,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			g_warning("Not implemented");
 			break;
 		      default:
+			if(!(midi_override&DENEMO_OVERRIDE_HIDDEN))
 			if(buffer) {
 			  if(NULL==put_event(buffer, numbytes,  &curobj->midi_events, track))
 			    g_warning("Directive has invalid MIDI bytes\n");
@@ -1861,7 +1811,11 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
        * Do some checking
        *******************/
 
+	    
 	  measurewidth = bars2ticks (1, timesigupper, timesiglower);
+
+	  if(curmeasure->data == NULL)//An empty measure - treat as whole measure silence
+	    ticks_read = ticks_at_bar + measurewidth;
 	  if (ticks_at_bar + measurewidth != ticks_read)
 	    {
 	      if ((!measure_is_empty) && curmeasure->next)
@@ -1925,11 +1879,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
   }
   /* we are done */
 
-  if(si->smf) {
-    smf_t *temp = si->smf;
-    si->smf = NULL;
-    smf_delete(temp);
-  }
+
+  free_midi_data(si);
   si->smf = smf;
 
   si->smfsync = si->changecount;
@@ -1939,6 +1890,15 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
   return smf_get_length_seconds(smf);
 }
 
+void free_midi_data(DenemoScore *si) {
+  if(si->smf) {
+    smf_t *temp = si->smf;
+    si->smf = NULL;
+    smf_delete(temp);
+  }
+}
+
+
 /*
  * That's all, folks!
  *
