@@ -308,6 +308,17 @@ newDirectivesElem(xmlNodePtr objElem, xmlNsPtr ns, GList *g, gchar *type) {
   //GList *g = ((chord *) curObj->object)->directives;
   for(;g;g=g->next) {
     DenemoDirective *directive = (DenemoDirective *)g->data;
+
+/*      hhmmmm the set_action_script_for_tag is not modifying the directive - just associating a script with the tag. It is when we try to invoke the directive that we find there is an action script */
+/* We Decline to store any directive that has a tag for which an action script is defined in this run of denemo 
+*  this implies people need to be careful in the tags they use for action scripts*/
+
+/*      We have some serious thought needed here!!!!!!!!!!!!!!!!!!!!!!!! */
+/* could be */
+    if(directive->tag && get_action_script (directive->tag->str))
+       continue;
+
+
      xmlNodePtr directiveElem =  xmlNewChild (directivesElem, ns, (xmlChar *) "directive", NULL);
 #define DO_DIREC(field)  if (directive->field \
                    && directive->field->len)\
@@ -696,10 +707,14 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 			  curStaffStruct->transposition);
 	  xmlNewChild (curElem, ns, (xmlChar *) "instrument",
 		       (xmlChar *) curStaffStruct->midi_instrument->str);
+
+	  //FIXME this is only being done for staffs not voices is that good????
+	  if(curStaffStruct->device_port->len)
+	    xmlNewChild (curElem, ns, (xmlChar *) "device-port",
+			 (xmlChar *) curStaffStruct->device_port->str);
+
 	   newXMLIntChild (curElem, ns, (xmlChar *) "volume",
 			   			  curStaffStruct->volume);
-	  newXMLIntChild (curElem, ns, (xmlChar *) "midi_prognum_override",
-	               curStaffStruct->midi_prognum_override);
 	  newXMLIntChild (curElem, ns, (xmlChar *) "midi_prognum",
 	               curStaffStruct->midi_prognum);
 	  newXMLIntChild (curElem, ns, (xmlChar *) "midi_channel",
@@ -714,10 +729,10 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
           PUTCHILD(DENEMO_GROUP_START, GROUP_START_STRING);
           PUTCHILD(DENEMO_GROUP_END, GROUP_END_STRING);
 #undef PUTCHILD
-	  newXMLIntChild (curElem, ns, (xmlChar *) "space_above",
-			  curStaffStruct->space_above);
-	  newXMLIntChild (curElem, ns, (xmlChar *) "space_below",
-			  curStaffStruct->space_below);
+	  //  newXMLIntChild (curElem, ns, (xmlChar *) "space_above",
+	  //		  curStaffStruct->space_above);
+	  // newXMLIntChild (curElem, ns, (xmlChar *) "space_below",
+	  //		  curStaffStruct->space_below);
 	  newXMLIntChild (curElem, ns, (xmlChar *) "hasfigures",
 			  curStaffStruct->hasfigures);
 
@@ -857,17 +872,18 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 		    {
 		      objElem = xmlNewChild (measureElem, ns,
 					     (xmlChar *) "rest", NULL);
-		      if (curObj->isinvisible)
-			xmlSetProp (objElem, (xmlChar *) "show", (xmlChar *)
-				    "false");
-		      else
-			xmlSetProp (objElem, (xmlChar *) "show",
-				    (xmlChar *) "true");
+
 		    }
 		  else
 		    objElem =
 		      xmlNewChild (measureElem, ns, (xmlChar *) "chord",
 				   NULL);
+		  if (curObj->isinvisible)
+		    xmlSetProp (objElem, (xmlChar *) "show", (xmlChar *)
+				"false");
+		  else
+		    xmlSetProp (objElem, (xmlChar *) "show",
+				(xmlChar *) "true");
 		  chordXMLID = getXMLID (curObj);
 		  xmlSetProp (objElem, (xmlChar *) "id",
 			      (xmlChar *) chordXMLID);
