@@ -55,12 +55,11 @@ typedef struct notetype
 typedef struct nstack 
 {
 	GList *chordnotes; /* list of notes that go along with that object */
-	gint *pitch;	/* base pitch or lowest pitch possibly redundant because of chordnotes */
-     	gint *timeon;  /* tick number when the note starts*/
-	gint *on_delta_time; /* Is this NEEDED? this is time between last event and this notes start */
-     	gint *duration; /* length of time in ticks */ 
-	gint *tracknum;	
-	gint *voicenum;
+	gint pitch;	/* base pitch or lowest pitch possibly redundant because of chordnotes */
+     	gint timeon;  /* tick number when the note starts*/
+	gint on_delta_time; /* Is this NEEDED? this is time between last event and this notes start */
+     	gint duration; /* length of time in ticks */ 
+	gint tracknum;	
 }nstack;
 
 typedef struct midicallback
@@ -76,7 +75,6 @@ typedef struct midicallback
 	gint event_number; /* smf event number that is currently being processed */
 	gint key;   /* current key sig */
 	gint track; /* the current track that is being read */
-	gint current_voicenum;
 	smf_t *smf;
 	smf_track_t *selected_track;
 }midicallback;
@@ -94,7 +92,7 @@ void dokeysig(gint key, gint isminor, midicallback *mididata);
 void dotempo(gint tempo,  midicallback *mididata);
 void dotrackname(gchar *name, midicallback *mididata);
 void doinstrname(gchar *name, midicallback *mididata);
-void donoteon(midicallback *mididata, gint *pitchon, gint *velocity, gint *timeon);
+void donoteon(midicallback *mididata, gint pitchon, gint velocity, gint timeon);
 void donoteoff(midicallback *mididata);
 struct notetype ConvertLength(gint duration, midicallback *mididata);
 void ProcessNoteStack(midicallback *mididata);
@@ -335,8 +333,7 @@ decode_midi_event(const smf_event_t *event, midicallback *mididata)
 					channel, note, event->midi_buffer[2]);
 			mididata->delta_time = event->delta_time_pulses;
 			mididata->event_number = event->event_number;
-			donoteon(mididata,  (gint *)event->midi_buffer[1],  (gint *)event->midi_buffer[2], (gint *)
-					event->time_pulses);
+			donoteon(mididata,  event->midi_buffer[1],  event->midi_buffer[2], event->time_pulses);
 			break;
 
 		case AFTERTOUCH:
@@ -494,7 +491,7 @@ doinstrname (gchar* name,  midicallback *mididata)
 }
 
 static nstack *
-stack (gint *pitch, gint *timeon, gint *delta_time, gint *duration, gint *tracknum, gint *voicenum)
+stack (gint pitch, gint timeon, gint delta_time, gint duration, gint tracknum)
 {
   nstack *mystack = (nstack *)g_malloc0(sizeof(nstack));
   mystack->pitch = pitch;
@@ -502,7 +499,6 @@ stack (gint *pitch, gint *timeon, gint *delta_time, gint *duration, gint *trackn
   mystack->on_delta_time = delta_time;
   mystack->duration = duration;
   mystack->tracknum = tracknum;
-  mystack->voicenum = voicenum;
   return mystack;
 }
 
@@ -510,7 +506,7 @@ stack (gint *pitch, gint *timeon, gint *delta_time, gint *duration, gint *trackn
  * Process note on command 
  */
 void
-donoteon (midicallback *mididata, gint *pitchon, gint *velocity, gint *timeon)
+donoteon (midicallback *mididata, gint pitchon, gint velocity, gint timeon)
 {
   gint delta_time = mididata->delta_time; /*is this needed????*/
   
@@ -537,23 +533,21 @@ donoteoff (midicallback *mididata)
 }
 
 gboolean
-ChordToneCheck(midicallback *mididata, gint *pitch, gint *timeon, gint *delta_time, gint *duration){
+ChordToneCheck(midicallback *mididata, gint pitch, gint timeon, gint delta_time, gint duration){
   nstack *currentnote = mididata->currentnote;	
   gint tracknum = (int) mididata->track;
-  gint voicenum = (int) mididata->current_voicenum;
 
   if ((currentnote->timeon == timeon) &&
      (currentnote->duration == duration)){
 	  g_print("\n***Same Duration and timeon***\n");
   	  /* append note to GList */
-	  currentnote->chordnotes = g_list_append(currentnote->chordnotes, pitch);
+	  currentnote->chordnotes = g_list_append(currentnote->chordnotes, (gpointer)pitch);
 	  return TRUE;
   }
   else if ((currentnote->timeon <= timeon) && (timeon <= ((int) currentnote->timeon + (int) currentnote->duration))){
-	  voicenum++;
-	g_print("\n***NOTE_ON colliding between a NOTE_ON and NOTE_OFF tracknum = %d voicenum = %d***\n",tracknum, voicenum);	
+	g_print("\n***NOTE_ON colliding between a NOTE_ON and NOTE_OFF tracknum = %d***\n",tracknum);	
   	/* append to voice glist */
-	nstack *noteon = stack(pitch, timeon, delta_time, duration, (gint *) tracknum,  (gint *) mididata->current_voicenum);
+	nstack *noteon = stack(pitch, timeon, delta_time, duration, tracknum);
       	/* store noteon in mididata->notestack */
 	mididata->notestack = g_list_append(mididata->notestack, noteon);
 	return FALSE;
@@ -562,25 +556,24 @@ ChordToneCheck(midicallback *mididata, gint *pitch, gint *timeon, gint *delta_ti
 }
 
 gint
-Get_Smf_Note_OFF (gint *pitch, gint *timeon, gint *delta_time, midicallback *mididata){
+Get_Smf_Note_OFF (gint pitch, gint timeon, gint delta_time, midicallback *mididata){
   gint event_number = mididata->event_number;
   smf_event_t *event;
   gint duration;
   gint tracknum = mididata->track;
   gboolean chordtone = FALSE;
-  mididata->current_voicenum = 1;
 
   while ((event = smf_track_get_event_by_number(mididata->selected_track, event_number)) != NULL){
     if (((event->midi_buffer[0] & SYS_EXCLUSIVE_MESSAGE1) == NOTE_OFF) 
 		    & (event->midi_buffer[1] == (int) pitch)){
-	duration = event->time_pulses - (int) timeon; 
+	duration = event->time_pulses - timeon; 
 	if (mididata->currentnote != NULL) 
-	   chordtone = ChordToneCheck(mididata, pitch, timeon, delta_time, (int *) duration);
+	   chordtone = ChordToneCheck(mididata, pitch, timeon, delta_time, duration);
 	if (!chordtone){
       	  /* store note in mididata->currentnote */
-	  mididata->currentnote = stack(pitch, timeon, delta_time, (int *) duration, (int *) tracknum, (int *) mididata->current_voicenum);
+	  mididata->currentnote = stack(pitch, timeon, delta_time, duration, tracknum);
 	}
-	g_print("\nFound corresponding note off to pitch %d timeon = %d duration = %d\n", (gint) pitch, (gint) timeon, (gint) duration);
+	g_print("\nFound corresponding note off to pitch %d timeon = %d duration = %d\n", (gint) pitch, timeon, (gint) duration);
     	break;
     }
     event_number++;
@@ -729,12 +722,9 @@ notetype ConvertLength(gint duration, midicallback *mididata){
 void StaffCheck(midicallback *mididata){
   DenemoScore *si = mididata->gui->si;
   gint track = (int) mididata->currentnote->tracknum;
-  gint voicenum = (int) mididata->currentnote->voicenum;
   gint currentstaffnum = si->currentstaffnum;
-  gint currentvoicenum = mididata->current_voicenum; 
 
-  g_print("\nmididata->currentnote->voicenum = %d  mididata->current_voicenum = %d\n", voicenum, (gint) mididata->current_voicenum);
-  if ((track > currentstaffnum) || (voicenum > currentvoicenum)) /*if not first track add track */
+  if (track > currentstaffnum) /*if not first track add track */
     {
       si->currentstaffnum++;
       si->currentstaff = g_list_first (si->thescore); /* set the first track to be copied */
@@ -744,10 +734,6 @@ void StaffCheck(midicallback *mididata){
       si->cursor_x = 0;
       mididata->bartime = 0;
       si->currentmeasurenum = 1;
-      /*need to increment voicenum and tracknum to commpensate */
-      //mididata->currentnote->tracknum++;
-      if  (voicenum > currentvoicenum)
-        mididata->current_voicenum++;
     }
 }
 
@@ -820,7 +806,7 @@ void TiedNoteCheck(midicallback *mididata){
 	{
 	  	mididata->leftover = (int) (duration - (barlength - mididata->bartime));	/*tied over bar line */
 	  	duration = (int) (barlength - mididata->bartime); /*new value that fits in bar*/
-		mididata->currentnote->duration = (int *) duration; 
+		mididata->currentnote->duration = duration; 
 	}
       	else 
 		mididata->leftover = (int) 0;
@@ -852,7 +838,7 @@ void ProcessNote(midicallback *mididata) {
 	/* if the starttime of noteon is not were we left off we need to do something */
 	if ((starttime != mididata->lastoff) && (mididata->leftover !=0)){
 		mididata->leftover = 0;
-		mididata->currentnote->timeon = (int *) mididata->lastoff;
+		mididata->currentnote->timeon = mididata->lastoff;
 		process_list(mididata);
 	}
 }
@@ -862,7 +848,6 @@ ProcessNoteStack(midicallback *mididata){
   	while (mididata->notestack){
 		/* Assign the note to currentnote */
 		mididata->currentnote = mididata->notestack->data; 
-		//mididata->current_voicenum++; //???? can I do this to pointer???
 		/* send the note on for processing */
 		process_list(mididata);
 		/* remove note from list */
@@ -908,7 +893,6 @@ importMidi (gchar *filename, DenemoGUI *gui)
   /* Read Track Data */ 
   readtrack(mididata);
 
-  //g_free(mididata);
-  g_free(filename);
+  g_free(mididata);
   return ret;
 }
