@@ -869,6 +869,21 @@ parseBaseChord (xmlNodePtr chordElem, xmlNsPtr ns, DenemoScore * si)
   gchar *durationType;
   gint baseDuration = 2, numDots = 0;
 
+  gchar *showProp = (gchar *) xmlGetProp (chordElem, (xmlChar *) "show");
+  gboolean show = TRUE;
+  if (showProp != NULL)
+    {
+      if (strcmp (showProp, "true") == 0)
+	show = TRUE;
+      else if (strcmp (showProp, "false") == 0)
+	show = FALSE;
+      else
+	{
+	  g_warning ("Invalid value for show attribute of <rest> or <chord>: \"%s\"; "
+		     "defaulting to false", showProp);
+	  show = FALSE;
+	}
+    }
   /*
    * First, in order to actually create a chord object, we must figure out the
    * Denemo duration and number of dots from the XML duration.
@@ -929,7 +944,7 @@ parseBaseChord (xmlNodePtr chordElem, xmlNsPtr ns, DenemoScore * si)
       numDots = 0;
     }
 
-  return newchord (baseDuration, numDots, 0);
+  return show?newchord (baseDuration, numDots, 0):hidechord(newchord (baseDuration, numDots, 0));
 }
 
 
@@ -941,25 +956,9 @@ parseRest (xmlNodePtr restElem, xmlNsPtr ns, DenemoScore * si)
 {
   DenemoObject *chordObj;
   xmlNodePtr childElem;
-  gchar *showProp = (gchar *) xmlGetProp (restElem, (xmlChar *) "show");
-  gboolean show = TRUE;
-  if (showProp != NULL)
-    {
-      if (strcmp (showProp, "true") == 0)
-	show = TRUE;
-      else if (strcmp (showProp, "false") == 0)
-	show = FALSE;
-      else
-	{
-	  g_warning ("Invalid value for show attribute of <rest>: \"%s\"; "
-		     "defaulting to false", showProp);
-	  show = FALSE;
-	}
-    }
-  if (show)
-    chordObj = parseBaseChord (restElem, ns, si);
-  else
-    chordObj = hidechord (parseBaseChord (restElem, ns, si));
+
+  chordObj = parseBaseChord (restElem, ns, si);
+
   FOREACH_CHILD_ELEM (childElem, restElem)  {
     if (childElem->ns == ns) {
       if (ELEM_NAME_EQ (childElem, "directives"))  {
@@ -1497,7 +1496,8 @@ parseLilyDir (xmlNodePtr LilyDirectiveElem, xmlNsPtr ns, DenemoScore *si)
   GET_INT_FIELD(gy);
   GET_INT_FIELD(override);
   GET_INT_FIELD(minpixels);
-  curobj->minpixelsalloted = thedirective->minpixels;
+  // curobj->minpixelsalloted = thedirective->minpixels?thedirective->minpixels:16;//FIXME setpixelmin
+  setpixelmin(curobj);
   return curobj;
 }
 
@@ -1640,14 +1640,14 @@ parseSetupInfo (xmlNodePtr editInfoElem, xmlNsPtr ns, DenemoGUI * gui)
 	    tmp = (gchar *) xmlNodeListGetString (childElem->doc,
 						  childElem->
 						  xmlChildrenNode, 1);
-	    if (tmp != NULL)
+	    if (tmp != NULL && strcmp(tmp, "2.8.7"))//2.8.7 is ignored, it was the value used when version was mandated, but did not mean anything.
 	      {
 		//g_print ("lilypond version %s", tmp);
 		//g_string_assign (gui->lilycontrol.lilyversion, tmp);
 		if(strcmp(tmp, LILYPOND_VERSION))
-		   warningdialog("This file may contain embedded LilyPond from an earlier LilyPond version\nIf you have problems printing from it\nrefresh the directives responsible.");
+		   g_warning("This file may contain embedded LilyPond from an earlier LilyPond version\nIf you have problems printing from it\nrefresh the directives responsible.");
 		g_free (tmp);
-	      }
+	      } else g_warning("ignoring version %s", tmp);
 	  }
 	if (ELEM_NAME_EQ (childElem, "lilypond"))//backward compatibility only
 	  {
@@ -1950,7 +1950,7 @@ parseStaff (xmlNodePtr staffElem, xmlNsPtr ns, DenemoScore * si)
   	  }	    
         else if (ELEM_NAME_EQ (childElem, "midi_prognum_override"))
 	  {
-  	    curStaff->midi_prognum_override = getXMLIntChild (childElem);
+	    /*obsolete*/;
   	  }	    
   	else if (ELEM_NAME_EQ (childElem, "midi_prognum"))
 	  {
@@ -1963,14 +1963,14 @@ parseStaff (xmlNodePtr staffElem, xmlNsPtr ns, DenemoScore * si)
 	else if (ELEM_NAME_EQ (childElem, "transpose"))
 	  {
 	    curStaff->transposition = getXMLIntChild (childElem);
-	  }
+	  }	
 	else if (ELEM_NAME_EQ (childElem, "space_above"))
-	  {
-	    curStaff->space_above = getXMLIntChild (childElem);
+	  {//  set dynamically now
+	    //   curStaff->space_above = getXMLIntChild (childElem);
 	  }
 	else if (ELEM_NAME_EQ (childElem, "space_below"))
-	  {
-	    curStaff->space_below = getXMLIntChild (childElem);
+	  {//  set dynamically now
+	    //    curStaff->space_below = getXMLIntChild (childElem);
 	  }
 	else if (ELEM_NAME_EQ (childElem, "hasfigures"))
 	  {
@@ -1997,9 +1997,26 @@ parseStaff (xmlNodePtr staffElem, xmlNsPtr ns, DenemoScore * si)
 	  {
 	    gchar *temp = (gchar *) xmlNodeListGetString
 	      (childElem->doc, childElem->xmlChildrenNode, 1);
-	    g_string_assign (curStaff->midi_instrument, temp);
+	    if(temp)
+	      g_string_assign (curStaff->midi_instrument, temp);
+	    else
+	      curStaff->midi_instrument = g_string_new("");
 	    g_free (temp);
 	  }
+
+	else if (ELEM_NAME_EQ (childElem, "device-port"))
+	  {
+	    gchar *temp = (gchar *) xmlNodeListGetString
+	      (childElem->doc, childElem->xmlChildrenNode, 1);
+	    if(temp)
+	      g_string_assign (curStaff->device_port, temp);
+	    else
+	      curStaff->device_port = g_string_new("");
+	    g_free (temp);
+	  }
+
+
+
 	else if (ELEM_NAME_EQ (childElem, "context"))
 	  {
 	    gchar *temp = NULL;
@@ -2783,7 +2800,7 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
       }
       break;
     case REPLACE_SCORE:
-      free_gui(gui);
+      free_movements(gui);
       deleteSchemeText();
       /* this is dependent on the order of elements, which is not strictly correct */
       FOREACH_CHILD_ELEM(childElem, rootElem){
