@@ -89,11 +89,12 @@ typedef struct _DenemoImportXMLNSHandler
 } DenemoImportXMLNSHandler;
 
 
+
 /*
  * Import the given file in Denemo's "native" XML file format into the given
  * score.  Return TRUE if the file was imported successfully, FALSE otherwise.
  */
-gboolean importXML (gchar * filename, DenemoScore *si);
+gboolean importXML (gchar * filename, DenemoGUI *gui, ImportType type);
 
 void registerImportXMLNSHandler (DenemoImportXMLNSHandler * handler);
 
