@@ -25,12 +25,14 @@ static GdkEventKey ** divert_key_event;/* Non null if key events are being inter
 					* in which case the kyval, state pair are returned
 					*/
 
+static gint divert_key_id=0;
 gboolean intercept_scorearea_keypress (GdkEventKey *pevent) {
   if(divert_key_event) {
     warningdialog("Recursive key capture not possible!");/* we could make a stack of them instead ... */
     return FALSE;
   }
   GdkEventKey *event;
+  divert_key_id = Denemo.gui->id;
   divert_key_event = &event;
   gtk_main();
   divert_key_event = NULL;
@@ -104,7 +106,7 @@ scorearea_keypress_event (GtkWidget * widget, GdkEventKey * event)
 {
   DenemoGUI *gui = Denemo.gui;
   keymap *the_keymap = Denemo.map;
-  if(divert_key_event && !isModifier(event)) {
+  if(divert_key_event && !isModifier(event) && divert_key_id==Denemo.gui->id) {
     *divert_key_event = event;
     //g_object_ref(event); FIXME do we need to keep it around?
     gtk_main_quit();
@@ -424,6 +426,23 @@ insert_chord_6key (DenemoGUI * gui)
     dnm_insertchord (gui, 6, gui->mode, FALSE);
 }
 
+void
+insert_chord_7key (DenemoGUI * gui)
+{
+
+    dnm_insertchord (gui, 7, gui->mode, FALSE);
+}
+
+void
+insert_chord_8key (DenemoGUI * gui)
+{
+
+    dnm_insertchord (gui, 8, gui->mode, FALSE);
+}
+
+
+
+
 void
 insert_rest_0key (DenemoGUI * gui)
 {
@@ -467,6 +486,19 @@ insert_rest_6key (DenemoGUI * gui)
   dnm_insertchord (gui, 6, INPUTREST, TRUE);
 }
 
+void
+insert_rest_7key (DenemoGUI * gui)
+{
+  dnm_insertchord (gui, 7, INPUTREST, TRUE);
+}
+
+void
+insert_rest_8key (DenemoGUI * gui)
+{
+  dnm_insertchord (gui, 8, INPUTREST, TRUE);
+}
+
+
 
 void
 insert_blankchord_0key (DenemoGUI * gui)
@@ -522,6 +554,21 @@ insert_blankchord_6key (DenemoGUI * gui)
 
 }
 
+void
+insert_blankchord_7key (DenemoGUI * gui)
+{
+
+  dnm_insertchord (gui, 7, INPUTBLANK, FALSE);
+
+}
+
+void
+insert_blankchord_8key (DenemoGUI * gui)
+{
+
+  dnm_insertchord (gui, 8, INPUTBLANK, FALSE);
+
+}
 
 
 void
