@@ -38,7 +38,9 @@ static void action_script_table_insert(gchar *name, gchar *script) {
 void set_action_script_for_tag(gchar *tag, gchar *script) {
   action_script_table_insert(tag, script);
 }
-static  gchar *get_action_script(gchar *name) {
+
+
+gchar *get_action_script(gchar *name) {
   if(action_scripts)
     return (gchar *)g_hash_table_lookup(action_scripts, name);
   return NULL;
@@ -290,12 +292,12 @@ void insert_lily_directive(gchar *postfix, gchar *display, gboolean locked, gint
   gboolean is_new = FALSE;
     if (curObj && curObj->type == LILYDIRECTIVE) {
       g_string_assign((lilyobj=(lilydirective *) curObj->object)->postfix, postfix);
-      curObj->minpixelsalloted = minpixels;
+      setpixelmin(curObj);//curObj->minpixelsalloted = minpixels;
     }  else {  
       lily = lily_directive_new (postfix);
       is_new= TRUE;
       lilyobj = (lilydirective *) lily->object;
-      lily->minpixelsalloted = minpixels;// g_print("min pixels %d\n", lily->minpixelsalloted);
+      setpixelmin(lily);//lily->minpixelsalloted = minpixels;// g_print("min pixels %d\n", lily->minpixelsalloted);
     }
     if(lilyobj) {
       lilyobj->locked = locked;
@@ -1117,9 +1119,21 @@ gchar *basename = g_strconcat(tag, ".scm", NULL);
 }
 
 
+/*
+instead of the "activate"  "button-release-event" signal
 
+gboolean            user_function                      (GtkWidget      *widget,
+                                                        GdkEventButton *event,
+                                                        gpointer        user_data)      : Run Last
+the look at event to see if left or right button pressed
+and allow advanced edit if right button.
+
+*/
+static gboolean
+text_edit_directive_by_fn(DenemoDirective *directive, gpointer fn);
 static void
-button_callback (GtkWidget *w, DenemoDirective *directive){
+button_callback  (GtkWidget *w, GdkEventButton *event, DenemoDirective *directive) {
+  gboolean left = (event->button != 3);                  
   if(directive->override&DENEMO_OVERRIDE_EDITOR)
     {
       GtkWidget *texteditor = (GtkWidget*)g_object_get_data(G_OBJECT(directive->widget), DENEMO_TEXTEDITOR_TAG);
@@ -1129,20 +1143,39 @@ button_callback (GtkWidget *w, DenemoDirective *directive){
 	gtk_window_present(GTK_WINDOW(gtk_widget_get_toplevel(texteditor)));
       }
     } else {
-      gchar *script = get_action_script(directive->tag->str);
-      if(script)
-	call_out_to_guile(script);
-      else {
+    gchar *script = get_action_script(directive->tag->str);
+    if(script)
+      call_out_to_guile(script);
+    else {
+      if(left)
 	script = get_editscript_filename(directive->tag->str);
-	if(script)
-	  execute_script_file(script);
-	else {
+      else
+	script = NULL;
+      if(script)
+	execute_script_file(script);
+      else {
+	/* if there is an action of this tag with scheme script, run it again
+	   else do text edit of the directives fields
+
+	*/
+	GtkAction *action;
+	if(left && ((action = lookup_action_from_name((gchar *)directive->tag->str))!=NULL))
+	  gtk_action_activate(action); else {
 	  gpointer fn = g_object_get_data(G_OBJECT(w), "fn");
-	  if(fn)
-	    edit_directive_callback(w, fn);
+	  if(fn) {
+	    gboolean delete = !text_edit_directive_by_fn(directive, fn);
+	    if(delete) {
+	      GList *directives = (GList*)g_object_get_data(w, "directives-pointer");
+	      if(directives)
+		delete_directive(directives, directive->tag->str);
+	      else
+		g_warning("Could not get directives list to delete from");
+	    }
+	  }
 	}
       }
     }
+  }
 }
 
 /* return a GtkTextView which has been installed inside a scrolled window */
@@ -1165,7 +1198,8 @@ static GtkWidget * create_text_window(void) {
   return textview;
 }
 
-static assign_text(GtkWidget *w, gchar *text) {
+static void
+assign_text(GtkWidget *w, gchar *text) {
   GtkTextBuffer *textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(w));
   if(textbuffer)
     gtk_text_buffer_set_text(textbuffer, text, -1);
@@ -1285,7 +1319,7 @@ widget_for_directive(DenemoDirective *directive,  void fn()) {
       menu = (GtkWidget *)((DenemoStaff*)Denemo.gui->si->currentstaff->data)->staffmenu;
       directive->widget = gtk_menu_item_new_with_label(value);
       attach_textedit_widget(directive);
-      g_signal_connect(G_OBJECT(directive->widget), "activate",  G_CALLBACK(button_callback), directive);
+      g_signal_connect(G_OBJECT(directive->widget), "button-release-event",  G_CALLBACK(button_callback), directive);
       gtk_menu_shell_prepend(GTK_MENU_SHELL(menu), GTK_WIDGET(directive->widget));
     } else    
       if(fn==(void(*)())voice_directive_put_graphic) {
@@ -1294,7 +1328,7 @@ widget_for_directive(DenemoDirective *directive,  void fn()) {
 	attach_textedit_widget(directive);
 	GtkWidget *menu;
 	menu = (GtkWidget *)((DenemoStaff*)Denemo.gui->si->currentstaff->data)->voicemenu;  
-	g_signal_connect(G_OBJECT(directive->widget), "activate",  G_CALLBACK(button_callback), fn);
+	g_signal_connect(G_OBJECT(directive->widget), "button-release-event",  G_CALLBACK(button_callback), directive);
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu), GTK_WIDGET(directive->widget));
       }  else 
 	if(box)  {
@@ -1305,7 +1339,7 @@ widget_for_directive(DenemoDirective *directive,  void fn()) {
 	    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	  }
 	  attach_textedit_widget(directive);
-	  g_signal_connect(G_OBJECT(directive->widget), "clicked",  G_CALLBACK(button_callback), directive);
+	  g_signal_connect(G_OBJECT(directive->widget), "button-release-event",  G_CALLBACK(button_callback), directive);
 	  if(box){
 	    gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET(directive->widget), FALSE, TRUE,0);
 	    gtk_widget_show(box);
@@ -1313,7 +1347,7 @@ widget_for_directive(DenemoDirective *directive,  void fn()) {
 	} else {
 	  directive->widget = gtk_menu_item_new_with_label(value);
 	  attach_textedit_widget(directive);
-	  g_signal_connect(G_OBJECT(directive->widget), "activate",  G_CALLBACK(button_callback), directive);
+	  g_signal_connect(G_OBJECT(directive->widget), "button-release-event",  G_CALLBACK(button_callback), directive);
 	}
     g_object_set_data(G_OBJECT(directive->widget), "directive", (gpointer)directive);
     g_object_set_data(G_OBJECT(directive->widget), "fn", (gpointer)fn);
@@ -1778,7 +1812,7 @@ gboolean unpopulate_menu(GtkWidget *menu) {
 void edit_object(GtkAction *action,  DenemoScriptParam *param) {
   DenemoObject *obj = findobj();
   if(obj==NULL){
-      warningdialog("No object here to edit");
+      warningmessage("No object here to edit");
     return;
   }
   switch(obj->type){
@@ -2017,6 +2051,7 @@ static gboolean text_edit_directive(DenemoDirective *directive, gchar *what) {
   TEXTENTRY("Tag", tag);
   TEXTENTRY("MidiBytes", midibytes);
   NEWINTENTRY("Override Mask", override);
+  NEWINTENTRY("Minimum pixel width", minpixels);
 #undef TEXTENTRY
   hbox = gtk_hbox_new (FALSE, 8);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
@@ -2062,14 +2097,14 @@ if(directive->field && directive->field->len==0) g_string_free(directive->field,
   
   //REMOVEEMPTIES(tag); don't allow NULL tag
 #undef REMOVEEMPTIES
-  
+
   if(directive->tag && directive->tag->len==0)
     directive->tag = g_string_new(UNKNOWN_TAG);
   if(directive->widget){
     if(GTK_IS_WIDGET(directive->widget))
       widget_for_directive(directive, NULL/* no need to pass fn in as it is only needed if there is not widget, g_object_get_data(directive->widget, "fn") */);
   }
-  if(directive->graphic){
+  if(directive->graphic_name && directive->graphic){
       loadGraphicItem (directive->graphic_name->str,  (GdkBitmap **)&directive->graphic,  &directive->width, &directive->height);
   }
   gtk_widget_destroy (dialog);
@@ -2078,7 +2113,27 @@ if(directive->field && directive->field->len==0) g_string_free(directive->field,
   return ret;
 }
 
-
+#define TEXT_EDIT_IF(what)\
+  if(fn == (void(*)())what##_directive_put_graphic)\
+    return text_edit_directive(directive, #what);
+static gboolean
+text_edit_directive_by_fn(DenemoDirective *directive, gpointer fn) {
+TEXT_EDIT_IF(note);
+TEXT_EDIT_IF(chord);
+TEXT_EDIT_IF(staff);
+TEXT_EDIT_IF(voice);
+TEXT_EDIT_IF(score);
+TEXT_EDIT_IF(clef);
+TEXT_EDIT_IF(timesig);
+TEXT_EDIT_IF(keysig);
+TEXT_EDIT_IF(scoreheader);
+TEXT_EDIT_IF(header);
+TEXT_EDIT_IF(paper);
+TEXT_EDIT_IF(layout);
+TEXT_EDIT_IF(movementcontrol);
+TEXT_EDIT_IF(standalone);
+}
+#undef TEXT_EDIT_IF
 /* allow edit of a directive, either via script or textually if no script exists 
    return FALSE if user confirms a request to delete the directive
 */
@@ -2143,6 +2198,8 @@ void edit_object_directive(GtkAction *action,  DenemoScriptParam *param) {
       dnm_deleteobject(Denemo.gui->si);
     }
   }
+  if(Denemo.gui->si->currentobject)//for standalone directive
+    setpixelmin(Denemo.gui->si->currentobject->data);
 }
 
 /**
