@@ -40,12 +40,21 @@
 #include "exportxml.h"
 #include "runsilent.h"
 #include "utils.h"
+#ifdef _HAVE_FLUIDSYNTH_
+#include "fluid.h"
+#endif
 #ifdef _HAVE_JACK_
 #include "jackmidi.h"
 #endif
 
 struct DenemoRoot Denemo;
 
+/* set strings for midi_audio_output */
+const gchar *Jack = "Jack";
+const gchar *Portaudio = "Portaudio";
+const gchar *Fluidsynth = "InternalSynth";
+
+
 /* just a simple check, if the user has never run denemo before
    better, keep this for whole first session? */
 gboolean first_time_user(void) {
@@ -416,9 +425,8 @@ main (int argc, char *argv[])
 //  /* workaround necessary for compilation on Cygwin */
 //  g_set_print_handler ((GPrintFunc)printf);
 //#endif
-
-
-  /* set the default handler for debug messages */
+  
+   /* set the default handler for debug messages */
   g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG, debug_handler, NULL);
 
 
@@ -583,14 +591,17 @@ Report bugs to bug-denemo@gnu.org\n"), NULL) ;
   denemo_scheme_init(initschemefile);
 
 #ifdef _HAVE_JACK_
-  g_debug("\nDenemo.prefs.jack_at_startup = %d\n", Denemo.prefs.jack_at_startup);
-  if (Denemo.prefs.jack_at_startup)
-    init_jack();
-#else
+if (Denemo.prefs.midi_audio_output == Jack)
+  init_jack();
+#endif
   /* audio initialization */
-  ext_init ();                  /* external players (midi...) */
-
-
+  //ext_init (); 
+  /* external players (midi...) */
+#ifdef _HAVE_FLUIDSYNTH_
+if (Denemo.prefs.midi_audio_output == Fluidsynth)
+  fluidsynth_init(); 
+#endif
+if (Denemo.prefs.midi_audio_output == Portaudio){
   /* Immediate Playback */
   if(Denemo.prefs.immediateplayback) {
     if( midi_init ()  )  {           /* Opens Denemo.prefs.sequencer, if this is set to an empty
@@ -601,7 +612,8 @@ Report bugs to bug-denemo@gnu.org\n"), NULL) ;
 
     }
   }
-#endif
+}
+
 
   /* Set up the signal handler */
   signal (SIGSEGV, denemo_signal_handler);
