@@ -37,7 +37,7 @@
 #include <denemo/denemo.h>
 #include "draw.h"
 #include "audio.h"
-
+#include "jackmidi.h"
 
 #define SEQ_DEV    (Denemo.prefs.sequencer->str)
 #define SEQ_DEV_N  0
@@ -60,10 +60,44 @@ SEQ_DEFINEBUF (128);
 
 static gint ttag;
 
+/* 
+ *  get the midi channel of the currently selected staff
+ */
+gint get_midi_channel()
+{
+  gint tracknumber;
+  gint channel;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) Denemo.gui->si->currentstaff->data;
+  if (!strcmp (curstaffstruct->midi_instrument->str, "drums"))
+    channel = 9;
+  else
+    {
+      tracknumber = Denemo.gui->si->currentstaffnum-1;
+      tracknumber = (tracknumber >= 9) ? tracknumber + 1 : tracknumber;
+      channel = tracknumber&0xF;
+    }
+  return channel ; //staff struct uses encoding 0-15
+}
 
+gint get_midi_prognum()
+{
+  gint prognum;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) Denemo.gui->si->currentstaff->data;
+  if (curstaffstruct->midi_channel == 9)
+    prognum = 0;
+  else
+    prognum = select_program (curstaffstruct->midi_instrument->str);  
+  return prognum;
+}
 
+gint get_midi_port()
+{
+  gint portnumber;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) Denemo.gui->si->currentstaff->data;
 
-
+  portnumber = curstaffstruct->midi_port;
+  return portnumber; 
+}
 /**
  * Dump the global buffer to the sequencer device
  *
@@ -143,22 +177,20 @@ void playpitch(double pitch, double duration, double volume, int channel) {
 }
 
 void play_midikey(gint key, double duration, double volume, gint channel){
-#ifdef _HAVE_JACK_
-  //playpitch(midi2hz(key), duration, volume, channel);	
-#define NOTEDURATION 1000 /*duration in mseconds*/ 
-  jack_playpitch(key, NOTEDURATION);
-
-#else
-  playpitch(midi2hz(key), duration, volume, channel);
-#endif
+  if (Denemo.prefs.midi_audio_output == Portaudio)
+    playpitch(midi2hz(key), duration, volume, channel);
+  else if (Denemo.prefs.midi_audio_output == Jack)
+    jack_playpitch(key, 1000 /*duration*/);
+  else if (Denemo.prefs.midi_audio_output == Fluidsynth)
+    fluid_playpitch(key, 1000 /*duration*/, channel, (int)(0x7f&(int)(volume*127)));
 }
 
 /**
- *  Used to play each tone in the given chord
+ *  Used to play each note in the given chord
  *  (a g_list_foreach function)
  */
 static void
-playtone (gpointer tone, gpointer chord, int prognum)
+playnote (gpointer tone, gpointer chord, int channel)
 {
   gint offset;
   gchar key;
@@ -174,10 +206,10 @@ playtone (gpointer tone, gpointer chord, int prognum)
   key += ((note *) tone)->enshift;
   voice = g_list_index ((GList *) chord, tone);
   if(sequencer_fd == -1)
-    play_midikey(key, 0.3, 0.5/*Denemo.prefs.pcmvolume*/, 0/*prognum*/);
+    play_midikey(key, 0.3, 0.5/*Denemo.prefs.pcmvolume*/, channel);
 #ifdef HAVE_SYS_SOUNDCARD_H
   else {
-    SEQ_SET_PATCH (SEQ_DEV_N, voice, prognum);
+    SEQ_SET_PATCH (SEQ_DEV_N, voice, channel);
     SEQ_START_NOTE (SEQ_DEV_N, voice, key, 127);
     SEQ_DUMPBUF ();
   }
@@ -229,11 +261,11 @@ close_seqfd (gpointer data)
  * write, as a separate process for performance-type reasons 
  */
 void
-playnotes (gboolean doit, chord chord_to_play, int prognum)
+playnotes (gboolean doit, chord chord_to_play, int channel)
 {
-  //  g_print("playnotes called");
+  //g_print("playnotes called for channel %d\n", channel);
   if (doit && (sequencer_absent) && chord_to_play.notes) {
-    playtone( chord_to_play.notes->data, chord_to_play.notes, 0);
+    playnote( chord_to_play.notes->data, chord_to_play.notes, channel);
     return;
   }
 #ifdef HAVE_SYS_SOUNDCARD_H
@@ -250,7 +282,7 @@ playnotes (gboolean doit, chord chord_to_play, int prognum)
 	tone = chord_to_play.notes;
 	while (tone)
 	  {
-	    playtone (tone->data, chord_to_play.notes, prognum);
+	    playnote (tone->data, chord_to_play.notes, channel);
 	    tone = tone->next;
 	  }
 	SEQ_DELTA_TIME (50);
@@ -276,12 +308,15 @@ static  GIOChannel* channel;/* a channel to access /dev/midi by */
 
 
 static gint *divert_midi_event;
+static gint divert_midi_id=0;//id of the DenemoGUI which wants to intercept midi events
+
+
 #define command ((*buf)&0xFF)
 #define notenumber ((*(buf+1))&0xFF)
 #define velocity ((*(buf+2))&0xFF)
 void process_midi_event(gchar *buf) {
   //g_print("process midi (%s) %x %x %x\n",divert_midi_event?"diverted":"straight", command, notenumber, velocity);
-  if(divert_midi_event){
+  if(divert_midi_event &&  divert_midi_id==Denemo.gui->id){
     // this is only good for one endianness - FIXME
     *divert_midi_event = 0;//clear 4th byte
     memcpy(divert_midi_event, buf, 3);//midi events are up to three bytes long
@@ -299,6 +334,7 @@ gboolean intercept_midi_event(gint *midi) {
     return FALSE;
   }
   divert_midi_event = midi;
+  divert_midi_id = Denemo.gui->id;
   gtk_main();
   divert_midi_event = NULL;
   return TRUE;
@@ -355,6 +391,9 @@ process_callback (GIOChannel *source, GIOCondition condition, gchar * data)
 gint init_midi_input(void) {
 #ifdef _HAVE_JACK_
  return init_jack();
+#else
+#ifdef _HAVE_FLUIDSYNTH_
+ return fluid_start_midi_in();
 #else
   GError *error = NULL;
   if(!channel)
@@ -369,11 +408,15 @@ gint init_midi_input(void) {
   //  g_io_add_watch (channel,G_IO_IN, (GIOFunc) process_callback,NULL, NULL);
   return 0;
 #endif
+#endif
 }
 
 gint stop_midi_input(void) {
 #ifdef _HAVE_JACK_
   stop_jack();
+#else
+#ifdef _HAVE_FLUIDSYNTH_
+ return fluid_stop_midi_in();
 #else
   GError *error = NULL;
   if(channel)
@@ -382,6 +425,7 @@ gint stop_midi_input(void) {
     g_warning(error->message);
   else
     channel = NULL;
+#endif
 #endif
   return 0;
 }
