@@ -340,6 +340,21 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
   DenemoGUI *gui = Denemo.gui;
   //  g_print("Marked %d\n", gui->si->markstaffnum);
 
+  if(event->x<LEFT_MARGIN) {
+    struct placement_info pi; //FIXME duplicate code
+    if (event->y < 0)
+      get_placement_from_coordinates (&pi, event->x, 0, gui->si);
+    else
+      get_placement_from_coordinates (&pi, event->x, event->y, gui->si);
+    if(pi.staff_number==gui->si->currentstaffnum) {
+      gint offset = (gint)get_click_height(gui, event->y);
+      if(offset<STAFF_HEIGHT/2) {
+	if(((DenemoStaff*)gui->si->currentstaff->data)->staff_directives)
+	  gtk_menu_popup (((DenemoStaff*)gui->si->currentstaff->data)->staffmenu, NULL, NULL, NULL, NULL,0, gtk_get_current_event_time()) ;
+      }
+    }
+  }
+
     if (lh_down || (selecting && gui->si->markstaffnum)){
       struct placement_info pi; 
       if (event->y < 0)
@@ -348,8 +363,6 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
 	get_placement_from_coordinates (&pi, event->x, event->y, gui->si);
       if (pi.the_measure != NULL){ /*don't place cursor in a place that is not there*/
 	change_staff(gui->si, pi.staff_number, pi.the_staff);
-	//gui->si->currentstaffnum = pi.staff_number;
-	//gui->si->currentstaff = pi.the_staff;
 	gui->si->currentmeasurenum = pi.measure_number;
 	gui->si->currentmeasure = pi.the_measure;
 	gui->si->currentobject = pi.the_obj;
@@ -387,11 +400,6 @@ DenemoGUI *gui = Denemo.gui;
   struct placement_info pi;
   gboolean left = (event->button != 3);
   gtk_widget_grab_focus(widget);
-  //  if(gui->si->top_staff==1 && 
-  //    event->y < ((DenemoStaff *) gui->si->thescore->data)->space_above) {
-  //   popup_menu("/ScorePopup");
-  //   return TRUE;
-  //  }
   gint key = gui->si->maxkeywidth;
   gint cmajor = key?0:5;//allow some area for keysig in C-major
   if(left && (gui->si->leftmeasurenum>1) && (event->x<KEY_MARGIN+SPACE_FOR_TIME+key)  && (event->x>LEFT_MARGIN)){
@@ -404,10 +412,6 @@ DenemoGUI *gui = Denemo.gui;
   else
     get_placement_from_coordinates (&pi, event->x, event->y, gui->si);
   change_staff(gui->si, pi.staff_number, pi.the_staff);
-  //hide_lyrics();
-  //gui->si->currentstaff = pi.the_staff;
-  //gui->si->currentstaffnum = pi.staff_number;
-  // show_lyrics();
 
   if(event->x<LEFT_MARGIN) {
     gint offset = (gint)get_click_height(gui, event->y);
@@ -491,3 +495,32 @@ DenemoGUI *gui = Denemo.gui;
   return TRUE;
 }
 
+gint
+scorearea_scroll_event (GtkWidget *widget, GdkEventScroll *event) {
+  switch(event->direction) {
+    DenemoScriptParam param;
+  case GDK_SCROLL_UP:
+    staffup (&param);
+    if(!param.status)
+      warningmessage("This is the top staff");
+    break;
+  case GDK_SCROLL_DOWN:
+    staffdown (&param);
+    if(!param.status)
+      warningmessage("This is the bottom staff");
+    break;
+  case GDK_SCROLL_LEFT:
+    measureleft (&param);
+    if(!param.status)
+      warningmessage("This is the first measure");
+    break;
+  case GDK_SCROLL_RIGHT:
+    measureright (&param);
+    if(!param.status)
+      warningmessage("This is the last measure");
+    break;
+
+
+  }
+  displayhelper(Denemo.gui);
+}
