@@ -37,7 +37,7 @@ move_viewport_up (DenemoGUI *gui);
 void
 move_viewport_down (DenemoGUI *si);
 
-void
+gboolean
 set_currentmeasurenum (DenemoGUI *si, gint dest);
 
 void
@@ -46,6 +46,7 @@ vertical_scroll (GtkAdjustment *adjust, DenemoGUI *si);
 void
 horizontal_scroll (GtkAdjustment *adjust, DenemoGUI *si);
 
-void set_currentstaffnum(DenemoGUI *si, gint dest);
+gboolean
+set_currentstaffnum(DenemoGUI *si, gint dest);
 
 #endif
