@@ -5,7 +5,7 @@
  * (c) 2000-2005 Matthew Hiller
  */
 
-#define SMALLESTDURATION 6
+#define SMALLESTDURATION 8
 #define WHOLEHEAD_WIDTH 20
 #define WHOLEHEAD_HEIGHT 10
 #define WHOLEHEAD_SEMI_HEIGHT 5
@@ -31,6 +31,10 @@
 #define SIXTEENTHSTEM_HEIGHT 30
 #define THIRTYSECONDSTEM_HEIGHT 39
 #define SIXTYFOURTHSTEM_HEIGHT 44
+#define HUNDREDTWENTYEIGHTHSTEM_HEIGHT 49
+#define TWOHUNDREDFIFTYSIXTHSTEM_HEIGHT 54
+
+
 #define WHOLEREST_WIDTH 15
 #define WHOLEREST_HEIGHT 5
 #define WHOLEREST_OFFSETFROMTOP LINE_SPACE
@@ -53,6 +57,15 @@
 #define SIXTYFOURTHREST_HEIGHT 48
 #define SIXTYFOURTHREST_OFFSETFROMTOP -2
 
+#define HUNDREDTWENTYEIGHTHREST_WIDTH 18
+#define HUNDREDTWENTYEIGHTHREST_HEIGHT 58
+#define HUNDREDTWENTYEIGHTHREST_OFFSETFROMTOP -2
+
+#define TWOHUNDREDFIFTYSIXTHREST_WIDTH 18
+#define TWOHUNDREDFIFTYSIXTHREST_HEIGHT 68
+#define TWOHUNDREDFIFTYSIXTHREST_OFFSETFROMTOP -2
+
+
 #define THINBEAM_HEIGHT 3
 #define THICKBEAM_HEIGHT 3
 #define STUB_WIDTH 8
