@@ -209,6 +209,7 @@ newstaffbreakobject ()
   return ret;
 }
 
+/* clone the directive, excluding the widget */
 DenemoDirective *clone_directive(DenemoDirective *directive) {
   DenemoDirective *ret = (DenemoDirective *)g_malloc0(sizeof(DenemoDirective));
   memcpy(ret, directive, sizeof(DenemoDirective));//BEWARE all pointers in DenemoDirective require code, as follows:
@@ -223,9 +224,14 @@ DenemoDirective *clone_directive(DenemoDirective *directive) {
   CLONE(display);
   CLONE(graphic_name);
 #undef CLONE
-  if(directive->graphic) {    
+  if(directive->graphic) {
     ret->graphic = directive->graphic;//alternatively could load it via loadGraphicItem, is the same
   }
+ if(directive->widget) {
+   //  gpointer fn = g_object_get_data(G_OBJECT(directive->widget), "fn");
+   ret->widget = NULL;//FIXME call widget_for_directive here???
+   //   widget_for_directive(ret, fn);
+ }
   return ret;
 }
 
@@ -245,12 +251,20 @@ free_directive_data(DenemoDirective *directive) {
     DFREE(postfix);
     DFREE(graphic_name);
 #undef DFREE
-    if(directive->graphic && GTK_IS_WIDGET(directive->graphic)) {
-      //g_print("We should destroy the widget now");
-      gtk_widget_destroy((GtkWidget *)directive->graphic);
+  
+    if(directive->widget && !G_IS_OBJECT(directive->widget)) {
+      g_debug("Found non-gobject widget %p\n", directive->widget);
     }
-      else	
-   ; //  g_object_unref(directive->graphic); we leave these GdkBitmap in a hash table, and never discard them
+    if(directive->widget && G_IS_OBJECT(directive->widget)) {
+      //g_print("We should destroy the widget now ");
+      GtkWidget *texteditor =  (GtkWidget*)g_object_get_data(directive->widget, DENEMO_TEXTEDITOR_TAG);
+      if(texteditor)
+	gtk_widget_destroy(texteditor);//FIXME we may need to destroy its parents
+      gtk_widget_destroy((GtkWidget *)directive->widget);
+    }
+
+
+
 }
 void
 free_directive(DenemoDirective *directive) {
@@ -324,6 +338,7 @@ dnm_clone_object (DenemoObject * orig)
 	      break;
 	    default:
 	      g_warning("Unknown object type"); 
+	      ret = lily_directive_new ("%unknown object\n");
 	      break;
 	    }
   }
