@@ -26,7 +26,24 @@ newstaffbreakobject ();
 DenemoObject *
 lily_directive_new (gchar* type);
 
+DenemoObject *
+directive_object_new(DenemoDirective *directive);
+
 DenemoObject *
 dynamic_new (gchar *type);
 
+DenemoDirective *
+clone_directive(DenemoDirective *directive);
+
+GList *
+clone_directives(GList *directives);
+
+void
+free_directives(GList *directives);
+
+void
+free_directive(DenemoDirective *directive);
+
+void
+free_directive_data(DenemoDirective *directive);
 #endif
