@@ -366,9 +366,19 @@ void set_sharper(GtkAction *action, gpointer param) {
 void set_flatter(GtkAction *action, gpointer param) {
   enharmonic_step (FALSE);
 }
+
+void
+signal_measure_end(void) {
+if (Denemo.prefs.midi_audio_output == Fluidsynth)
+  fluid_playpitch(74, 300, 9, 40);
+ else
+   gdk_beep();
+}
+
+
 static void sound_click(void) {
   if(PR_click)
-    gdk_beep();
+    signal_measure_end();
 }
 
 static GList *get_tones(GList *tone_store, gint measurenum) {
@@ -652,6 +662,15 @@ static gint measure_pitch_accurately (DenemoGUI *gui) {
 
   return TRUE;
 }
+
+
+static float Freq2Pitch(float freq)
+{
+   return 0.5 + (69.0 + 12.0 * (log(freq / 440.0) / log(2.0)));
+}
+
+
+
 /* look for a new note played into audio input, if
    present insert it into the score/store */
 gint pitchentry(DenemoGUI *gui) {
@@ -695,9 +714,17 @@ gint pitchentry(DenemoGUI *gui) {
       // Enter the note in the score
       if(!PR_tuning){
 	display_pitch(note, gui);
-	if(gui->input_source==INPUTMIDI)
-	  playpitch(found->pitch * (pow(2,(octave))), 0.3, 0.5, 0);
-	if(!Denemo.prefs.overlays) {
+	if(gui->input_source==INPUTMIDI) {
+	  gint key=(gint)(Freq2Pitch(found->pitch * (pow(2,(octave)))));
+	  //g_print("pitch %f key number %d\n",found->pitch, key);
+	  if (Denemo.prefs.midi_audio_output == Portaudio)
+	    playpitch(found->pitch * (pow(2,(octave))), 0.3, 0.5, 0);
+	  else if (Denemo.prefs.midi_audio_output == Jack)
+	    jack_playpitch(key, 300 /*duration*/);
+	  else if (Denemo.prefs.midi_audio_output == Fluidsynth)
+	    fluid_playpitch(key, 300 /*duration*/,  ((DenemoStaff *)Denemo.gui->si->currentstaff->data)->midi_channel, 0);
+	}
+	if(gui->input_source==INPUTMIDI || !Denemo.prefs.overlays) {
 	  enter_note_in_score(gui, found, octave);
 	  if(gui->mode & INPUTRHYTHM) {
 	    static beep = FALSE;
@@ -705,7 +732,7 @@ gint pitchentry(DenemoGUI *gui) {
 	    scheme_next_note(NULL);
 	    if(measure != gui->si->currentmeasurenum)
 	      beep=TRUE;
-	    else if(beep) gdk_beep(), beep=FALSE;
+	    else if(beep) signal_measure_end(), beep=FALSE;
 	  }
 	}
 	else
