@@ -1,5 +1,5 @@
 /* pitchentry.h
- * function prototypes for responses to pitchrecognition from audio in
+ * function prototypes for interface to audio/midi in
  *
  * for Denemo, a gtk+ frontend to GNU Lilypond
  * (c)2007 Richard Shann
@@ -16,10 +16,15 @@
 #include "objops.h"
 
 
-gint setup_pitch_recognition(DenemoGUI *gui);
-gint stop_pitch_recognition(void);
-void start_pitch_recognition(DenemoGUI *gui);
+gint setup_pitch_input(void);
+gint stop_pitch_input(void);
+void start_pitch_input(void);
 gboolean pitch_recognition_system_active(void);
 gboolean delete_tone(DenemoScore *si, chord *thechord);
 void clear_overlay(GtkAction *action, gpointer param);
+void store_pitch(double pitch);
+double get_pitch(void);
+void set_sharper (GtkAction *action, gpointer param);
+void set_flatter (GtkAction *action, gpointer param);
+gchar *determine_interval(gint bass, gint harmony);
 #endif //PITCHENTRY_H
