@@ -29,10 +29,28 @@
 #endif
 #include <errno.h>
 #include "jackmidi.h"
+#include "fluid.h"
 
 static gint timeout_id = 0, kill_id=0;
 static gdouble duration = 0.0;
 
+gchar *
+get_midi_audio_pointer(gchar *audio_device)
+{
+  if (!strcmp(audio_device, Fluidsynth))
+    return Fluidsynth;
+  else if (!strcmp(audio_device, Jack))
+    return Jack;
+  else if (!strcmp(audio_device, Portaudio))
+    return Portaudio;
+
+#ifdef _HAVE_FLUIDSYNTH_
+  return Fluidsynth;
+#else 
+  return Portaudio;
+#endif
+}
+
 static gint move_on(DenemoGUI *gui){
   if(timeout_id==0)
     return FALSE;
@@ -100,6 +118,8 @@ ext_midi_playback_control (gboolean start)
     }
 
   fp = fopen (pidpath, "rb+");
+  if(!fp)
+    return;
 #ifdef HAVE_FILE_LOCKS
   if (ftrylockfile (fp))	/* might not exist on old BSD's */
     {
@@ -187,21 +207,27 @@ ext_midi_playback_control (gboolean start)
 void
 ext_midi_playback (GtkAction * action, gpointer param)
 {
-#ifdef _HAVE_JACK_
-  jack_midi_playback_start();
-#else
-  ext_midi_playback_control (TRUE);
-#endif
+  if (Denemo.prefs.midi_audio_output == Jack)
+    jack_midi_playback_start();
+  else if (Denemo.prefs.midi_audio_output == Fluidsynth)
+    fluid_midi_play();
+  else  
+    ext_midi_playback_control (TRUE);
 }
 
 void stop_midi_playback (GtkAction * action, gpointer param) {
-#ifdef _HAVE_JACK_
- jack_midi_playback_stop();
- jack_kill_timer();
-#else
- ext_midi_playback_control (FALSE);
- kill_timer();
-#endif
+ if (Denemo.prefs.midi_audio_output == Jack){
+   jack_midi_playback_stop();
+   jack_kill_timer();
+ }
+ else if (Denemo.prefs.midi_audio_output == Fluidsynth){
+   fluid_midi_stop();
+   fluid_kill_timer();
+ }
+ else {
+   ext_midi_playback_control (FALSE);
+   kill_timer();
+ }
 }
 
 
