@@ -2,7 +2,8 @@
 #define PLAYBACKH
 #include <gtk/gtk.h>
 
-
+gchar *
+get_midi_audio_pointer(gchar *audio_device);
 
 void
 playback_local (gpointer callback_data, guint callback_action,
