@@ -17,14 +17,16 @@
 #include <denemo/denemo.h>
 #include "prefops.h"
 #include "utils.h"
-#ifdef _HAVE_JACK_
+#include "playback.h"
 #include "jackmidi.h"
-#endif
+#include "fluid.h"
+#include "device_manager.h"
 
 struct callbackdata
 {
   DenemoPrefs *prefs;
   GtkWidget *lilypath;
+  GtkWidget *midi_audio_output;
   GtkWidget *immediateplayback;
   GtkWidget *saveparts;
   GtkWidget *autosave;
@@ -47,10 +49,19 @@ struct callbackdata
 #ifdef _HAVE_JACK_
   GtkWidget *jacktransport;
   GtkWidget *jacktransport_start_stopped;
-  GtkWidget *jack_at_startup;
+#endif
+#ifdef _HAVE_FLUIDSYNTH_
+  GtkWidget *fluidsynth_audio_driver;
+  GtkWidget *fluidsynth_soundfont;
+  GtkWidget *fluidsynth_reverb;
+  GtkWidget *fluidsynth_chorus;
+  GtkWidget *fluidsynth_sample_rate;
+  GtkWidget *fluidsynth_period_size;
+
 #endif
   GtkWidget *texteditor;
   GtkWidget *midiplayer;
+  GtkWidget *audioplayer;
   GtkWidget *denemopath;
   GtkWidget *temperament;
   GtkWidget *strictshortcuts;
@@ -83,10 +94,9 @@ set_preferences (struct callbackdata *cbdata)
 {
   DenemoPrefs *prefs = cbdata->prefs;
 
-
 #define ASSIGNTEXT(field) \
   g_string_assign (prefs->field,\
-                   gtk_entry_get_text (GTK_ENTRY (cbdata->field)));
+    gtk_entry_get_text (GTK_ENTRY (cbdata->field)));
 
 #define ASSIGNBOOLEAN(field) \
   prefs->field =\
@@ -96,6 +106,13 @@ set_preferences (struct callbackdata *cbdata)
    prefs->field =\
     gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(cbdata->field));
 
+#define ASSIGNCOMBO(field) \
+  g_string_assign (prefs->field,\
+    (gchar *) gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (cbdata->field)->entry)));
+
+#define ASSIGNCOMBO2(field) \
+  prefs->field = get_midi_audio_pointer(\
+    (gchar *) gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (cbdata->field)->entry)));
 
   ASSIGNTEXT(lilypath)
   ASSIGNTEXT(browser) 
@@ -105,15 +122,24 @@ set_preferences (struct callbackdata *cbdata)
   ASSIGNTEXT(password)
   ASSIGNTEXT(texteditor)
   ASSIGNTEXT(midiplayer)
+  ASSIGNTEXT(audioplayer)
   ASSIGNTEXT(denemopath)
-  ASSIGNTEXT(sequencer)
-  ASSIGNTEXT(midi_in)
-  ASSIGNTEXT(sequencer)
+    // ASSIGNTEXT(sequencer)
+#ifndef _HAVE_FLUIDSYNTH_
   ASSIGNTEXT(midi_in)
+#endif
 #ifdef _HAVE_JACK_
-  ASSIGNBOOLEAN(jacktransport)
-  ASSIGNBOOLEAN(jacktransport_start_stopped)
-  ASSIGNBOOLEAN(jack_at_startup)
+    // ASSIGNBOOLEAN(jacktransport)
+    //  ASSIGNBOOLEAN(jacktransport_start_stopped)
+#endif
+#ifdef _HAVE_FLUIDSYNTH_
+  /*TODO save combo as int????*/
+  ASSIGNCOMBO(fluidsynth_audio_driver);
+  ASSIGNTEXT(fluidsynth_soundfont);
+  ASSIGNBOOLEAN(fluidsynth_reverb)
+  ASSIGNBOOLEAN(fluidsynth_chorus)
+    ASSIGNINT(fluidsynth_sample_rate)
+    ASSIGNINT(fluidsynth_period_size)
 #endif
   ASSIGNTEXT(temperament)
   ASSIGNBOOLEAN(strictshortcuts)
@@ -121,6 +147,10 @@ set_preferences (struct callbackdata *cbdata)
   ASSIGNBOOLEAN(continuous)
   ASSIGNINT(resolution)
   ASSIGNINT(maxhistory)
+
+
+  ASSIGNCOMBO2(midi_audio_output); 
+  
   ASSIGNBOOLEAN(immediateplayback)
   ASSIGNBOOLEAN(autosave)
   ASSIGNINT(autosave_timeout)
@@ -150,11 +180,6 @@ preferences_change (GtkAction *action, gpointer param)
   GtkWidget *notebook;
   GtkWidget *hbox;
   GtkWidget *vbox;
-  GtkListStore *list_store;
-  GtkWidget *tree;
-  GtkTreeIter iter;
-  GtkTreeViewColumn *column;
-  GtkCellRenderer *renderer;
   GtkWidget *entrywidget;
   static struct callbackdata cbdata;
   g_assert (gui != NULL);
@@ -233,13 +258,50 @@ preferences_change (GtkAction *action, gpointer param)
   gtk_box_pack_start (GTK_BOX (hbox), field, FALSE, FALSE, 0);\
   cbdata.field = field;
 
+#define BUTTON(thelabel, field, thecallback, data) \
+  hbox = gtk_hbox_new (FALSE, 8);\
+  gtk_box_pack_start (GTK_BOX (vbox1), hbox, FALSE, FALSE, 0);\
+  GtkWidget *field = gtk_button_new_with_label(thelabel);\
+  gtk_box_pack_start (GTK_BOX (vbox1), field, FALSE, FALSE, 0);\
+  g_signal_connect (G_OBJECT (field), "clicked",\
+  G_CALLBACK (thecallback), (gpointer) data);
+
   /*
    * Note entry settings
    */
   
   NEWPAGE("View");
   
+  //Doesnt GList need to be freed
+  GList *output_option_list = NULL;
+  output_option_list = g_list_append (output_option_list, (gpointer) Portaudio);
+#ifdef _HAVE_JACK_
+  output_option_list = g_list_append (output_option_list, (gpointer) Jack);
+#endif 
+#ifdef _HAVE_FLUIDSYNTH_
+  output_option_list = g_list_append (output_option_list, (gpointer) Fluidsynth);
+#endif 
+
+
+#define COMBOBOX(thelable, field, thelist, settext)\
+  hbox = gtk_hbox_new (FALSE, 8);\
+  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);\
+  label = gtk_label_new (thelable);\
+  gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);\
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);\
+  hbox = gtk_hbox_new (FALSE, 8);\
+  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);\
+  GtkWidget *field = gtk_combo_new ();\
+  gtk_combo_set_popdown_strings (GTK_COMBO (field), thelist);\
+  gtk_box_pack_start (GTK_BOX (hbox), field, FALSE, FALSE, 0);\
+  gtk_entry_set_text\
+    (GTK_ENTRY (GTK_COMBO (field)->entry),  settext);\
+  gtk_widget_show (field);\
+  cbdata.field = field;
+
+  COMBOBOX("Midi/Audio output", midi_audio_output, output_option_list, Denemo.prefs.midi_audio_output) 
   BOOLEANENTRY("Play back entered notes immediately", immediateplayback);  
+ 
   BOOLEANENTRY("Display Note/Rest entry toolbar", notation_palette);
   BOOLEANENTRY("Display articulation palette", articulation_palette);
   BOOLEANENTRY("Display Titles. Controls etc", visible_directive_buttons);
@@ -268,9 +330,10 @@ preferences_change (GtkAction *action, gpointer param)
 
 
   BOOLEANENTRY("Autosave Parts", saveparts);
-  TEXTENTRY("Sequencer Device", sequencer)
+  //TEXTENTRY("Sequencer Device", sequencer)
+#ifndef _HAVE_FLUIDSYNTH_
   TEXTENTRY("Midi Input Device", midi_in)
-
+#endif
 
   /*
    * Pitch Entry Parameters 
@@ -301,6 +364,7 @@ preferences_change (GtkAction *action, gpointer param)
   TEXTENTRY("Image Viewer", imageviewer)
   TEXTENTRY("Text Editor", texteditor)
   TEXTENTRY("Midi Player", midiplayer)
+  TEXTENTRY("Audio Player", audioplayer)
 
   TEXTENTRY("Default Save Path", denemopath)
   BOOLEANENTRY("Update the command set on startup", autoupdate);
@@ -315,30 +379,78 @@ preferences_change (GtkAction *action, gpointer param)
   TEXTENTRY("User Name", username)
   PASSWORDENTRY("Password for Denemo.org", password)
   /*
-   * Jack Menu
+   * Fluidsynth Menu
    */
-#ifdef _HAVE_JACK_
-  NEWPAGE("JACK");
-  BOOLEANENTRY("Enable Jack Transport", jacktransport);
-  BOOLEANENTRY("Jack Transport starts stopped", jacktransport_start_stopped);
-  BOOLEANENTRY("Enable Jack at startup", jack_at_startup);
+#ifdef _HAVE_FLUIDSYNTH_
+  NEWPAGE("Fluidsynth");
   /* Start/Restart Button */
+  //BUTTON("Start/Restart FLUIDSYNTH", fluid_restart, fluidsynth_start_restart, NULL)
+
+  /*TODO ifdef differnet os's and support
+   *jack, alsa, oss, pulseaudio, coreaudio, dsound, portaudio, sndman, dart, file 
+   *defaults are:
+   *jack (Linux), dsound (Windows), sndman (MacOS9), coreaudio (Mac OS X), dart (OS/2) 
+   */
+#ifdef G_OS_WIN32
+  gchar *driver_options[5] = {"portaudio", "jack"};
+#else
+  gchar *driver_options[5] = {"alsa", "jack", "oss", "pulseaudio", "portaudio"};
+#endif
+  GList *driver_option_list = NULL;
+  gint i;
+  for (i=0;i<G_N_ELEMENTS(driver_options);i++)
+    driver_option_list = g_list_append (driver_option_list, driver_options[i]);
+
+  COMBOBOX("Audio Driver", fluidsynth_audio_driver, driver_option_list, Denemo.prefs.fluidsynth_audio_driver->str)
+  TEXTENTRY("Soundfont", fluidsynth_soundfont)	
+  
   hbox = gtk_hbox_new (FALSE, 8);
   gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);
-  GtkWidget *jack_activate = gtk_button_new_with_label("Start/Restart Jack Client");
-  gtk_box_pack_start (GTK_BOX (hbox), jack_activate, FALSE, FALSE, 0);
-  g_signal_connect (G_OBJECT (jack_activate), "clicked",
-    G_CALLBACK (jack_start_restart), (gpointer) NULL);
+  GtkWidget *button = gtk_button_new_with_label (_("Choose Soundfont"));
+  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+  gtk_signal_connect (GTK_OBJECT (button), "clicked",
+    GTK_SIGNAL_FUNC (choose_sound_font), fluidsynth_soundfont);
+  gtk_widget_show (button);
+
+  BOOLEANENTRY("Enable Reverb on soundfont", fluidsynth_reverb)
+  BOOLEANENTRY("Enable Chorus on soundfont", fluidsynth_chorus)
+    INTENTRY_LIMITS(_("Sample Rate"), fluidsynth_sample_rate, 0, 96000);
+   INTENTRY_LIMITS(_("Period Size"), fluidsynth_period_size, 0, 2048);
 
 #endif
-
-
-  /*
-   * Help settings
+  /**
+   * Device Manager
    */
-  //  NEWPAGE("Help Settings")
+#ifdef _HAVE_JACK_
+  NEWPAGE("MIDI Device Manager");
+  
+  GtkWidget *mhbox = gtk_hbox_new(FALSE, 5);
+  gtk_box_pack_start (GTK_BOX (main_vbox), mhbox, FALSE, FALSE, 0);
 
-  /* Set up the callback data */
+  GtkWidget *vbox1 = gtk_vbox_new(FALSE, 5);
+  gtk_box_pack_start (GTK_BOX (mhbox), vbox1, FALSE, FALSE, 0);
+  
+  //None of this is working right now anyway  
+  //BOOLEANENTRY("Enable Jack Transport", jacktransport);
+  //BOOLEANENTRY("Jack Transport starts stopped", jacktransport_start_stopped);
+  //BOOLEANENTRY("Enable Jack at startup", jack_at_startup);
+
+  //BUTTON("Start/Restart Jack Client", jack_restart, jack_start_restart, NULL);
+  BUTTON("Add Device", midi_add_device, device_manager_create_device, NULL); 
+  BUTTON("Remove Device", midi_remove_device, device_manager_remove_device, NULL); 
+  BUTTON("Add Port", midi_device_add_port, device_manager_create_port, NULL);
+  BUTTON("Remove Port", midi_device_remove_port, device_manager_remove_port, NULL);
+  
+  GtkWidget *vbox2 = gtk_vbox_new(FALSE, 5);
+  gtk_box_pack_start (GTK_BOX (mhbox), vbox2, FALSE, FALSE, 0);
+  
+  GtkWidget *view = DeviceManager();
+  g_print("the view %p is %d\n", view, GTK_IS_WIDGET(view));
+  gtk_box_pack_start (GTK_BOX (vbox2), view, FALSE, FALSE, 0);
+  
+  gtk_widget_show (view);
+  device_manager_refresh_model();
+#endif
 
 #define SETCALLBACKDATA(field) \
   cbdata.field = field;
@@ -355,7 +467,9 @@ preferences_change (GtkAction *action, gpointer param)
     {
       set_preferences (&cbdata);
     }
+#ifdef _HAVE_JACK_
+  gtk_container_remove(GTK_CONTAINER(vbox2), view);
+#endif
   gtk_widget_destroy (dialog);
 }
 
-
