@@ -19,6 +19,7 @@
 #include <libxml/tree.h>
 #include "utils.h"
 #include "prefops.h"
+#include "playback.h"
 
 static gint
 readxmlprefsFile (gchar * filename);
@@ -78,6 +79,16 @@ initprefs ()
   const gchar *name = g_get_user_name();
   ret->username = g_string_new (name?name:"DenemoUser");
   ret->password = g_string_new ("");
+//#ifdef _HAVE_PORTAUDIO_
+  ret->midi_audio_output = Portaudio;
+//#endif
+
+#ifdef _HAVE_FLUIDSYNTH_ 
+  ret->midi_audio_output = Fluidsynth;	  
+#endif
+#ifdef _HAVE_JACK_
+  ret->midi_audio_output = Jack;
+#endif
 
 #ifdef G_OS_WIN32
   ret->browser = g_string_new ("firefox");
@@ -101,7 +112,7 @@ initprefs ()
   ret->midi_in = g_string_new ("/dev/midi");
 
   ret->denemopath = g_string_new (g_get_home_dir());
-  ret->lilyversion = g_string_new (LILYPOND_VERSION);
+  ret->lilyversion = g_string_new ("");//meaning use installed LilyPond version
   ret->temperament = g_string_new("Equal");
   ret->strictshortcuts = FALSE;
   ret->resolution = 300;
@@ -111,6 +122,20 @@ initprefs ()
   ret->immediateplayback = FALSE;
 #else
   ret->immediateplayback = TRUE;
+#endif
+#ifdef _HAVE_FLUIDSYNTH_
+  /*TODO needs to check if linux and set fluidsynth_audio_driver = alsa
+  	for some reason the default for linux is jack */
+#ifdef G_OS_WIN32
+  ret->fluidsynth_audio_driver = g_string_new ("portaudio");
+#else
+  ret->fluidsynth_audio_driver = g_string_new ((char *)fluidsynth_get_default_audio_driver());
+#endif
+  gchar *soundfontpath = g_build_filename (get_data_dir (), "soundfonts",
+		                                           "A320U.sf2", NULL);
+  ret->fluidsynth_soundfont = g_string_new(soundfontpath);
+  ret->fluidsynth_sample_rate = 0;//do not set
+
 #endif
   ret->saveparts = FALSE;
   ret->rtcs = TRUE;
@@ -151,6 +176,109 @@ initprefs ()
  *  Local function definitions to parse denemorc file
  */
 
+static void
+parsePorts (xmlDocPtr doc, xmlNodePtr cur, gint i)
+{
+  gint j=0;
+  xmlNodePtr child;
+  //first count the ports
+  for (j=0, child = cur->xmlChildrenNode;child != NULL;child = child->next)
+    {
+      if (xmlStrcmp (child->name, (const xmlChar *) "port") == 0)
+	{
+	  xmlChar *tmp = xmlNodeListGetString (doc, child->xmlChildrenNode, 1);
+	  if(tmp)
+	    {
+	      j++;
+	      xmlFree (tmp); 
+	    }
+	}
+    }
+  g_debug("We have %d ports for client %s\n",j, Denemo.prefs.midi_device[i].client_name->str);
+
+#if 1
+  {GArray *arr = g_array_new(TRUE, TRUE, sizeof(DeviceManagerPort));
+    g_array_set_size(arr, j);
+    Denemo.prefs.midi_device[i].ports =  (DeviceManagerPort *)arr->data;
+    Denemo.prefs.midi_device[i].ports_array = arr;
+  }
+#else
+  Denemo.prefs.midi_device[i].ports = g_malloc0((j+1) * sizeof(DeviceManagerPort));
+#endif
+
+
+  for (j=0,child = cur->xmlChildrenNode;child != NULL;child = child->next)
+    {
+      if (xmlStrcmp (child->name, (const xmlChar *) "port") == 0)
+	{
+	  xmlChar *tmp = xmlNodeListGetString (doc, child->xmlChildrenNode, 1);
+	  if(tmp)
+	    {
+	      g_print("storing port %s into client\n", tmp);
+	      Denemo.prefs.midi_device[i].ports[j].midi_buffer = g_malloc0(DENEMO_BUFFER_MAX_INDEX*sizeof(MidiBuffer));
+	      Denemo.prefs.midi_device[i].ports[j].port_name = g_string_new(tmp);
+	      j++;
+	      //FIXME check j<max
+	      xmlFree (tmp); 
+	    }
+	}
+    }
+}
+
+/**
+ * parseDevices - reads midi device prefs
+ * 
+ * @param  doc	document pointer
+ * @param cur pointer to the current XML Node
+ * @param prefs pointer to the preferences structure
+ */
+
+static void
+parseDevices (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
+{
+  gint i;
+  xmlNodePtr child;
+  //first count the client devices
+  for (i=0, child = cur->xmlChildrenNode;child != NULL && i<DENEMO_MAX_DEVICES;child = child->next)
+    {
+      if (xmlStrcmp (child->name, (const xmlChar *) "device") == 0)
+	{
+	  i++;	  
+	}
+    }
+#if 1  
+  {GArray *arr = g_array_new(TRUE, TRUE, sizeof(DeviceManagerDevice));
+    g_array_set_size(arr, i);
+    prefs->midi_device =  (DeviceManagerDevice *)arr->data;
+    prefs->midi_device_array = arr;
+  }
+#else
+  prefs->midi_device = (DeviceManagerDevice *)g_malloc0((i+1)*sizeof(DeviceManagerDevice));
+#endif
+  for (i=0, child = cur->xmlChildrenNode;child != NULL && i<DENEMO_MAX_DEVICES;child = child->next, i++)
+    {
+      if (xmlStrcmp (child->name, (const xmlChar *) "device") == 0)
+	{
+	  gchar *tmp = (gchar *) xmlGetProp (child, (xmlChar *) "client");
+g_print("storing client name %s\n", tmp);
+	  if(tmp)
+	    {
+	      if(prefs->midi_device[i].client_name)
+		g_string_assign (prefs->midi_device[i].client_name, (gchar *) tmp);
+	      else
+		prefs->midi_device[i].client_name = g_string_new ((gchar *) tmp);
+	      xmlFree (tmp);
+	    }
+	}
+      xmlNodePtr ports = child->xmlChildrenNode;
+      g_print("for client ports is %p\n", ports);   
+      if (ports && xmlStrcmp (ports->name, (const xmlChar *) "ports") == 0)
+	{
+	  parsePorts(doc, ports, i);
+	}
+    }
+}
+
 /**
  * parseConfig searches the rc file for the configuration settings.
  *
@@ -178,6 +306,18 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 	    }\
 	}
 
+#define READXMLENTRY2(field)  \
+      else if (0 == xmlStrcmp (cur->name, (const xmlChar *) #field))\
+	{\
+	  xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
+	  if(tmp)\
+	    {\
+              define_scheme_variable("DenemoPref_" #field, tmp, NULL);\
+	      prefs->field = get_midi_audio_pointer(tmp);\
+	      xmlFree (tmp);\
+	    }\
+	}
+
 #define READINTXMLENTRY(field) \
       else if (0 ==\
 	       xmlStrcmp (cur->name, (const xmlChar *) #field))\
@@ -205,6 +345,13 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 	      xmlFree (tmp);
 	    }
 	}
+
+      if (0 == xmlStrcmp (cur->name, (const xmlChar *) "midi-devices"))
+	{
+	  parseDevices(doc, cur, &Denemo.prefs);
+
+	}
+
 	READXMLENTRY(midiplayer)      
 	READXMLENTRY(audioplayer)        
 	READXMLENTRY(browser)
@@ -252,16 +399,17 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READXMLENTRY(temperament)
       READXMLENTRY(midi_in)
       READXMLENTRY(sequencer)
+      READXMLENTRY2(midi_audio_output)
       
       READINTXMLENTRY(createclones)
-      READINTXMLENTRY(immediateplayback)   
+      READINTXMLENTRY(immediateplayback) 
+  
       READINTXMLENTRY(strictshortcuts)
       READINTXMLENTRY(resolution)
       READINTXMLENTRY(overlays)
       READINTXMLENTRY(continuous)
       READINTXMLENTRY(jacktransport)
       READINTXMLENTRY(jacktransport_start_stopped)
-      READINTXMLENTRY(jack_at_startup)
       READINTXMLENTRY(lilyentrystyle)
       READINTXMLENTRY(notation_palette)
       READINTXMLENTRY(articulation_palette)
@@ -270,7 +418,14 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READINTXMLENTRY(object_palette)
       READINTXMLENTRY(autoupdate) 
      
-      READXMLENTRY(lilyversion) 
+      READXMLENTRY(fluidsynth_audio_driver)
+      READXMLENTRY(fluidsynth_soundfont)
+      READINTXMLENTRY(fluidsynth_reverb)
+      READINTXMLENTRY(fluidsynth_chorus)
+      READINTXMLENTRY(fluidsynth_sample_rate)
+      READINTXMLENTRY(fluidsynth_period_size)
+
+
       READINTXMLENTRY(saveparts)
       
       cur = cur->next;
@@ -291,6 +446,10 @@ writeHistoryEntry (gpointer data, gpointer user_data)
 		   (xmlChar *) data);
 }
 
+
+
+
+
 /**
  * parseHistory - reads history entry from xml node and adds it to the history queue
  * 
@@ -442,6 +601,29 @@ newXMLIntChild (xmlNodePtr parent, const xmlChar * name, gint content)
  * @param prefs a pointer to the preferences structure
  *
  */
+static void
+writeDevices(xmlDocPtr doc, xmlNodePtr parent, DenemoPrefs * prefs) {
+  gint i;
+  xmlNodePtr child;
+  if(!prefs->midi_device)
+    return;
+  if(prefs->midi_device[0].client_name) {
+    child =  xmlNewChild (parent, NULL, (xmlChar *) "midi-devices", NULL);
+    for(i=0;i<DENEMO_MAX_DEVICES && prefs->midi_device[i].client_name;i++){
+	xmlNodePtr device = xmlNewChild (child, NULL, "device", NULL);
+	xmlSetProp (device, (xmlChar *) "client",
+		    (xmlChar *) prefs->midi_device[i].client_name->str);
+	
+	if(prefs->midi_device[i].ports && prefs->midi_device[i].ports[0].port_name) {
+	  gint j;
+	  xmlNodePtr ports = xmlNewChild (device, NULL, (xmlChar *) "ports", NULL);
+	  for(j=0;prefs->midi_device[i].ports[j].port_name;j++)
+	    xmlNewChild (ports, NULL, (xmlChar *)"port", (xmlChar *)prefs->midi_device[i].ports[j].port_name->str);
+	} 
+    }
+  }
+}
+
 
 gint
 writeXMLPrefs (DenemoPrefs * prefs)
@@ -462,6 +644,8 @@ writeXMLPrefs (DenemoPrefs * prefs)
     xmlNewDocNode (doc, NULL, (xmlChar *) "Denemo", NULL);
   child = xmlNewChild (parent, NULL, (xmlChar *) "Config", NULL);
 
+    writeDevices(doc, child, prefs);
+
 #define WRITEXMLENTRY(field) \
   if (prefs->field){\
     gchar *def = g_strdup("Holds the value of the user's " #field " preference");\
@@ -472,6 +656,16 @@ writeXMLPrefs (DenemoPrefs * prefs)
     xmlNewChild (child, NULL, (xmlChar *) #field,\
 		 (xmlChar *) prefs->field->str);}
 
+ #define WRITEXMLENTRY2(field) \
+  if (prefs->field){\
+    gchar *def = g_strdup("Holds the value of the user's " #field " preference");\
+    gchar *curname = g_strdup_printf("DenemoPref_%s", #field);\
+    define_scheme_variable(curname, prefs->field, def);\
+    g_free(curname);\
+    g_free(def);\
+    xmlNewChild (child, NULL, (xmlChar *) #field,\
+		 (xmlChar *) prefs->field);}
+   
   WRITEXMLENTRY(lilypath)
   WRITEXMLENTRY(midiplayer)
   WRITEXMLENTRY(audioplayer)
@@ -486,8 +680,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEXMLENTRY(temperament)
   WRITEXMLENTRY(midi_in)
   WRITEXMLENTRY(sequencer)
-  WRITEXMLENTRY(lilyversion)
- 
+
 #define WRITEINTXMLENTRY(field){ \
     gchar *def = g_strdup("Holds the value of the user's " #field " preference");\
     gchar *value = g_strdup_printf("%d", prefs->field);\
@@ -512,7 +705,6 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEINTXMLENTRY(continuous)
   WRITEINTXMLENTRY(jacktransport)
   WRITEINTXMLENTRY(jacktransport_start_stopped)
-  WRITEINTXMLENTRY(jack_at_startup)
   WRITEINTXMLENTRY(rtcs)
   WRITEINTXMLENTRY(notation_palette)
   WRITEINTXMLENTRY(articulation_palette)
@@ -520,8 +712,14 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEINTXMLENTRY(autoupdate)
   WRITEINTXMLENTRY(rhythm_palette)
   WRITEINTXMLENTRY(object_palette)
+  WRITEXMLENTRY2(midi_audio_output)
+  WRITEXMLENTRY(fluidsynth_audio_driver)
+  WRITEXMLENTRY(fluidsynth_soundfont)
+  WRITEINTXMLENTRY(fluidsynth_reverb)
+  WRITEINTXMLENTRY(fluidsynth_chorus)
+  WRITEINTXMLENTRY(fluidsynth_sample_rate)
+  WRITEINTXMLENTRY(fluidsynth_period_size)
 
-  
   WRITEXMLENTRY(browser) 
   
   xmlSaveFormatFile (localrc->str, doc, 1);
