@@ -80,7 +80,7 @@ check_lilypond_path (DenemoGUI * gui){
       return 1;
 }
 
-#if GLIB_MINOR_VERSION >= 14
+#if 1 // lilypond -v command should be good for all versions. was GLIB_MINOR_VERSION >= 14
 int
 version_check(lilyversion base, lilyversion installed)
 {
@@ -139,8 +139,8 @@ regex_parse_version_number (const gchar *string)
   return g_string_free(lilyversion, FALSE); 	  
 }
 
-int
-get_lily_version (gchar *version)
+gchar *
+get_lily_version_string (void)
 {
   GError *error = NULL;
   gchar *version_string;
@@ -166,10 +166,15 @@ get_lily_version (gchar *version)
   &error);
 
   read(standard_output, buf, sizeof(buf));
-  version_string = regex_parse_version_number(buf);
+  return regex_parse_version_number(buf);
+
+}
+int
+check_lily_version (gchar *version)
+{
+  gchar *  version_string = get_lily_version_string();
   lilyversion installed_version = string_to_lilyversion(version_string);
   lilyversion check_version = string_to_lilyversion(version);
-
   return version_check(check_version, installed_version);
 }
 #endif
@@ -368,8 +373,8 @@ run_lilypond(gchar *filename, DenemoGUI *gui){
   gchar *lilyfile = g_strconcat (filename, ".ly", NULL);
   gchar *resolution = g_strdup_printf("-dresolution=%d",(int) Denemo.prefs.resolution);
   gchar *printfile = g_strconcat (filename, "_", NULL);
-  /* Check Lilypond Version */
-  //if (get_lily_version("2.12") != SAME)
+  /* Check if Lilypond Version is set for this file, if so it may need conversion */
+  if(gui->lilycontrol.lilyversion->len)
     convert_ly(lilyfile);
 
 #if GLIB_MINOR_VERSION >= 14
@@ -396,7 +401,7 @@ run_lilypond(gchar *filename, DenemoGUI *gui){
     NULL
   };
   
-  if (get_lily_version("2.12") >= 1)
+  if (check_lily_version("2.12") >= 1)
      arguments = png_arguments1;
   else
      arguments = png_arguments2;
@@ -575,16 +580,101 @@ printrangedialog(DenemoGUI * gui){
 }
 
 
-/* callback to print whole of score */
-void
-printall_cb (GtkAction *action, gpointer param) {
-  DenemoGUI *gui = Denemo.gui;
-  gui->lilycontrol.excerpt = FALSE;
-  gchar *str = g_strdup_printf("No direct printing yet\nWe will run the PDF viewer program %s so you can use its print command.\nYou can change the PDF viewer using \nEdit->Preferences->Externals->Pdf viewer.", Denemo.prefs.pdfviewer->str);
-  warningdialog(str);
-  g_free(str);
-  print(gui, FALSE, TRUE);
+static   cairo_surface_t *the_surface;
+static gdouble repeat_length;
+static void
+begin_print (GtkPrintOperation *operation,
+	     GtkPrintContext   *context)
+{
+
+  gchar *filename = get_printfile_pathbasename();
+  gchar *path = g_strconcat (filename, "_.png", NULL);
+  g_free(filename);
+  the_surface = cairo_image_surface_create_from_png (path);
+  g_free(path);
+  int src_width = cairo_image_surface_get_width(the_surface);//PIXELS
+  int src_height = cairo_image_surface_get_height(the_surface);
+
+  double page_height =  1.414*((double)src_width);
+  //g_print("Estimated page height from width %f giving %f pages\n", page_height, src_height/page_height);
+  int num_pages = (int)(0.5+src_height/page_height);
+  repeat_length = src_height/num_pages +1.0;
+  //g_print("Estimated page height from width %f giving %f pages\nRepeat length %f", page_height, src_height/page_height, repeat_length);
+  gtk_print_operation_set_n_pages (operation, num_pages);
+  gtk_print_operation_set_use_full_page(operation, TRUE);
 }
+
+
+/***********************************
+We divide the .png image into pages.
+ we use the page_nr parameter to choose the n'th page-sized chunk of the .png surface.
+ paper size in points:
+
+Letter		 612x792
+LetterSmall	 612x792
+Tabloid		 792x1224
+Ledger		1224x792
+Legal		 612x1008
+Statement	 396x612
+Executive	 540x720
+A0               2384x3371
+A1              1685x2384
+A2		1190x1684
+A3		 842x1190
+A4		 595x842
+A4Small		 595x842
+A5		 420x595
+B4		 729x1032
+B5		 516x729
+Envelope	 ???x???
+Folio		 612x936
+Quarto		 610x780
+10x14		 720x1008
+
+
+*********************/
+static void
+draw_page (GtkPrintOperation *operation,
+	   GtkPrintContext   *context,
+	   gint               page_nr)
+{
+  cairo_t * cr = gtk_print_context_get_cairo_context (context);
+
+  int src_width = cairo_image_surface_get_width(the_surface);//PIXELS
+  int src_height = cairo_image_surface_get_height(the_surface);
+  int page_origin_x = 0;
+  int page_origin_y = 0;
+  static double scale = 1.414;
+  //g_print("width %d height %d\n", src_width, src_height);
+  double page_height =  scale*src_width;
+  int num_pages = (int)(0.5 + src_height/page_height);
+  //g_print("Have %d pages of page height %f at page number %d\n", num_pages, page_height, page_nr);
+
+  cairo_status_t  status = cairo_surface_status(the_surface);
+  if(status != CAIRO_STATUS_SUCCESS)
+    g_print("An error %d\n", status);
+  if(page_nr>=num_pages) {
+    g_warning("called for page_nr %d\n", page_nr+1);
+    gtk_print_operation_cancel (operation);
+    //cairo_surface_destroy (the_surface); the_surface = NULL;
+  }
+  else {
+
+    double margin = 15.0;
+    //cairo_rotate (cr, 45* 3.1418/180); works
+    cairo_scale (cr, 70.0/180.0, 70.0/180.0);
+    cairo_translate(cr, 4*margin,  4*margin   );
+    cairo_set_source_surface (cr, the_surface, 0.0 /*2*margin*/,   - (double)(repeat_length*page_nr));
+    cairo_rectangle (cr, 0.0, 0.0, (double)src_width+2*margin, (double)repeat_length);
+    cairo_fill (cr);
+  }
+  if(page_nr==num_pages-1)
+    g_print("Finished printing\n");
+  else
+    g_print("returning from drawing page %d\n", page_nr+1);
+}
+
+
 /* callback to print current part (staff) of score */
 void
 printpart_cb (GtkAction *action, gpointer param) {
@@ -789,6 +879,46 @@ static gint offsetx, offsety;
 
 static gint curx, cury;// position of mouse pointer while during motion
 static gint pointx, pointy,  markx, marky;//coordinates defining a selected region in print preview pane. These are set by left button press/release, with pointx, pointy being set to top left
+
+
+static GtkPrintSettings *settings;
+/* print the score as stored in .png image generated by LilyPond. */
+static void
+printall(void) {
+  //g_print("print all");
+  GtkPrintOperation *operation;
+  gint res;
+  GError *error = NULL;
+  operation = gtk_print_operation_new ();
+  if (settings != NULL)
+    gtk_print_operation_set_print_settings (operation, settings);
+
+  g_signal_connect (operation, "begin-print",
+		    G_CALLBACK (begin_print), NULL);
+  g_signal_connect (operation, "draw-page",
+		    G_CALLBACK (draw_page), NULL);
+
+  res = gtk_print_operation_run (operation, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG,
+				 GTK_WINDOW (Denemo.window), &error);
+  if (res == GTK_PRINT_OPERATION_RESULT_APPLY) {
+    if (settings != NULL)
+      g_object_unref (settings);
+    settings = g_object_ref (gtk_print_operation_get_print_settings (operation));
+  }
+  else if (error) {
+    GtkWidget *dialog;
+    dialog = gtk_message_dialog_new (GTK_WINDOW (Denemo.window),
+				     GTK_DIALOG_NO_SEPARATOR,
+				     GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+				     "%s", error->message);
+    g_error_free (error);
+    gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy (dialog);
+  }
+  g_object_unref (operation);
+}
+
+
 static void draw_print(DenemoGUI *gui) {
   gint x, y;
   GtkAdjustment * adjust = gtk_range_get_adjustment(GTK_RANGE(gui->printhscrollbar));
@@ -864,7 +994,8 @@ process_printpreview_errors(void){
   g_free(bytes);
 }
 static void
-printview_finished(void) {
+printview_finished(GPid pid, gint status, gboolean preview_only) {
+  // g_print("printview finished with preview_only set %d", preview_only);
   DenemoGUI *gui = Denemo.gui;
   g_spawn_close_pid (printviewpid);
   printviewpid = GPID_NONE;
@@ -890,12 +1021,15 @@ printview_finished(void) {
    }
  g_object_set_data(G_OBJECT(Denemo.gui->printarea), "printviewupdate", (gpointer) changecount);
  gtk_widget_queue_draw (gui->printarea);
+ 
+ if(!preview_only)
+   printall();
 }
 
-void refresh_print_view (void) {
+void refresh_print_view (gboolean preview_only) {
   DenemoGUI *gui = Denemo.gui;
   GError *error = NULL;
-  //g_print("printviewpid %d\n", printviewpid);
+  //g_print("preview only %d\n", preview_only);
   if((changecount == Denemo.gui->changecount) && ((gint)g_object_get_data(G_OBJECT(Denemo.gui->printarea), "printviewupdate")==Denemo.gui->changecount)) {
     if(confirm ("No changes since last update", "Cancel refresh of print view?"))
       return;
@@ -924,6 +1058,8 @@ void refresh_print_view (void) {
   // run_lilypond_and_viewer(filename, gui);
   gchar *printfile = g_strconcat (filename, "_", NULL);
   gchar *resolution = "-dresolution=180";
+
+
 #if GLIB_MINOR_VERSION >= 14
   gchar **arguments;
   gchar *arguments1[] = {
@@ -947,7 +1083,7 @@ void refresh_print_view (void) {
     lilyfile,
     NULL
   };
-  if (get_lily_version("2.12") >= 1)
+  if (check_lily_version("2.12") >= 1)
    arguments = arguments1;
   else
     arguments = arguments2;
@@ -979,9 +1115,24 @@ void refresh_print_view (void) {
 	         &printpreview_errors,		/* stderr */
 		 &error);
   g_free(lilyfile);
-  g_child_watch_add (printviewpid, (GChildWatchFunc)printview_finished  /*  GChildWatchFunc function */, NULL);
+  g_child_watch_add (printviewpid, (GChildWatchFunc)printview_finished  /*  GChildWatchFunc function */, preview_only);
 }
 
+/* callback to print whole of score */
+
+void
+printall_cb (GtkAction *action, gpointer param) {
+  DenemoGUI *gui = Denemo.gui;
+  gui->lilycontrol.excerpt = FALSE;
+  gchar *str = g_strdup_printf("Direct printing is experimental - use print preview otherwise after setting pdf viewer in prefs (currently %s).", Denemo.prefs.pdfviewer->str);
+  warningdialog(str);
+  g_free(str);
+  //g_print("changecount %d %d %d \n", changecount, Denemo.gui->changecount, (gint)g_object_get_data(G_OBJECT(Denemo.gui->printarea), "printviewupdate"));
+  if((changecount == Denemo.gui->changecount) && ((gint)g_object_get_data(G_OBJECT(Denemo.gui->printarea), "printviewupdate")==Denemo.gui->changecount)) 
+    printall();
+  else
+    refresh_print_view(FALSE);//calls printall when lilypond has finished.
+}
 
 
 //static gint 
@@ -1001,7 +1152,7 @@ popup_print_preview_menu(void) {
   GtkWidget *item = gtk_menu_item_new_with_label("Refresh Print Preview");
 
   gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
-  g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(refresh_print_view), NULL);
+  g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(refresh_print_view), TRUE);
   item = gtk_menu_item_new_with_label("Drag to desired offset");
   gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
   g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(start_drag), &offsetting);
@@ -1127,7 +1278,8 @@ printarea_button_press (GtkWidget * widget, GdkEventButton * event)
   /* creating an offset? */
   if(offsetting) {
     offsetx = curx - markx;
-    offsety = cury - marky;   
+    offsety = cury - marky;  
+
     GtkWidget *thedialog = g_object_get_data(G_OBJECT(Denemo.gui->printarea), "offset-dialog");
     g_object_set_data(G_OBJECT(Denemo.gui->printarea), "offsetx", (gpointer)offsetx);
     g_object_set_data(G_OBJECT(Denemo.gui->printarea), "offsety", (gpointer)offsety);
@@ -1143,7 +1295,8 @@ printarea_button_press (GtkWidget * widget, GdkEventButton * event)
   }
   /*( creating a padding value? */
   if(padding) {
-    gint pad = ABS(curx - markx);
+    gint pad = ABS(curx - markx); 
+
     GtkWidget *thedialog = g_object_get_data(G_OBJECT(Denemo.gui->printarea), "pad-dialog");
     g_object_set_data(G_OBJECT(Denemo.gui->printarea), "padding", (gpointer)pad);
     if(thedialog){
@@ -1180,9 +1333,6 @@ printarea_button_release (GtkWidget * widget, GdkEventButton * event)
   if(!left) {
         return TRUE;
   }
-
-
-
   if(Denemo.gui->pixbuf==NULL)
     return TRUE;
   if(selecting) {
@@ -1193,14 +1343,13 @@ printarea_button_release (GtkWidget * widget, GdkEventButton * event)
 
     width = pointx-markx;
     height = pointy-marky;
+    GtkIconFactory *icon_factory = gtk_icon_factory_new ();
+    GdkPixbuf *sub_pixbuf = gdk_pixbuf_new_subpixbuf (Denemo.gui->pixbuf, markx+adjust_x, marky+adjust_y, width, height);
 
-    GdkPixbuf *alphapixbuf = gdk_pixbuf_add_alpha (Denemo.gui->pixbuf, TRUE, 255, 255, 255);
-    if(alphapixbuf){
-      //   gchar *data =  create_xbm_data_from_pixbuf(alphapixbuf, markx, marky, pointx, pointy);
-      gchar *data =  create_xbm_data_from_pixbuf(alphapixbuf, markx+adjust_x, marky+adjust_y, pointx+adjust_x, pointy+adjust_y);
-      g_print("Used adjust x y %d, %d\n", adjust_x, adjust_y);
-      GtkIconFactory *icon_factory = gtk_icon_factory_new ();
-      GdkPixbuf *sub_pixbuf = gdk_pixbuf_new_subpixbuf (Denemo.gui->pixbuf, markx+adjust_x, marky+adjust_y, width, height);
+    GdkPixbuf *alphapixbuf = gdk_pixbuf_add_alpha (sub_pixbuf, TRUE, 255, 255, 255);
+    GdkPixbuf *scaledpixbuf = gdk_pixbuf_scale_simple(alphapixbuf, width, height,GDK_INTERP_BILINEAR);
+    if(scaledpixbuf) {
+      gchar *data =  create_xbm_data_from_pixbuf(scaledpixbuf, 0, 0, width, height);
 
       GtkIconSet *icon_set = gtk_icon_set_new_from_pixbuf (sub_pixbuf);
       g_object_unref(sub_pixbuf);
