@@ -3,6 +3,9 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "CursorDo
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "CursorUp"), "CursorUp", "Cursor Up", "Moves the cursor one scale step up", cursorup);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "CursorRight"), "CursorRight", "Cursor Right", "Moves the cursor one object right, altering the selection if any", cursorright);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "GoToMark"), "GoToMark", "To Mark", "Moves the cursor to the Mark without altering the selection", goto_mark);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "PushPosition"), "PushPosition", "Push Position", "Pushes the current cursor position onto a stack", PushPosition);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "PopPosition"), "PopPosition", "Pop Position", "Pops a position from the stack of cursor positions, moving the cursor there", PopPosition);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "PopPushPosition"), "PopPushPosition", "Pop and Push Position", "Pops a position from the stack of cursor positions, pushes the current position, then moves the cursor to the popped position", PopPushPosition);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "StaffUp"), "StaffUp", "Staff Up", "Moves the cursor to the staff above", staffup);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "StaffDown"), "StaffDown", "Staff Down", "Moves the cursor to the staff below", staffdown);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "MeasureLeft"), "MeasureLeft", "Measure Left", "Moves the cursor to the first object in the next measure", measureleft);
@@ -23,6 +26,8 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "EighthNo
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SixteenthNote"), "SixteenthNote", ""MUSIC_FONT("4")"", "Insert sixteenth-note", insert_chord_4key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ThirtysecondNote"), "ThirtysecondNote", ""MUSIC_FONT("5")"", "Insert thirty-second-note", insert_chord_5key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SixtyfourthNote"), "SixtyfourthNote", ""MUSIC_FONT("6")"", "Insert sixty-fourth-note", insert_chord_6key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "OneHundredTwentyEighthNote"), "OneHundredTwentyEighthNote", "128th", "Insert 128th-note", insert_chord_7key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "TwoHundredFiftySixthNote"), "TwoHundredFiftySixthNote", "256th", "Insert 256th-note", insert_chord_8key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertBlankWholeNote"), "InsertBlankWholeNote", "Insert Blank Whole Note", "No Tooltip yet", insert_blankchord_0key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertBlankHalfNote"), "InsertBlankHalfNote", "Insert Blank Half Note", "No Tooltip yet", insert_blankchord_1key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertBlankQuarterNote"), "InsertBlankQuarterNote", "Insert Blank Quarter Note", "No Tooltip yet", insert_blankchord_2key);
@@ -30,6 +35,8 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertBl
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertBlankSixteenthNote"), "InsertBlankSixteenthNote", "Insert Blank Sixteenth Note", "No Tooltip yet", insert_blankchord_4key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertBlankThirtysecondNote"), "InsertBlankThirtysecondNote", "Insert Blank Thirty Second Note", "No Tooltip yet", insert_blankchord_5key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertBlankSixtyfourthNote"), "InsertBlankSixtyfourthNote", "Insert Blank Sixty Forth Note", "No Tooltip yet", insert_blankchord_6key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertBlankOneHundredTwentyEighthNote"), "InsertBlankOneHundredTwentyEighthNote", "Insert Blank one hundred and twenty eighth Note", "No Tooltip yet", insert_blankchord_7key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertBlankTwoHundredFiftySixthNote"), "InsertBlankTwoHundredFiftySixthNote", "Insert Blank two hundred and fifty sixth Note", "No Tooltip yet", insert_blankchord_8key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleRestMode"), "ToggleRestMode", "Toggle Rest Mode", "No Tooltip yet", rest_toggle_key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleBlankMode"), "ToggleBlankMode", "Toggle Blank Mode", "No Tooltip yet", toggle_blank);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertWholeRest"), "InsertWholeRest", ""MUSIC_FONT("r")"", "Insert whole-note rest", insert_rest_0key);
@@ -59,9 +66,12 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertTi
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ToggleTie"), "ToggleTie", "Toggle Tie", "Ties/unties the note at the cursor", toggle_tie);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteObject"), "DeleteObject", "Delete Object", "Delete the object at the cursor", deleteobject);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeletePreviousObject"), "DeletePreviousObject", "Delete Previous Object", "Delete to the left of the cursor.", deletepreviousobject);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertMeasure"), "InsertMeasure", "Insert Measure", "Insert a blank measure before the current one (in all staffs)", insert_measure_key);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "AppendMeasure"), "AppendMeasure", "Append Measure", "No Tooltip yet", append_measure_key);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteMeasure"), "DeleteMeasure", "Delete Measure", "Delete the current measure in this staff, leaving the staff short", deletemeasure);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertMeasure"), "InsertMeasure", "Insert Measure Before", "Insert a blank measure before the current one (in all staffs)", insert_measure_key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddMeasure"), "AddMeasure", "Insert Measure After", "Insert a blank measure after the current one (in all staffs)", addmeasureafter);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertMeasureBefore"), "InsertMeasureBefore", "Staff Insert Measure Before", "Insert a blank measure before the current one (in current staff)", insertmeasurebefore);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertMeasureAfter"), "InsertMeasureAfter", "Staff Insert Measure After", "Insert a blank measure in current staff after the current measure", insertmeasureafter);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AppendMeasure"), "AppendMeasure", "Staff Append Measure", "No Tooltip yet", append_measure_key);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteMeasure"), "DeleteMeasure", "Staff Delete Measure", "Delete the current measure in this staff, leaving the staff short", deletemeasure);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteMeasureAllStaffs"), "DeleteMeasureAllStaffs", "Delete Measure All Staffs", "Delete the current measure in all staffs", deletemeasureallstaffs);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ShrinkMeasures"), "ShrinkMeasures", "Shrink Measure", "No Tooltip yet", adjust_measure_less_width_key);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "WidenMeasures"), "WidenMeasures", "Widen Measures", "No Tooltip yet", adjust_measure_more_width_key);
@@ -195,7 +205,8 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "ForceCau
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangePitch"), "ChangePitch", "Change Pitch", "No Tooltip yet", change_pitch);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRhythm"), "InsertRhythm", "Insert Rhythm", "No Tooltip yet", insert_rhythm_pattern);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "NextRhythm"), "NextRhythm", "Next Rhythm", "Make next rhythm pattern\nthe prevailing rhythm.\nNotes entered will follow this pattern", nextrhythm);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "AppendMeasuresToScore"), "AppendMeasuresToScore", "Append Measure To Score", "No Tooltip yet", append_measure_score);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "AppendMeasureAllStaffs"), "AppendMeasureAllStaffs", "Append Measure All Staffs", "Appends a blank measure to every staff in this movement", append_measure_score);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "ExecuteScheme"), "ExecuteScheme", "Execute Scheme", "Execute the scheme code from the scripting window", execute_scheme);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SharpenEnharmonicSet"), "SharpenEnharmonicSet", "Shift Accidentals Sharpwise", "Shifts the set of accidentals one step sharper", set_sharper);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "FlattenEnharmonicSet"), "FlattenEnharmonicSet", "Shift Accidentals Flatwise", "Shifts the set of accidentals one step flatter", set_flatter);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "New"), "New", "New File", "Start a new musical score", file_newwrapper);
@@ -228,7 +239,6 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "Undo"),
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Redo"), "Redo", "Redo", "Redo", redowrapper);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Copy"), "Copy", "Copy", "Copy", copywrapper);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Cut"), "Cut", "Cut", "Cut", cutwrapper);
-register_command(Denemo.map, gtk_action_group_get_action(action_group, "Paste"), "Paste", "Paste", "Paste the selected music", pastewrapper);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "PasteClipboard"), "PasteClipboard", "Paste LilyPond notes", "Paste LilyPond notes from the text clipboard", paste_clipboard);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ScoreProperties"), "ScoreProperties", "Score Properties", "Change some of the properties of the current score. This will start up a dialog window", score_properties_dialog);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "SaveSelection"), "SaveSelection", "Save Selection", "Save the selected music. Not sure if this is working", saveselwrapper);
@@ -261,6 +271,8 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertSt
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "AddVerse"), "AddVerse", "Add Lyric Verse", "Add a verse of lyrics", add_verse);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteVerse"), "DeleteVerse", "Delete Verse", "Deletes current verse of lyrics from current voice", delete_verse);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditFiguredBass"), "EditFiguredBass", "Insert/Edit Figured Bass", "Add a bass figure to the current note. Use | sign to split the duration of a note so as to have multiple figures on one note. See Lilypond docs for other notation", figure_insert);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "DeleteFiguredBass"), "DeleteFiguredBass", "Delete Figures", "Delete the figured bass on the current staff", delete_figured_bass);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "HideFiguredBass"), "HideFiguredBass", "Hide Figures (Print)", "Hide the figured bass on the current staff on printing", hide_figured_bass);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "EditChords"), "EditChords", "Edit Chord Symbols", "Allows chord symbols to be added to the current note. E.G.cis:dim7 for c-sharp diminished 7th. See Lilypond docs for notation", fakechord_insert);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertDynamic"), "InsertDynamic", "Insert Dynamics", "Inserts a dynamic marking at the cursor position", insert_dynamic);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertLilyDirective"), "InsertLilyDirective", "Insert Lilypond", "Insert or edit a directive in the LilyPond music typesetting language. This can be used for extra spacing, transposing or almost anything. See LilyPond documentation for ideas.", standalone_directive);
@@ -317,33 +329,52 @@ register_command(Denemo.map, gtk_action_group_get_action(action_group, "Change0"
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Insert0"), "Insert0", N_(MUSIC_FONT("0")), N_("Insert a "MUSIC_FONT("0")), InsertDur0);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRest0"), "InsertRest0",  N_("Insert a "MUSIC_FONT("0")"rest") ,  N_("Inserts a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("0")), InsertRest0);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeRest0"), "ChangeRest0",  N_("Change a "MUSIC_FONT("0")"rest") ,  N_("Changes a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("0")), ChangeRest0);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Set0"), "Set0", N_(MUSIC_FONT("0")), N_("Set the prevailing duration to "MUSIC_FONT("0")), SetDur0);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "1"), "1", N_(MUSIC_FONT("1")), N_("In insert mode, changes prevailing rhythm to "MUSIC_FONT("1")"\nIn edit mode changes the current note to "MUSIC_FONT("1")"\n or appends a "MUSIC_FONT("1")" if no current note\nIn classic mode inserts a "MUSIC_FONT("1")" at the cursor"), Dur1);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Change1"), "Change1", N_(MUSIC_FONT("1")), N_("Change the current note to a "MUSIC_FONT("1")), ChangeDur1);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Insert1"), "Insert1", N_(MUSIC_FONT("1")), N_("Insert a "MUSIC_FONT("1")), InsertDur1);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRest1"), "InsertRest1",  N_("Insert a "MUSIC_FONT("1")"rest") ,  N_("Inserts a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("1")), InsertRest1);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeRest1"), "ChangeRest1",  N_("Change a "MUSIC_FONT("1")"rest") ,  N_("Changes a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("1")), ChangeRest1);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Set1"), "Set1", N_(MUSIC_FONT("1")), N_("Set the prevailing duration to "MUSIC_FONT("1")), SetDur1);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "2"), "2", N_(MUSIC_FONT("2")), N_("In insert mode, changes prevailing rhythm to "MUSIC_FONT("2")"\nIn edit mode changes the current note to "MUSIC_FONT("2")"\n or appends a "MUSIC_FONT("2")" if no current note\nIn classic mode inserts a "MUSIC_FONT("2")" at the cursor"), Dur2);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Change2"), "Change2", N_(MUSIC_FONT("2")), N_("Change the current note to a "MUSIC_FONT("2")), ChangeDur2);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Insert2"), "Insert2", N_(MUSIC_FONT("2")), N_("Insert a "MUSIC_FONT("2")), InsertDur2);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRest2"), "InsertRest2",  N_("Insert a "MUSIC_FONT("2")"rest") ,  N_("Inserts a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("2")), InsertRest2);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeRest2"), "ChangeRest2",  N_("Change a "MUSIC_FONT("2")"rest") ,  N_("Changes a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("2")), ChangeRest2);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Set2"), "Set2", N_(MUSIC_FONT("2")), N_("Set the prevailing duration to "MUSIC_FONT("2")), SetDur2);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "3"), "3", N_(MUSIC_FONT("3")), N_("In insert mode, changes prevailing rhythm to "MUSIC_FONT("3")"\nIn edit mode changes the current note to "MUSIC_FONT("3")"\n or appends a "MUSIC_FONT("3")" if no current note\nIn classic mode inserts a "MUSIC_FONT("3")" at the cursor"), Dur3);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Change3"), "Change3", N_(MUSIC_FONT("3")), N_("Change the current note to a "MUSIC_FONT("3")), ChangeDur3);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Insert3"), "Insert3", N_(MUSIC_FONT("3")), N_("Insert a "MUSIC_FONT("3")), InsertDur3);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRest3"), "InsertRest3",  N_("Insert a "MUSIC_FONT("3")"rest") ,  N_("Inserts a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("3")), InsertRest3);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeRest3"), "ChangeRest3",  N_("Change a "MUSIC_FONT("3")"rest") ,  N_("Changes a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("3")), ChangeRest3);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Set3"), "Set3", N_(MUSIC_FONT("3")), N_("Set the prevailing duration to "MUSIC_FONT("3")), SetDur3);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "4"), "4", N_(MUSIC_FONT("4")), N_("In insert mode, changes prevailing rhythm to "MUSIC_FONT("4")"\nIn edit mode changes the current note to "MUSIC_FONT("4")"\n or appends a "MUSIC_FONT("4")" if no current note\nIn classic mode inserts a "MUSIC_FONT("4")" at the cursor"), Dur4);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Change4"), "Change4", N_(MUSIC_FONT("4")), N_("Change the current note to a "MUSIC_FONT("4")), ChangeDur4);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Insert4"), "Insert4", N_(MUSIC_FONT("4")), N_("Insert a "MUSIC_FONT("4")), InsertDur4);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRest4"), "InsertRest4",  N_("Insert a "MUSIC_FONT("4")"rest") ,  N_("Inserts a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("4")), InsertRest4);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeRest4"), "ChangeRest4",  N_("Change a "MUSIC_FONT("4")"rest") ,  N_("Changes a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("4")), ChangeRest4);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Set4"), "Set4", N_(MUSIC_FONT("4")), N_("Set the prevailing duration to "MUSIC_FONT("4")), SetDur4);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "5"), "5", N_(MUSIC_FONT("5")), N_("In insert mode, changes prevailing rhythm to "MUSIC_FONT("5")"\nIn edit mode changes the current note to "MUSIC_FONT("5")"\n or appends a "MUSIC_FONT("5")" if no current note\nIn classic mode inserts a "MUSIC_FONT("5")" at the cursor"), Dur5);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Change5"), "Change5", N_(MUSIC_FONT("5")), N_("Change the current note to a "MUSIC_FONT("5")), ChangeDur5);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Insert5"), "Insert5", N_(MUSIC_FONT("5")), N_("Insert a "MUSIC_FONT("5")), InsertDur5);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRest5"), "InsertRest5",  N_("Insert a "MUSIC_FONT("5")"rest") ,  N_("Inserts a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("5")), InsertRest5);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeRest5"), "ChangeRest5",  N_("Change a "MUSIC_FONT("5")"rest") ,  N_("Changes a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("5")), ChangeRest5);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Set5"), "Set5", N_(MUSIC_FONT("5")), N_("Set the prevailing duration to "MUSIC_FONT("5")), SetDur5);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "6"), "6", N_(MUSIC_FONT("6")), N_("In insert mode, changes prevailing rhythm to "MUSIC_FONT("6")"\nIn edit mode changes the current note to "MUSIC_FONT("6")"\n or appends a "MUSIC_FONT("6")" if no current note\nIn classic mode inserts a "MUSIC_FONT("6")" at the cursor"), Dur6);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Change6"), "Change6", N_(MUSIC_FONT("6")), N_("Change the current note to a "MUSIC_FONT("6")), ChangeDur6);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "Insert6"), "Insert6", N_(MUSIC_FONT("6")), N_("Insert a "MUSIC_FONT("6")), InsertDur6);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRest6"), "InsertRest6",  N_("Insert a "MUSIC_FONT("6")"rest") ,  N_("Inserts a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("6")), InsertRest6);
 register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeRest6"), "ChangeRest6",  N_("Change a "MUSIC_FONT("6")"rest") ,  N_("Changes a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("6")), ChangeRest6);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Set6"), "Set6", N_(MUSIC_FONT("6")), N_("Set the prevailing duration to "MUSIC_FONT("6")), SetDur6);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "7"), "7", N_(MUSIC_FONT("7")), N_("In insert mode, changes prevailing rhythm to "MUSIC_FONT("7")"\nIn edit mode changes the current note to "MUSIC_FONT("7")"\n or appends a "MUSIC_FONT("7")" if no current note\nIn classic mode inserts a "MUSIC_FONT("7")" at the cursor"), Dur7);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Change7"), "Change7", N_(MUSIC_FONT("7")), N_("Change the current note to a "MUSIC_FONT("7")), ChangeDur7);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Insert7"), "Insert7", N_(MUSIC_FONT("7")), N_("Insert a "MUSIC_FONT("7")), InsertDur7);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRest7"), "InsertRest7",  N_("Insert a "MUSIC_FONT("7")"rest") ,  N_("Inserts a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("7")), InsertRest7);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeRest7"), "ChangeRest7",  N_("Change a "MUSIC_FONT("7")"rest") ,  N_("Changes a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("7")), ChangeRest7);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Set7"), "Set7", N_(MUSIC_FONT("7")), N_("Set the prevailing duration to "MUSIC_FONT("7")), SetDur7);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "8"), "8", N_(MUSIC_FONT("8")), N_("In insert mode, changes prevailing rhythm to "MUSIC_FONT("8")"\nIn edit mode changes the current note to "MUSIC_FONT("8")"\n or appends a "MUSIC_FONT("8")" if no current note\nIn classic mode inserts a "MUSIC_FONT("8")" at the cursor"), Dur8);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Change8"), "Change8", N_(MUSIC_FONT("8")), N_("Change the current note to a "MUSIC_FONT("8")), ChangeDur8);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Insert8"), "Insert8", N_(MUSIC_FONT("8")), N_("Insert a "MUSIC_FONT("8")), InsertDur8);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "InsertRest8"), "InsertRest8",  N_("Insert a "MUSIC_FONT("8")"rest") ,  N_("Inserts a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("8")), InsertRest8);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "ChangeRest8"), "ChangeRest8",  N_("Change a "MUSIC_FONT("8")"rest") ,  N_("Changes a rest at cursor position\nSets prevailing rhythm to "MUSIC_FONT("8")), ChangeRest8);
+register_command(Denemo.map, gtk_action_group_get_action(action_group, "Set8"), "Set8", N_(MUSIC_FONT("8")), N_("Set the prevailing duration to "MUSIC_FONT("8")), SetDur8);
