@@ -19,6 +19,18 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "CursorRight")), "scm", (g
 SCM scheme_GoToMark(SCM optional);
 install_scm_function ("d-GoToMark", scheme_GoToMark);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "GoToMark")), "scm", (gpointer)1);
+/*PushPosition PushPosition*/
+SCM scheme_PushPosition(SCM optional);
+install_scm_function ("d-PushPosition", scheme_PushPosition);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "PushPosition")), "scm", (gpointer)1);
+/*PopPosition PopPosition*/
+SCM scheme_PopPosition(SCM optional);
+install_scm_function ("d-PopPosition", scheme_PopPosition);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "PopPosition")), "scm", (gpointer)1);
+/*PopPushPosition PopPushPosition*/
+SCM scheme_PopPushPosition(SCM optional);
+install_scm_function ("d-PopPushPosition", scheme_PopPushPosition);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "PopPushPosition")), "scm", (gpointer)1);
 /*StaffUp staffup*/
 SCM scheme_StaffUp(SCM optional);
 install_scm_function ("d-StaffUp", scheme_StaffUp);
@@ -99,6 +111,14 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ThirtysecondNote")), "scm
 SCM scheme_SixtyfourthNote(SCM optional);
 install_scm_function ("d-SixtyfourthNote", scheme_SixtyfourthNote);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "SixtyfourthNote")), "scm", (gpointer)1);
+/*OneHundredTwentyEighthNote insert_chord_7key*/
+SCM scheme_OneHundredTwentyEighthNote(SCM optional);
+install_scm_function ("d-OneHundredTwentyEighthNote", scheme_OneHundredTwentyEighthNote);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "OneHundredTwentyEighthNote")), "scm", (gpointer)1);
+/*TwoHundredFiftySixthNote insert_chord_8key*/
+SCM scheme_TwoHundredFiftySixthNote(SCM optional);
+install_scm_function ("d-TwoHundredFiftySixthNote", scheme_TwoHundredFiftySixthNote);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "TwoHundredFiftySixthNote")), "scm", (gpointer)1);
 /*InsertBlankWholeNote insert_blankchord_0key*/
 SCM scheme_InsertBlankWholeNote(SCM optional);
 install_scm_function ("d-InsertBlankWholeNote", scheme_InsertBlankWholeNote);
@@ -127,6 +147,14 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertBlankThirtysecondNo
 SCM scheme_InsertBlankSixtyfourthNote(SCM optional);
 install_scm_function ("d-InsertBlankSixtyfourthNote", scheme_InsertBlankSixtyfourthNote);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertBlankSixtyfourthNote")), "scm", (gpointer)1);
+/*InsertBlankOneHundredTwentyEighthNote insert_blankchord_7key*/
+SCM scheme_InsertBlankOneHundredTwentyEighthNote(SCM optional);
+install_scm_function ("d-InsertBlankOneHundredTwentyEighthNote", scheme_InsertBlankOneHundredTwentyEighthNote);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertBlankOneHundredTwentyEighthNote")), "scm", (gpointer)1);
+/*InsertBlankTwoHundredFiftySixthNote insert_blankchord_8key*/
+SCM scheme_InsertBlankTwoHundredFiftySixthNote(SCM optional);
+install_scm_function ("d-InsertBlankTwoHundredFiftySixthNote", scheme_InsertBlankTwoHundredFiftySixthNote);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertBlankTwoHundredFiftySixthNote")), "scm", (gpointer)1);
 /*ToggleRestMode rest_toggle_key*/
 SCM scheme_ToggleRestMode(SCM optional);
 install_scm_function ("d-ToggleRestMode", scheme_ToggleRestMode);
@@ -247,6 +275,18 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "DeletePreviousObject")),
 SCM scheme_InsertMeasure(SCM optional);
 install_scm_function ("d-InsertMeasure", scheme_InsertMeasure);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertMeasure")), "scm", (gpointer)1);
+/*AddMeasure addmeasureafter*/
+SCM scheme_AddMeasure(SCM optional);
+install_scm_function ("d-AddMeasure", scheme_AddMeasure);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AddMeasure")), "scm", (gpointer)1);
+/*InsertMeasureBefore insertmeasurebefore*/
+SCM scheme_InsertMeasureBefore(SCM optional);
+install_scm_function ("d-InsertMeasureBefore", scheme_InsertMeasureBefore);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertMeasureBefore")), "scm", (gpointer)1);
+/*InsertMeasureAfter insertmeasureafter*/
+SCM scheme_InsertMeasureAfter(SCM optional);
+install_scm_function ("d-InsertMeasureAfter", scheme_InsertMeasureAfter);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertMeasureAfter")), "scm", (gpointer)1);
 /*AppendMeasure append_measure_key*/
 SCM scheme_AppendMeasure(SCM optional);
 install_scm_function ("d-AppendMeasure", scheme_AppendMeasure);
@@ -787,10 +827,14 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertRhythm")), "scm", (
 SCM scheme_NextRhythm(SCM optional);
 install_scm_function ("d-NextRhythm", scheme_NextRhythm);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "NextRhythm")), "scm", (gpointer)1);
-/*AppendMeasuresToScore append_measure_score*/
-SCM scheme_AppendMeasuresToScore(SCM optional);
-install_scm_function ("d-AppendMeasuresToScore", scheme_AppendMeasuresToScore);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AppendMeasuresToScore")), "scm", (gpointer)1);
+/*AppendMeasureAllStaffs append_measure_score*/
+SCM scheme_AppendMeasureAllStaffs(SCM optional);
+install_scm_function ("d-AppendMeasureAllStaffs", scheme_AppendMeasureAllStaffs);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "AppendMeasureAllStaffs")), "scm", (gpointer)1);
+/*ExecuteScheme execute_scheme*/
+SCM scheme_ExecuteScheme(SCM optional);
+install_scm_function ("d-ExecuteScheme", scheme_ExecuteScheme);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ExecuteScheme")), "scm", (gpointer)1);
 /*SharpenEnharmonicSet set_sharper*/
 SCM scheme_SharpenEnharmonicSet(SCM optional);
 install_scm_function ("d-SharpenEnharmonicSet", scheme_SharpenEnharmonicSet);
@@ -919,10 +963,6 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Copy")), "scm", (gpointer
 SCM scheme_Cut(SCM optional);
 install_scm_function ("d-Cut", scheme_Cut);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Cut")), "scm", (gpointer)1);
-/*Paste pastewrapper*/
-SCM scheme_Paste(SCM optional);
-install_scm_function ("d-Paste", scheme_Paste);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Paste")), "scm", (gpointer)1);
 /*PasteClipboard paste_clipboard*/
 SCM scheme_PasteClipboard(SCM optional);
 install_scm_function ("d-PasteClipboard", scheme_PasteClipboard);
@@ -1051,6 +1091,14 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "DeleteVerse")), "scm", (g
 SCM scheme_EditFiguredBass(SCM optional);
 install_scm_function ("d-EditFiguredBass", scheme_EditFiguredBass);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditFiguredBass")), "scm", (gpointer)1);
+/*DeleteFiguredBass delete_figured_bass*/
+SCM scheme_DeleteFiguredBass(SCM optional);
+install_scm_function ("d-DeleteFiguredBass", scheme_DeleteFiguredBass);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "DeleteFiguredBass")), "scm", (gpointer)1);
+/*HideFiguredBass hide_figured_bass*/
+SCM scheme_HideFiguredBass(SCM optional);
+install_scm_function ("d-HideFiguredBass", scheme_HideFiguredBass);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "HideFiguredBass")), "scm", (gpointer)1);
 /*EditChords fakechord_insert*/
 SCM scheme_EditChords(SCM optional);
 install_scm_function ("d-EditChords", scheme_EditChords);
@@ -1250,7 +1298,10 @@ SCM scheme_InsertDur0(SCM optional);
 install_scm_function ("d-Insert0", scheme_InsertDur0);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Change0")), "scm", (gpointer)1);
 SCM scheme_ChangeDur0(SCM optional);
-install_scm_function ("d-Change0", scheme_ChangeRest0);
+install_scm_function ("d-Change0", scheme_ChangeDur0);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Set0")), "scm", (gpointer)1);
+SCM scheme_SetDur0(SCM optional);
+install_scm_function ("d-Set0", scheme_SetDur0);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertRest0")), "scm", (gpointer)1);
 SCM scheme_InsertRest0(SCM optional);
 install_scm_function ("d-InsertRest0", scheme_InsertRest0);
@@ -1266,7 +1317,10 @@ SCM scheme_InsertDur1(SCM optional);
 install_scm_function ("d-Insert1", scheme_InsertDur1);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Change1")), "scm", (gpointer)1);
 SCM scheme_ChangeDur1(SCM optional);
-install_scm_function ("d-Change1", scheme_ChangeRest1);
+install_scm_function ("d-Change1", scheme_ChangeDur1);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Set1")), "scm", (gpointer)1);
+SCM scheme_SetDur1(SCM optional);
+install_scm_function ("d-Set1", scheme_SetDur1);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertRest1")), "scm", (gpointer)1);
 SCM scheme_InsertRest1(SCM optional);
 install_scm_function ("d-InsertRest1", scheme_InsertRest1);
@@ -1282,7 +1336,10 @@ SCM scheme_InsertDur2(SCM optional);
 install_scm_function ("d-Insert2", scheme_InsertDur2);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Change2")), "scm", (gpointer)1);
 SCM scheme_ChangeDur2(SCM optional);
-install_scm_function ("d-Change2", scheme_ChangeRest2);
+install_scm_function ("d-Change2", scheme_ChangeDur2);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Set2")), "scm", (gpointer)1);
+SCM scheme_SetDur2(SCM optional);
+install_scm_function ("d-Set2", scheme_SetDur2);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertRest2")), "scm", (gpointer)1);
 SCM scheme_InsertRest2(SCM optional);
 install_scm_function ("d-InsertRest2", scheme_InsertRest2);
@@ -1298,7 +1355,10 @@ SCM scheme_InsertDur3(SCM optional);
 install_scm_function ("d-Insert3", scheme_InsertDur3);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Change3")), "scm", (gpointer)1);
 SCM scheme_ChangeDur3(SCM optional);
-install_scm_function ("d-Change3", scheme_ChangeRest3);
+install_scm_function ("d-Change3", scheme_ChangeDur3);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Set3")), "scm", (gpointer)1);
+SCM scheme_SetDur3(SCM optional);
+install_scm_function ("d-Set3", scheme_SetDur3);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertRest3")), "scm", (gpointer)1);
 SCM scheme_InsertRest3(SCM optional);
 install_scm_function ("d-InsertRest3", scheme_InsertRest3);
@@ -1314,7 +1374,10 @@ SCM scheme_InsertDur4(SCM optional);
 install_scm_function ("d-Insert4", scheme_InsertDur4);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Change4")), "scm", (gpointer)1);
 SCM scheme_ChangeDur4(SCM optional);
-install_scm_function ("d-Change4", scheme_ChangeRest4);
+install_scm_function ("d-Change4", scheme_ChangeDur4);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Set4")), "scm", (gpointer)1);
+SCM scheme_SetDur4(SCM optional);
+install_scm_function ("d-Set4", scheme_SetDur4);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertRest4")), "scm", (gpointer)1);
 SCM scheme_InsertRest4(SCM optional);
 install_scm_function ("d-InsertRest4", scheme_InsertRest4);
@@ -1330,7 +1393,10 @@ SCM scheme_InsertDur5(SCM optional);
 install_scm_function ("d-Insert5", scheme_InsertDur5);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Change5")), "scm", (gpointer)1);
 SCM scheme_ChangeDur5(SCM optional);
-install_scm_function ("d-Change5", scheme_ChangeRest5);
+install_scm_function ("d-Change5", scheme_ChangeDur5);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Set5")), "scm", (gpointer)1);
+SCM scheme_SetDur5(SCM optional);
+install_scm_function ("d-Set5", scheme_SetDur5);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertRest5")), "scm", (gpointer)1);
 SCM scheme_InsertRest5(SCM optional);
 install_scm_function ("d-InsertRest5", scheme_InsertRest5);
@@ -1346,10 +1412,51 @@ SCM scheme_InsertDur6(SCM optional);
 install_scm_function ("d-Insert6", scheme_InsertDur6);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Change6")), "scm", (gpointer)1);
 SCM scheme_ChangeDur6(SCM optional);
-install_scm_function ("d-Change6", scheme_ChangeRest6);
+install_scm_function ("d-Change6", scheme_ChangeDur6);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Set6")), "scm", (gpointer)1);
+SCM scheme_SetDur6(SCM optional);
+install_scm_function ("d-Set6", scheme_SetDur6);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertRest6")), "scm", (gpointer)1);
 SCM scheme_InsertRest6(SCM optional);
 install_scm_function ("d-InsertRest6", scheme_InsertRest6);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeRest6")), "scm", (gpointer)1);
 SCM scheme_ChangeRest6(SCM optional);
 install_scm_function ("d-ChangeRest6", scheme_ChangeRest6);
+/*7 */
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "7")), "scm", (gpointer)1);
+SCM scheme_7(SCM optional);
+install_scm_function ("d-7", scheme_7);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Insert7")), "scm", (gpointer)1);
+SCM scheme_InsertDur7(SCM optional);
+install_scm_function ("d-Insert7", scheme_InsertDur7);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Change7")), "scm", (gpointer)1);
+SCM scheme_ChangeDur7(SCM optional);
+install_scm_function ("d-Change7", scheme_ChangeDur7);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Set7")), "scm", (gpointer)1);
+SCM scheme_SetDur7(SCM optional);
+install_scm_function ("d-Set7", scheme_SetDur7);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertRest7")), "scm", (gpointer)1);
+SCM scheme_InsertRest7(SCM optional);
+install_scm_function ("d-InsertRest7", scheme_InsertRest7);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeRest7")), "scm", (gpointer)1);
+SCM scheme_ChangeRest7(SCM optional);
+install_scm_function ("d-ChangeRest7", scheme_ChangeRest7);
+/*8 */
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "8")), "scm", (gpointer)1);
+SCM scheme_8(SCM optional);
+install_scm_function ("d-8", scheme_8);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Insert8")), "scm", (gpointer)1);
+SCM scheme_InsertDur8(SCM optional);
+install_scm_function ("d-Insert8", scheme_InsertDur8);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Change8")), "scm", (gpointer)1);
+SCM scheme_ChangeDur8(SCM optional);
+install_scm_function ("d-Change8", scheme_ChangeDur8);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Set8")), "scm", (gpointer)1);
+SCM scheme_SetDur8(SCM optional);
+install_scm_function ("d-Set8", scheme_SetDur8);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertRest8")), "scm", (gpointer)1);
+SCM scheme_InsertRest8(SCM optional);
+install_scm_function ("d-InsertRest8", scheme_InsertRest8);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ChangeRest8")), "scm", (gpointer)1);
+SCM scheme_ChangeRest8(SCM optional);
+install_scm_function ("d-ChangeRest8", scheme_ChangeRest8);
