@@ -165,7 +165,7 @@ copytobuffer (DenemoScore * si)
 	  k = 0;		/* Set it for next run through object loop */
 	  
 	}			/* End measure loop */
-      if (staffsinbuffer > 1)
+      if ((staffsinbuffer > 1) && (i < si->laststaffmarked))
 	{
 	  theobjs = g_list_append (theobjs, newstaffbreakobject ());
 	  g_debug ("Inserting Staffbreak object in copybuffer");
@@ -358,6 +358,49 @@ cuttobuffer (DenemoScore * si)
     gtk_widget_draw (si->scorearea, NULL);  */
 }
 
+
+
+DenemoObjType get_clip_obj_type(gint m, gint n) {
+  if(copybuffer==NULL)
+    return -1;
+  GList *stafflist = g_list_nth(copybuffer, m);
+  if(stafflist==NULL)
+    return -1;
+  GList *curbufferobj = g_list_nth(stafflist->data, n);
+  if(curbufferobj==NULL || curbufferobj->data==NULL )
+    return -1;
+  return ((DenemoObject*)(curbufferobj->data))->type;
+}
+
+// insert the nth object from the copybuffer into music at the cursor position
+// return TRUE if inserted
+gboolean insert_clip_obj(gint m, gint n) {
+  DenemoScore *si = Denemo.gui->si;
+  if(copybuffer==NULL)
+    return FALSE;
+  GList *stafflist = g_list_nth(copybuffer, m);
+  if(stafflist==NULL)
+    return FALSE;
+  objnode *curbufferobj = g_list_nth(stafflist->data, n);
+  if(curbufferobj==NULL)
+    return FALSE;
+  DenemoObject *clonedobj; 
+  DenemoObject *curobj = (DenemoObject*)curbufferobj->data; 
+  clonedobj = dnm_clone_object (curobj);
+  
+  clonedobj->starttick = (si->currentobject?
+			     ((DenemoObject *)si->currentobject->data)->starttickofnextnote: 0);
+  Denemo.gui->si->currentmeasure->data =
+    g_list_insert ((objnode *)si->currentmeasure->data,
+		   clonedobj, si->cursor_x);
+  si->cursor_x++;
+  if (si->cursor_appending)
+    si->currentobject = g_list_last ((objnode *) si->currentmeasure->data);
+  else
+    si->currentobject = g_list_nth ((objnode *) si->currentmeasure->data,
+				    si->cursor_x);
+  return TRUE;
+}
 /**
  * pastefrombuffer
  * Pastes the current buffer to the score
@@ -649,7 +692,30 @@ goto_mark (GtkAction *action, DenemoScriptParam *param)
   } 
 }
 
+static GSList *positions=NULL;
+DenemoPosition *pop_position(void) {
+  DenemoPosition *pos;
+  if(positions) {
+    pos = positions->data;
+    positions = g_slist_delete_link(positions, positions);
+    return pos;
+  }
+  return NULL;
+}
 
+void push_position(void) {
+  DenemoScore *si = Denemo.gui->si;
+  DenemoPosition *pos = ( DenemoPosition *)g_malloc(sizeof(DenemoPosition));
+  pos->movement =  g_list_index(Denemo.gui->movements, si)+1;
+  pos->staff =  si->currentstaffnum;
+  pos->measure = si->currentmeasurenum;
+  pos->object =  si->currentobject?si->cursor_x+1:0;
+  if(pos->movement)
+     positions = g_slist_prepend(positions, pos);
+  else
+    g_free(pos);
+  //g_print("%d %d %d %d \n", pos->movement, pos->staff, pos->measure, pos->object);
+}
 
 
 /**
