@@ -198,13 +198,14 @@ struct callbackdata
   GtkWidget *midi_prognum;
   GtkWidget *midi_channel;
   GtkWidget *midi_prognum_override;
+  GtkWidget *device_port;
   GtkWidget *space_above;
   GtkWidget *space_below;
   GtkWidget *no_of_lines;
   GtkWidget *transposition;
   GtkWidget *volume;
   GtkWidget *mute_volume;
-  GtkWidget *pos_in_half_lines;
+ 
   GtkWidget *context;
   GtkWidget *staff_prolog_insert;
   GtkWidget *voice_prolog_insert;
@@ -250,14 +251,21 @@ set_properties (struct callbackdata *cbdata)
   gint err;
 
 #define ASSIGNTEXT(field) \
+  if(cbdata->field)\
     g_string_assign (staffstruct->field,\
     gtk_entry_get_text (GTK_ENTRY (cbdata->field)))
 
 #define ASSIGNNUMBER(field) \
+  if(cbdata->field)\
     staffstruct->field = \
       atoi(gtk_entry_get_text(GTK_ENTRY (cbdata->field)))
+#define ASSIGNNUMBER_1(field) \
+  if(cbdata->field)\
+    staffstruct->field = \
+      atoi(gtk_entry_get_text(GTK_ENTRY (cbdata->field)))-1
 
 #define ASSIGNBOOLEAN(field) \
+  if(cbdata->field)\
     staffstruct->field = \
     (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cbdata->field)));
 
@@ -267,12 +275,6 @@ set_properties (struct callbackdata *cbdata)
      staffstruct->denemo_name);
   set_lily_name (staffstruct->denemo_name, staffstruct->lily_name);
 
-#ifdef _HAVE_JACK_
-  /* check to make sure jack actually assigned a port before renaming */
-  if (staffstruct->jack_midi_out_port >= 0)
-    err = rename_jack_midi_port(staffstruct->jack_midi_out_port, staffstruct->denemo_name->str);
-#endif  
-
   /* !!!! Insert advisory function for detecting colliding staff names
    * here */
   //g_print("first %d\t", staffstruct->space_above);
@@ -281,16 +283,31 @@ set_properties (struct callbackdata *cbdata)
   ASSIGNNUMBER(space_below);
   ASSIGNNUMBER(no_of_lines);
   ASSIGNNUMBER(transposition);
-  ASSIGNNUMBER(pos_in_half_lines);
+
  
   /* set MIDI channel/prognum */
   ASSIGNTEXT(midi_instrument);
+  ASSIGNTEXT(device_port);
   ASSIGNBOOLEAN(mute_volume);
   ASSIGNNUMBER(volume);
-  ASSIGNBOOLEAN(midi_prognum_override);
-  ASSIGNNUMBER(midi_prognum);
-  ASSIGNNUMBER(midi_channel);
-
+  // ASSIGNBOOLEAN(midi_prognum_override);
+  if(staffstruct->midi_instrument->len) {
+    staffstruct->midi_prognum = get_midi_prognum();
+    gint i;
+    for(i=0;instruments[i];i++) {
+      if(!strcmp(instruments[i],staffstruct->midi_instrument->str)) {
+	staffstruct->midi_prognum = i;
+	break;
+      }
+    }
+    if(staffstruct->midi_prognum != i)
+      ASSIGNNUMBER_1(midi_prognum);
+    ASSIGNNUMBER_1(midi_channel);
+  } else {
+    ASSIGNNUMBER_1(midi_prognum);
+    ASSIGNNUMBER_1(midi_channel);
+  }
+  g_print("chan prog %d %d\n", staffstruct->midi_channel, staffstruct->midi_prognum); 
   /* staff context */
   DenemoContext old = staffstruct->context;
   staffstruct->context =
@@ -308,45 +325,17 @@ set_properties (struct callbackdata *cbdata)
   score_status(cbdata->gui, TRUE);
 }
 
-void staff_properties_change_cb (GtkAction *action, gpointer param) {
-  if(action)
-    (void) staff_properties_change(NULL);
-  else if(param==NULL)
-    (void) staff_properties_change(NULL);
-  else {
-    GString *values = (GString *)param;
-    gchar *str;
-    DenemoStaff *staff = (DenemoStaff *) Denemo.gui->si->currentstaff->data;
-#define SET_STRING(a, b)     if( (str = g_strstr_len(values->str+i,strlen(values->str+i), a))) {\
-      if(staff->b)\
-	g_string_free(staff->b, TRUE);\
-      staff->b = g_string_new(str+strlen(a)+1);\
-    }
-    gint i;
-    for(i=0;i<values->len;i+=strlen(values->str+i)+1) {
-      // SET_STRING("staff-prolog-insert", staff_prolog_insert); 
-      //SET_STRING("voice-prolog-insert", voice_prolog_insert);
-    // others ....
-    }
-#undef SET_STRING
-  }
-}
-
 
 /**
- * Create Dialog to allow the user to set the staffs parameters
+ * Create Dialog to allow the user to set the current staff's parameters
  * 
- * @param action Gtk Action event or NULL if called programatically
- * @param callback_data if action==NULL this holds newstaffinfotopass structure otherwise unused.
- * @return success or failure 
  */
-gboolean
-staff_properties_change (gpointer callback_data)
+static gboolean
+staff_properties_change (void)
 {
   DenemoScore *si;
   DenemoGUI *gui;
-  DenemoStaff *thestaff;
-  guint callback_action = 0;
+
   gboolean result = FALSE;
   DenemoStaff *staffstruct;
   GtkWidget *dialog;
@@ -363,6 +352,7 @@ staff_properties_change (gpointer callback_data)
   if (!instrument_list)
     {
       int i=0;
+      instrument_list = g_list_append (instrument_list, "");
       do {
 	   instrument_list = g_list_append (instrument_list, instruments[i++]);
       } while (instruments[i]);
@@ -377,7 +367,6 @@ staff_properties_change (gpointer callback_data)
 	}
     }
 
-  if (callback_data==NULL)
     {
       gui = Denemo.gui;
       si = gui->si;
@@ -388,16 +377,7 @@ staff_properties_change (gpointer callback_data)
 		      "to see them in the print-out.");
       }
     }
-  else
-    {
-      struct newstaffinfotopass *cbdata1 =
-	(struct newstaffinfotopass *) callback_data;
-      /* si =  cbdata1->si; */
-      gui = cbdata1->gui;
-      staffstruct = cbdata1->staff;
-      callback_action = cbdata1->addat;
-    }
-
+ 
 
   if (!entrycontent)
     {
@@ -448,6 +428,18 @@ staff_properties_change (gpointer callback_data)
   gtk_box_pack_start (GTK_BOX (hbox), field, FALSE, FALSE, 0);\
   cbdata.field = field;
 
+#define INTENTRY_LIMITS_1(thelabel, field, min, max) \
+  GtkWidget *field;\
+  hbox = gtk_hbox_new (FALSE, 8);\
+  gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);\
+  label = gtk_label_new (thelabel);\
+  gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);\
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);\
+  field = gtk_spin_button_new_with_range (min, max, 1.0);\
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (field), staffstruct->field+1);\
+  gtk_box_pack_start (GTK_BOX (hbox), field, FALSE, FALSE, 0);\
+  cbdata.field = field;
+
 #define BOOLEANENTRY(thelabel, field) \
   GtkWidget *field;\
   field =\
@@ -478,7 +470,7 @@ staff_properties_change (gpointer callback_data)
   INTENTRY_LIMITS("Space below:", space_below, 0, MAXEXTRASPACE); 
   INTENTRY_LIMITS("Number of Lines:", no_of_lines, 1, 5);
   INTENTRY_LIMITS("Transposition:", transposition, -30, 30);
-  INTENTRY_LIMITS("Position in half-lines:", pos_in_half_lines, -5, 5);
+
   
   /*print appearance tab */
   NEWPAGE("Printout Appearance");
@@ -495,10 +487,19 @@ staff_properties_change (gpointer callback_data)
   COMBOBOXENTRY("MIDI Instrument:", midi_instrument, instrument_list, staffstruct->midi_instrument);
   BOOLEANENTRY("Mute", mute_volume);
   INTENTRY_LIMITS("Volume:", volume, 0, 127);
-  BOOLEANENTRY("Override MIDI Channel/Program", midi_prognum_override);  
-  INTENTRY_LIMITS("Channel:", midi_channel, 1, 16);
-  INTENTRY_LIMITS("Program:", midi_prognum, 1, 128);
-  
+  // BOOLEANENTRY("Override MIDI Channel/Program", midi_prognum_override);  
+  INTENTRY_LIMITS_1("Channel:", midi_channel, 1, 16);
+  INTENTRY_LIMITS_1("Program:", midi_prognum, 1, 128);
+  g_print("chan prog %d %d\n", staffstruct->midi_channel, staffstruct->midi_prognum); 
+
+  GList *md = device_manager_DevicePort_list();
+  if(md) {
+#ifdef _HAVE_JACK_
+    COMBOBOXENTRY("Midi Devices", device_port, md, staffstruct->device_port);
+#endif
+  }
+  else
+    cbdata.device_port = NULL;
   /* Set up the callback data */
 #define SETCALLBACKDATA(field) \
     cbdata.field = field;
@@ -516,7 +517,7 @@ staff_properties_change (gpointer callback_data)
   gtk_entry_set_activates_default (GTK_ENTRY (space_below), TRUE);
   gtk_entry_set_activates_default (GTK_ENTRY (no_of_lines), TRUE);
   gtk_entry_set_activates_default (GTK_ENTRY (transposition), TRUE);
-  gtk_entry_set_activates_default (GTK_ENTRY (pos_in_half_lines), TRUE);
+
 */
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 
@@ -530,3 +531,38 @@ staff_properties_change (gpointer callback_data)
 
   return result;
 }
+
+
+void staff_properties_change_cb (GtkAction *action, DenemoScriptParam * param) {
+  GET_4PARAMS(action, param, denemo_name, device_port, midi_prognum, midi_channel);
+  DenemoStaff *staff = (DenemoStaff *) Denemo.gui->si->currentstaff->data;
+
+ if(query) {
+   if(*query) if(!strcmp("denemo_name", query)) {
+     g_string_assign(param->string, staff->denemo_name->str);
+     param->status = TRUE;
+   }
+   return;
+ }
+ if(denemo_name) {
+   g_string_assign(staff->denemo_name, denemo_name);
+    param->status = TRUE;
+   return;
+
+ }
+ if(device_port) {
+   g_string_assign(staff->device_port, device_port);
+    param->status = TRUE;
+    return;
+ }
+  
+ if(midi_prognum) {
+   staff->midi_prognum = atoi(midi_prognum);
+   return;
+ }
+ if(midi_channel) {
+   staff->midi_channel = atoi(midi_channel);
+   return;
+ }
+ (void) staff_properties_change();
+}
