@@ -275,14 +275,15 @@ setpixelmin (DenemoObject * theobj)
 #if 0
  40;
 #else
-      8;
+      16;
 #endif
-      theobj->space_before = 0;
+      theobj->space_before = theobj->minpixelsalloted/2;
       break;
     case LILYDIRECTIVE:
       {
 	DenemoDirective *directive = (DenemoDirective*)theobj->object;	
-	theobj->minpixelsalloted = directive->minpixels;
+	theobj->minpixelsalloted = directive->minpixels?directive->minpixels:16;
+	theobj->space_before = theobj->minpixelsalloted/2;
       }
       break;
     case CLEF:
@@ -309,7 +310,7 @@ setpixelmin (DenemoObject * theobj)
     case GRACE_START:
     case GRACE_END:
       theobj->minpixelsalloted = 16;
-      theobj->space_before = 0;
+      theobj->space_before = theobj->minpixelsalloted/2;
       break;
     default:
       theobj->minpixelsalloted = 0;
@@ -1061,12 +1062,14 @@ void console_output(gchar *text) {
   gtk_text_buffer_insert(buffer, &enditer, text, -1);
 }
 
-/* returns an override flag ORd from all those in the list of directives */
+/* returns an override flag ORd from all those in the list of directives, 
+   excluding ones with DENEMO_OVERRIDE_HIDDEN set */
 gint get_override(GList *g) {
   gint ret = 0;
   for(;g;g=g->next) {
     DenemoDirective *d = g->data;
-    ret |= d->override;
+    if(!(d->override&DENEMO_OVERRIDE_HIDDEN))
+      ret |= d->override;
   }
   return ret;
 }
