@@ -98,6 +98,9 @@ freeit (gpointer data, gpointer user_data);
 void 
 popup_menu(gchar *name);
 
+void
+warningmessage (gchar * msg);
+
 void
 warningdialog(gchar *msg);
 void
@@ -114,7 +117,6 @@ headerfields(GtkWidget *dialog, GtkListStore *list_store,
 void initdir ();
 const gchar *get_data_dir ();
 const gchar *get_conf_dir ();
-const gchar *get_plugin_dir ();
 const gchar *get_locale_dir ();
 
 void kill_process (GPid pid);
@@ -250,4 +252,6 @@ if(!action && param){\
 gchar * get_option(gchar *str, gint length);
 void console_output(gchar *text);
 
+gint get_override(GList *g);
+
 #endif /* UTILS_H */
